@@ -17,9 +17,6 @@ autoreconf -v --install --force || exit 1
 # otherwise "make dist" fails.
 touch config/depcomp
 
-#create an empty config/config.rpath else iconf configure test generates a warning
-touch config/config.rpath
-
 # ensure COPYING is based on cpl1.0.txt
 #   cpl1.0.txt was obtained from: http://www.opensource.org/licenses/cpl1.0.txt
 rm -f COPYING
