@@ -1,4 +1,4 @@
-/* $Id: Draw.c,v 1.5 2005/11/13 01:35:10 ellson Exp $ $Revision: 1.5 $ */
+/* $Id: Draw.c,v 1.8 2009/10/13 14:20:29 ellson Exp $ $Revision: 1.8 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -44,6 +44,7 @@
  */
 
 #include <stdio.h>
+#include <stdint.h>
 #include "SFinternal.h"
 #include "xstat.h"
 #include <X11/StringDefs.h>
@@ -59,14 +60,6 @@
 #endif
 #define ABS(x) (((x) < 0) ? (-(x)) : (x))
 
-#ifdef HAVE_INTPTR_T
-#define INT2PTR(t,v) ((t)(intptr_t)(v))
-#define PTR2INT(v) ((Sflong_t)(intptr_t)(v))
-#else
-#define INT2PTR(t,v) ((t)(v))
-#define PTR2INT(v) ((Sflong_t)(v))
-#endif
-
 typedef struct {
     char *fontname;
 } TextData, *textPtr;
