@@ -1,4 +1,4 @@
-/* $Id: btree.c,v 1.5 2008/04/09 21:06:09 erg Exp $ $Revision: 1.5 $ */
+/* $Id: btree.c,v 1.10 2009/12/03 19:16:04 arif Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -43,7 +43,7 @@ int insert_node(btree_node * parent_n, btree_node * n)
 {
     parent_n->child_count++;
     parent_n->childs = RALLOC(parent_n->child_count, parent_n->childs,
-		btree_node *);
+			      btree_node *);
     parent_n->childs[parent_n->child_count - 1] = n;
     n->rank = parent_n->rank + 1;
     n->parent = parent_n;
@@ -67,7 +67,7 @@ int delete_node_recursive(btree_node * n)
 
 int delete_node(btree_node * n)
 {
-    btree_node* parent = n->parent;
+    btree_node *parent = n->parent;
     int i = 0;
     int child_found = 0;
     //rmeove from parent's child list
@@ -81,7 +81,8 @@ int delete_node(btree_node * n)
 		parent->childs[i] = parent->childs[i + 1];
 	}
     }
-    parent->childs = RALLOC(parent->child_count,parent->childs, btree_node *);
+    parent->childs =
+	RALLOC(parent->child_count, parent->childs, btree_node *);
     delete_node_recursive(n);
     return 1;
 }
@@ -125,14 +126,15 @@ int print_children(btree_node * n)
     else
 	printf("%*s %c(%i)\n", n->rank * 5 + 1, "", n->op, n->rank);
     prev_rank = n->rank;
-    for (i = 0; i < n->child_count; i++) {
+    for (i = 0; i < n->child_count; i++) 
+    {
 	print_children(n->childs[i]);
     }
     return 1;
 
 }
 
-int sample_tree()
+int sample_tree(void)
 {
     btree_node *root;
     btree_node *n;
@@ -178,7 +180,7 @@ btree_node *tree_from_filter_string(char *filter_string)
     char *b_cursor = 0;
     char *c_cursor;
     char op = '\0';
-    char last_char;
+    char last_char = '\0';
     root = new_node("R", "", 0, 0);
     cursor = root;
     c_cursor = filter_string;
@@ -249,11 +251,10 @@ int evaluate_filter_atom(char *string, btree_node * Nodes[], char *op)
     while (*c_cursor != '\0') {
 	if (kp_open) {
 	    if ((*c_cursor == ',') || ((*c_cursor == ']') && (!qt_open))) {
-		attrs = RALLOC(attrs_count + 1, attrs, char*);
+		attrs = RALLOC(attrs_count + 1, attrs, char *);
 		attrs[attrs_count] = strdup(buff_attr);
 		attrs_count++;
-		values =
-		    RALLOC(values_count + 1, values, char*);
+		values = RALLOC(values_count + 1, values, char *);
 		values[values_count] = strdup(buff_value);
 		values_count++;
 		buff_attr[0] = '\0';
