@@ -1,4 +1,4 @@
-/* $Id: draw.c,v 1.28 2009/03/10 22:58:49 arif Exp $ $Revision: 1.28 $ */
+/* $Id: draw.c,v 1.52 2009/12/03 19:16:04 arif Exp $ $Revision: 1.52 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -28,20 +28,22 @@ XDOT DRAWING FUNCTIONS, maybe need to move them somewhere else
 #include "xdot.h"
 #include "viewport.h"
 #include "topfisheyeview.h"
+#include "appmouse.h"
+#include "hotkeymap.h"
 
 //delta values
 static float dx = 0.0;
 static float dy = 0.0;
-static float globalz = 0.0;
+#define LAYER_DIFF 0.001
 
 GLubyte rasters[24] = {
     0xc0, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0xff, 0x00,
-	0xff, 0x00,
+    0xff, 0x00,
     0xc0, 0x00, 0xc0, 0x00, 0xc0, 0x00, 0xff, 0xc0, 0xff, 0xc0
 };
 
-static void
-DrawBezier(GLfloat * xp, GLfloat * yp, GLfloat * zp, int filled, int param)
+void DrawBezier(GLfloat * xp, GLfloat * yp, GLfloat * zp, int filled,
+		int param)
 {
     /*copied from NEHE */
     /*Written by: David Nikdel ( ogapo@ithink.net ) */
@@ -99,7 +101,7 @@ DrawBezier(GLfloat * xp, GLfloat * yp, GLfloat * zp, int filled, int param)
 	Z = Az * a * a * a + Bz * 3 * a * a * b + Cz * 3 * a * b * b +
 	    Dz * b * b * b;
 	// Draw the line from point to point (assuming OGL is set up properly)
-	glVertex3d(X, Y, Z+globalz);
+	glVertex3d(X, Y, Z + view->Topview->global_z);
 	// Change the variable
 	a -= 0.05;
 	b = 1.0 - a;
@@ -111,21 +113,21 @@ DrawBezier(GLfloat * xp, GLfloat * yp, GLfloat * zp, int filled, int param)
 static void set_options(sdot_op * op, int param)
 {
 
-    if ((param == 1) && (view->mouse.mouse_mode == 10) && (view->mouse.mouse_down == 1))	//selected, if there is move, move it
+    int a=get_mode(view);
+    if ((param == 1) && (a == 10) && (view->mouse.down == 1))	//selected, if there is move, move it
     {
-		dx = view->GLx - view->GLx2;
-		dy = view->GLy - view->GLy2;
-    } else 
-	{
-		dx = 0;
-		dy = 0;
+	dx = view->mouse.GLinitPos.x-view->mouse.GLfinalPos.x;
+	dy = view->mouse.GLinitPos.y-view->mouse.GLfinalPos.y;
+    } else {
+	dx = 0;
+	dy = 0;
     }
 
 }
 
 static void relocate_spline(sdot_op * sop, int param)
 {
-    Agedge_t *e;
+/*    Agedge_t *e;
     Agnode_t *tn;		//tail node
     Agnode_t *hn;		//head node
     int i = 0;
@@ -197,20 +199,24 @@ static void relocate_spline(sdot_op * sop, int param)
 				}
 			}
 		}
-	}
+	}*/
 }
 
-static void DrawBeziers(xdot_op * op, int param)
+void DrawBeziers(sdot_op* o, int param)
 {
     //SEND ALL CONTROL POINTS IN 3D ARRAYS
 
-    GLfloat tempX[4];
+	GLfloat tempX[4];
     GLfloat tempY[4];
     GLfloat tempZ[4];
     int temp = 0;
     int filled;
     int i = 0;
-    SelectBeziers((sdot_op *) op);
+	static xdot_op * op;
+	op=&o->op;
+	view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF;
+
+//    SelectBeziers((sdot_op *) op);
     relocate_spline((sdot_op *) op, param);
     if (op->kind == xd_filled_bezier)
 	filled = 1;
@@ -238,70 +244,24 @@ static void DrawBeziers(xdot_op * op, int param)
     DrawBezier(tempX, tempY, tempZ, filled, param);
 }
 
-/*function to load .raw files*/
-#if 0
-static void
-load_raw_texture(char *file_name, int width, int height, int depth,
-		 GLenum colour_type, GLenum filter_type)
-{
-    //Line 3 creates a pointer to an (as yet unallocated) array of gl unsigned bytes - 
-    //this will store our image until we've passed it to opengl.  Line 4 stores the file pointer, don't worry about that. 
-    GLubyte *raw_bitmap;
-    FILE *file;
 
-    //The if statement from line 6-10 opens the file and reports an error if it doesn't exist.   
-
-    if ((file = fopen(file_name, "rb")) == NULL) {
-	printf("File Not Found : %s\n", file_name);
-	exit(1);
-    }
-    //Line 11 allocates the correct number of bytes for the size and depth of the image.  Remember, our image depth will usually be 3 -- one 'channel' each for red, green and blue values.   
-    //Lines 13-18 check if the memory was allocated correctly and quit the program if there was a problem. 
-
-    raw_bitmap = N_GNEW(width * height * depth, GLubyte);
-
-    if (raw_bitmap == NULL) {
-	printf("Cannot allocate memory for texture\n");
-	fclose(file);
-	exit(1);
-    }
-    //Line 19 reads the required number of bytes from the file and places them into our glubyte array.  Line 20 closes the close as it isn't required anymore.   
-    fread(raw_bitmap, width * height * depth, 1, file);
-    fclose(file);
-
-    //Lines 22-25 set the texture's mapping type and environment settings.  GL_TEXTURE_MAG_FILTER and GL_TEXTURE_MIN_FILTER are enumerands that let us change the way in which opengl magnifies and minifies the texture.  If we passed GL_LINEAR to the function, our texture would be interpolated using bilinear filtering (in other words, it'd appear smoothed).  If we passed GL_NEAREST then no smoothing would occur.  By passing GL_MODULATE to the texture environment function, we tell opengl to blend the texture with the base colour of the object.  Had we specified GL_DECAL or GL_REPLACE then the base colour (and therefore our lighting effect) would be replaced purely with the colours of the texture. 
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, filter_type);
-    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, filter_type);
-
-    glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
-
-    //Line 27 passes the image to opengl using the function gluBuild2DMipmaps.
-    //Read a graphics book for a description of mipmaps.
-    //This function will also resize the texture map if it doesn't conform 
-    //to the opengl restriction of height and width values being a power of 2.   
-    gluBuild2DMipmaps(GL_TEXTURE_2D, colour_type, width, height,
-		      colour_type, GL_UNSIGNED_BYTE, raw_bitmap);
-
-    //We don't need our texture in the temporary array anymore as it has been passed to opengl.
-    //We use the standard C library call 'free' to return the allocated memory.  
-    free(raw_bitmap);
-}
-#endif
-
-//Draws a ellpise made out of points.
+//Draws an ellpise made out of points.
 //void DrawEllipse(xdot_point* xpoint,GLfloat xradius, GLfloat yradius,int filled)
-static void DrawEllipse(xdot_op * op, int param)
+void DrawEllipse(sdot_op*  o, int param)
 {
     //to draw a circle set xradius and yradius same values
     GLfloat x, y, xradius, yradius;
     int i = 0;
     int filled;
+	static xdot_op * op;
+	op=&o->op;
+	view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF;
     set_options((sdot_op *) op, param);
     x = op->u.ellipse.x - dx;
     y = op->u.ellipse.y - dy;
     xradius = (GLfloat) op->u.ellipse.w;
     yradius = (GLfloat) op->u.ellipse.h;
-    SelectEllipse((sdot_op *) op);
+//    SelectEllipse((sdot_op *) op);
     if (op->kind == xd_filled_ellipse) {
 	if (param == 0)
 	    glColor4f(view->fillColor.R, view->fillColor.G,
@@ -324,7 +284,6 @@ static void DrawEllipse(xdot_op * op, int param)
 	filled = 0;
     }
 
-    glLineWidth(view->LineWidth);
     if (!filled)
 	glBegin(GL_LINE_LOOP);
     else
@@ -333,17 +292,21 @@ static void DrawEllipse(xdot_op * op, int param)
 	//convert degrees into radians
 	float degInRad = (float) (i * DEG2RAD);
 	glVertex3f((GLfloat) (x + cos(degInRad) * xradius),
-		   (GLfloat) (y + sin(degInRad) * yradius),globalz);
+		   (GLfloat) (y + sin(degInRad) * yradius), view->Topview->global_z);
     }
     glEnd();
 }
 
-static void DrawPolygon(xdot_op * op, int param)
+extern void DrawPolygon(sdot_op * o, int param)
 //void DrawPolygon(xdot_point* xpoint,int count, int filled)
 {
     int i = 0;
     int filled;
-    SelectPolygon((sdot_op *) op);
+	static xdot_op * op;
+	op=&o->op;
+	view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF;
+
+	//SelectPolygon((sdot_op *) op);
     set_options((sdot_op *) op, param);
 
     if (op->kind == xd_filled_polygon) {
@@ -375,119 +338,117 @@ static void DrawPolygon(xdot_op * op, int param)
     for (i = 0; i < op->u.polygon.cnt; i = i + 1) {
 	glVertex3f((GLfloat) op->u.polygon.pts[i].x - dx,
 		   (GLfloat) op->u.polygon.pts[i].y - dy,
-		   (GLfloat) op->u.polygon.pts[i].z+globalz);
+		   (GLfloat) op->u.polygon.pts[i].z + view->Topview->global_z);
     }
-    glVertex3f((GLfloat) op->u.polygon.pts[0].x - dx, (GLfloat) op->u.polygon.pts[0].y - dy, (GLfloat) op->u.polygon.pts[0].z+globalz);	//close the polygon
+    glVertex3f((GLfloat) op->u.polygon.pts[0].x - dx, (GLfloat) op->u.polygon.pts[0].y - dy, (GLfloat) op->u.polygon.pts[0].z + view->Topview->global_z);	//close the polygon
     glEnd();
 }
 
-static void DrawPolyline(xdot_op * op, int param)
+void DrawPolyline(sdot_op* o, int param)
 {
     int i = 0;
+	static xdot_op * op;
+	op=&o->op;
+	view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF;
+
     if (param == 0)
 	glColor4f(view->penColor.R, view->penColor.G, view->penColor.B,
 		  view->penColor.A);
     if (param == 1)		//selected
 	glColor4f(view->selectedNodeColor.R, view->selectedNodeColor.G,
 		  view->selectedNodeColor.B, view->selectedNodeColor.A);
-    SelectPolyline((sdot_op *) op);
+    //SelectPolyline((sdot_op *) op);
     set_options((sdot_op *) op, param);
     glLineWidth(view->LineWidth);
     glBegin(GL_LINE_STRIP);
     for (i = 0; i < op->u.polyline.cnt; i = i + 1) {
 	glVertex3f((GLfloat) op->u.polyline.pts[i].x - dx,
 		   (GLfloat) op->u.polyline.pts[i].y - dy,
-		   (GLfloat) op->u.polyline.pts[i].z+globalz);
+		   (GLfloat) op->u.polyline.pts[i].z + view->Topview->global_z);
     }
     glEnd();
 }
 
-#if 0
-static void
-DrawBitmap(GLfloat bmpX, GLfloat bmpY, GLfloat bmpW, GLfloat bmpH)
+void SetFillColor(sdot_op*  o, int param)
 {
-    if (view->texture)
-	glEnable(GL_TEXTURE_2D);
-    else
-	glDisable(GL_TEXTURE_2D);
-/*	glRasterPos2d(bmpX,bmpY);
-	  glBitmap( bmpW,bmpH,0.0,0.0,0.0,0.0, 1); */
-    glBegin(GL_QUADS);
-    glTexCoord2d(bmpX, bmpY);
-    glVertex2d(bmpX, bmpY);
-    glTexCoord2d(bmpX + bmpW, bmpY);
-    glVertex2d(bmpX + bmpW, bmpY);
-    glTexCoord2d(bmpX + bmpW, bmpY + bmpH);
-    glVertex2d(bmpX + bmpW, bmpY + bmpH);
-    glTexCoord2d(bmpX, bmpY + bmpH);
-    glVertex2d(bmpX, bmpY + bmpH);
-    glEnd();
-    glDisable(GL_TEXTURE_2D);
-}
-#endif
-
-static void SetFillColor(xdot_op * op, int param)
-{
-    RGBColor c;
-    c = GetRGBColor(op->u.color);
+	glCompColor c;
+	static xdot_op * op;
+	op=&o->op;
+    c = GetglCompColor(op->u.color);
     view->fillColor.R = c.R;
     view->fillColor.G = c.G;
     view->fillColor.B = c.B;
     view->fillColor.A = c.A;
 }
-static void SetPenColor(xdot_op * op, int param)
+void SetPenColor(sdot_op* o, int param)
 {
-    RGBColor c;
-    c = GetRGBColor(op->u.color);
+    glCompColor c;
+	static xdot_op * op;
+	op=&o->op;
+    c = GetglCompColor(op->u.color);
     view->penColor.R = c.R;
     view->penColor.G = c.G;
     view->penColor.B = c.B;
     view->penColor.A = c.A;
 }
 
-static void SetStyle(xdot_op * op, int param)
+void SetStyle(sdot_op* o, int param)
 {
+	static xdot_op * op;
+	op=&o->op;
 
 
 }
 
-static void SetFont(xdot_op * op, int param)
+static sdot_op * font_op;
+
+void SetFont(sdot_op * o, int param)
 {
-	//activate the right font
-	view->fontset->activefont=add_font(view->fontset,op->u.font.name);//load or set active font
-	view->FontSize =  op->u.font.size;
+	font_op=o;
 }
 
-static void InsertImage(xdot_op * op, int param)
+void InsertImage(sdot_op * o, int param)
 {
-    SelectImage((sdot_op *) op);
-
 }
-static void EmbedText(xdot_op * op, int param)
+void EmbedText(sdot_op* o, int param)
 {
-    GLfloat x;
-    SelectText((sdot_op *) op);
-    set_options((sdot_op *) op, param);
-    if (op->u.text.align == 1)
-	x = (GLfloat) op->u.text.x - (GLfloat) (op->u.text.width / 2.0);
-    if (op->u.text.align == 0)
-	x = (GLfloat) op->u.text.x;
-    if (op->u.text.align == -1)
-	x = (GLfloat) op->u.text.x + op->u.text.width;
-	fontSize(view->fontset->fonts[view->fontset->activefont],view->FontSize);
-    if (param == 0)
-	fontColor(view->fontset->fonts[view->fontset->activefont],view->penColor.R, view->penColor.G, view->penColor.B);
-    if (param == 1)		//selected
-	fontColor(view->fontset->fonts[view->fontset->activefont],view->selectedNodeColor.R, view->selectedNodeColor.G,
-		  view->selectedNodeColor.B);
-	fontDrawString(view->fontset->fonts[view->fontset->activefont], (x - dx), (GLfloat)op->u.text.y -  dy,
-		   (GLfloat)op->u.text.width, op->u.text.text);
+	GLfloat x,y;
+	glColor4f(view->penColor.R,view->penColor.G,view->penColor.B,view->penColor.A);
+	view->Topview->global_z=view->Topview->global_z+o->layer*LAYER_DIFF+0.05;
+	switch (o->op.u.text.align)
+	{
+		case xd_left:
+			x=o->op.u.text.x ;
+			break;
+		case xd_center:
+			x=o->op.u.text.x - o->op.u.text.width / 2.0;
+			break;
+		case xd_right:
+			x=o->op.u.text.x - o->op.u.text.width;
+			break;
+
+	}
+	y=o->op.u.text.y;
+	if (o->font)
+		glCompDrawText3D(o->font,x,y,view->Topview->global_z,o->op.u.text.width,font_op->op.u.font.size);
+	else
+	{
+		o->font=new_font(
+		view->widgets,
+		o->op.u.text.text,
+		&view->penColor,
+		pangotext,
+		font_op->op.u.font.name,font_op->op.u.font.size,0);
+		//new_font(glCompSet * s, char *text, glCompColor * c, glCompFontType type, char *fontdesc, int fs)*/
+
+
+	}
 }
 
 void draw_selection_box(ViewInfo * view)
 {
-    if (((view->mouse.mouse_mode == 4) || (view->mouse.mouse_mode == 5))
-	&& view->mouse.mouse_down) {
+/*    if (((view->mouse.mouse_mode == 4) || (view->mouse.mouse_mode == 5))
+	&& view->mouse.down) {
 	glColor4f(view->Selection.SelectionColor.R,
 		  view->Selection.SelectionColor.G,
 		  view->Selection.SelectionColor.B,
@@ -497,34 +458,34 @@ void draw_selection_box(ViewInfo * view)
 	    glLineStipple(1, 15);
 	}
 	glBegin(GL_LINE_STRIP);
-	glVertex3f((GLfloat) view->GLx, (GLfloat) view->GLy,
-		   (GLfloat) 0.001+globalz);
-	glVertex3f((GLfloat) view->GLx, (GLfloat) view->GLy2,
-		   (GLfloat) 0.001+globalz);
-	glVertex3f((GLfloat) view->GLx2, (GLfloat) view->GLy2,
-		   (GLfloat) 0.001+globalz);
-	glVertex3f((GLfloat) view->GLx2, (GLfloat) view->GLy,
-		   (GLfloat) 0.001+globalz);
-	glVertex3f((GLfloat) view->GLx, (GLfloat) view->GLy,
-		   (GLfloat) 0.001+globalz);
+	glVertex3f((GLfloat) view->mouse.GLinitPos.x, (GLfloat) view->mouse.GLinitPos.y,
+		   (GLfloat) 0.001 + view->Topview->global_z);
+	glVertex3f((GLfloat) view->mouse.GLinitPos.x, (GLfloat) view->mouse.GLfinalPos.y,
+		   (GLfloat) 0.001 + view->Topview->global_z);
+	glVertex3f((GLfloat) view->mouse.GLfinalPos.x, (GLfloat) view->mouse.GLfinalPos.y,
+		   (GLfloat) 0.001 + view->Topview->global_z);
+	glVertex3f((GLfloat) view->mouse.GLfinalPos.x, (GLfloat) view->mouse.GLinitPos.y,
+		   (GLfloat) 0.001 + view->Topview->global_z);
+	glVertex3f((GLfloat) view->mouse.GLinitPos.x, (GLfloat) view->mouse.GLinitPos.y,
+		   (GLfloat) 0.001 + view->Topview->global_z);
 	glEnd();
 	if (view->mouse.mouse_mode == 5)
 	    glDisable(GL_LINE_STIPPLE);
 
-    }
+    }*/
 }
 
 void draw_magnifier(ViewInfo * view)
 {
 
-    if ((view->mouse.mouse_mode == MM_MAGNIFIER)
-	&& (view->mouse.mouse_down)) {
+    if ((get_mode(view) == MM_MAGNIFIER)
+	&& (view->mouse.down)) {
 
 	GLfloat mg_x, mg_y, mg_z;
 	//converting screen pixel distaances to GL distances
 	view->mg.GLwidth = GetOGLDistance(view->mg.width) / (float) 2.0;
 	view->mg.GLheight = GetOGLDistance(view->mg.height) / (float) 2.0;
-	GetOGLPosRef((int)view->mouse.mouse_X, (int)view->mouse.mouse_Y, &mg_x, &mg_y, &mg_z);	//retrieving mouse coords as GL coordinates
+	GetOGLPosRef((int) view->mouse.pos.x, (int) view->mouse.pos.y, &mg_x, &mg_y, &mg_z);	//retrieving mouse coords as GL coordinates
 	view->mg.x = mg_x;
 	view->mg.y = mg_y;
 	glLineWidth(4);
@@ -562,7 +523,7 @@ void draw_magnifier(ViewInfo * view)
 
 }
 
-static void draw_circle(float originX, float originY, float radius)
+void draw_circle(float originX, float originY, float radius)
 {
 /* draw a circle from a bunch of short lines */
     float vectorX1, vectorY1, vectorX, vectorY, angle;
@@ -574,7 +535,7 @@ static void draw_circle(float originX, float originY, float radius)
 	 angle += (float) 0.1) {
 	vectorX = originX + radius * (float) sin(angle);
 	vectorY = originY + radius * (float) cos(angle);
-	glVertex3d(vectorX1, vectorY1,globalz);
+	glVertex3d(vectorX1, vectorY1, view->Topview->global_z);
 	vectorY1 = vectorY;
 	vectorX1 = vectorX;
     }
@@ -583,33 +544,38 @@ static void draw_circle(float originX, float originY, float radius)
 
 }
 
-static GLUquadric* fisheyesphere;
+GLUquadric *fisheyesphere;
 void draw_fisheye_magnifier(ViewInfo * view)
 {
-    if ((view->mouse.mouse_mode == 21) && (view->mouse.mouse_down)) {
+    if (get_mode(view)==MM_FISHEYE_MAGNIFIER)
+
+    {
 	float a;
 	GLfloat mg_x, mg_y, mg_z;
 	a = GetOGLDistance((int) view->fmg.constantR);
 	view->fmg.R = (int) a;
-	GetOGLPosRef((int)view->mouse.mouse_X, (int)view->mouse.mouse_Y, &mg_x,
-		     &mg_y, &mg_z);
+	GetOGLPosRef((int) view->mouse.pos.x, (int) view->mouse.pos.y,
+		     &mg_x, &mg_y, &mg_z);
 	glColor4f((GLfloat) 0.3, (GLfloat) 0.1, (GLfloat) 0.8,
 		  (GLfloat) 1);
-	if (((view->fmg.x != mg_x) || (view->fmg.y != mg_y))&&(view->active_camera==-1)) {
-		fisheye_polar(mg_x, mg_y, view->Topview);
+	if (((view->fmg.x != mg_x) || (view->fmg.y != mg_y))
+	    && (view->active_camera == -1)) {
+	    fisheye_polar(mg_x, mg_y, view->Topview);
 	    draw_circle(mg_x, mg_y, a);
 	}
-	if (((view->fmg.x != mg_x) || (view->fmg.y != mg_y))&&(view->active_camera>-1)) {
-		fisheye_spherical(mg_x, mg_y,0.00,view->Topview);
+	if (((view->fmg.x != mg_x) || (view->fmg.y != mg_y))
+	    && (view->active_camera > -1)) {
+	    fisheye_spherical(mg_x, mg_y, 0.00, view->Topview);
 
 
-		if(!fisheyesphere)
-			fisheyesphere=gluNewQuadric();
-		gluQuadricDrawStyle ( fisheyesphere, GLU_LINE );
-		glColor4f((GLfloat) 0.3, (GLfloat) 0.1, (GLfloat) 0.8,(GLfloat)0.05);
-		glTranslatef(mg_x,mg_y,0);
-		gluSphere(fisheyesphere,a,30,30);
-		glTranslatef(-mg_x,-mg_y,0);
+	    if (!fisheyesphere)
+		fisheyesphere = gluNewQuadric();
+	    gluQuadricDrawStyle(fisheyesphere, GLU_LINE);
+	    glColor4f((GLfloat) 0.3, (GLfloat) 0.1, (GLfloat) 0.8,
+		      (GLfloat) 0.05);
+	    glTranslatef(mg_x, mg_y, 0);
+	    gluSphere(fisheyesphere, a, 30, 30);
+	    glTranslatef(-mg_x, -mg_y, 0);
 	}
 
 
@@ -622,33 +588,34 @@ void draw_fisheye_magnifier(ViewInfo * view)
 void drawBorders(ViewInfo * view)
 {
     if (view->bdVisible) {
-		glColor4f(view->borderColor.R,view->borderColor.B,view->borderColor.G,view->borderColor.A);
+	glColor4f(view->borderColor.R, view->borderColor.B,
+		  view->borderColor.G, view->borderColor.A);
 	glLineWidth(2);
 	glBegin(GL_LINE_STRIP);
-	glVertex2d(view->bdxLeft, view->bdyBottom);
-	glVertex2d(view->bdxRight, view->bdyBottom);
-	glVertex2d(view->bdxRight, view->bdyTop);
-	glVertex2d(view->bdxLeft, view->bdyTop);
-	glVertex2d(view->bdxLeft, view->bdyBottom);
+	glVertex3d(view->bdxLeft, view->bdyBottom,-0.001);
+	glVertex3d(view->bdxRight, view->bdyBottom,-0.001);
+	glVertex3d(view->bdxRight, view->bdyTop,-0.001);
+	glVertex3d(view->bdxLeft, view->bdyTop,-0.001);
+	glVertex3d(view->bdxLeft, view->bdyBottom,-0.001);
 	glEnd();
 	glLineWidth(1);
     }
 }
 
-static void drawXdot(xdot * xDot, int param, void *p)
+/*static void drawXdot(xdot * xDot, int param, void *p)
 {
     int id;
     sdot_op *ops = (sdot_op *) (xDot->ops);
     sdot_op *op;
 	//to avoid the overlapping , z is slightly increased for each xdot of a particular object
 	if (AGTYPE(p)==AGEDGE)
-		globalz=1;	
+		view->Topview->global_z=1;	
 	else
-		globalz=0;	
+		view->Topview->global_z=0;	
 
 	for (id = 0; id < xDot->cnt; id++)
 	{
-		globalz +=  (float)GLOBAL_Z_OFFSET;
+		view->Topview->global_z +=  (float)GLOBAL_Z_OFFSET;
 		op = ops + id;
 		op->obj = p;
 		op->op.drawfunc(&(op->op), param);
@@ -656,33 +623,34 @@ static void drawXdot(xdot * xDot, int param, void *p)
     if (OD_Preselected(p) == 1)
 		select_object(view->g[view->activeGraph], p);
     OD_Preselected(p) = 0;
-}
-
+}*/
 
 
+#ifdef UNUSED
 static void drawXdotwithattr(void *p, char *attr, int param)
 {
-    xdot *xDot;
+/*    xdot *xDot;
     if ((xDot = parseXDotF(agget(p, attr), OpFns, sizeof(sdot_op))))
 	{
 		drawXdot(xDot, param, p);
 		freeXDot(xDot);
-    }
+    }*/
 }
 
 static void drawXdotwithattrs(void *e, int param)
 {
-    drawXdotwithattr(e, "_draw_", param);
-    drawXdotwithattr(e, "_ldraw_", param);
-    drawXdotwithattr(e, "_hdraw_", param);
-    drawXdotwithattr(e, "_tdraw_", param);
-    drawXdotwithattr(e, "_hldraw_", param);
-    drawXdotwithattr(e, "_tldraw_", param);
+    /*   drawXdotwithattr(e, "_draw_", param);
+       drawXdotwithattr(e, "_ldraw_", param);
+       drawXdotwithattr(e, "_hdraw_", param);
+       drawXdotwithattr(e, "_tdraw_", param);
+       drawXdotwithattr(e, "_hldraw_", param);
+       drawXdotwithattr(e, "_tldraw_", param); */
 }
+#endif
 
 
 
-void drawGraph(Agraph_t * g)
+/*void drawGraph(Agraph_t * g)
 {
     Agnode_t *v;
     Agedge_t *e;
@@ -726,7 +694,7 @@ void drawGraph(Agraph_t * g)
 		view->SignalBlock = 0;
     }
 
-}
+}*/
 
 
 /*
@@ -739,14 +707,12 @@ static void scanXdot(xdot * xDot, void *p)
     sdot_op *ops = (sdot_op *) (xDot->ops);
     sdot_op *op;
 
-    for (id = 0; id < xDot->cnt; id++)
-	{
-		op = ops + id;
-		op->obj = p;
-		if (op->op.kind==xd_font)
-		{
-			add_font(view->fontset,op->op.u.font.name);//load or set active font
-		}
+    for (id = 0; id < xDot->cnt; id++) {
+	op = ops + id;
+	op->obj = p;
+/*	if (op->op->kind == xd_font) {
+//                      add_font(view->widgets->fontset,op->op.u.font.name,op->op.u.font.size);//load or set active font
+	}*/
     }
 
 }
@@ -755,10 +721,9 @@ static void scanXdot(xdot * xDot, void *p)
 static void scanXdotwithattr(void *p, char *attr)
 {
     xdot *xDot;
-    if ((xDot = parseXDotF(agget(p, attr), OpFns, sizeof(sdot_op))))
-	{
-		scanXdot(xDot, p);
-		freeXDot(xDot);
+    if ((xDot = parseXDotF(agget(p, attr), OpFns, sizeof(sdot_op)))) {
+	scanXdot(xDot, p);
+	freeXDot(xDot);
     }
 }
 
@@ -783,18 +748,16 @@ void scanGraph(Agraph_t * g)
 {
     Agnode_t *v;
     Agedge_t *e;
-    for (v = agfstnode(g); v; v = agnxtnode(g, v)) 
-	{
-		scanXdotwithattr(v, "_draw_"); 
-		scanXdotwithattr(v, "_ldraw_");
-		for (e = agfstout(g, v); e; e = agnxtout(g, e)) 
-		{
-	      scanXdotwithattrs(e);
-		}
+    for (v = agfstnode(g); v; v = agnxtnode(g, v)) {
+	scanXdotwithattr(v, "_draw_");
+	scanXdotwithattr(v, "_ldraw_");
+	for (e = agfstout(g, v); e; e = agnxtout(g, e)) {
+	    scanXdotwithattrs(e);
+	}
     }
 
 }
-int randomize_color(RGBColor * c, int brightness)
+int randomize_color(glCompColor * c, int brightness)
 {
     float R, B, G;
     float add;
@@ -822,31 +785,30 @@ void drawCircle(float x, float y, float radius, float zdepth)
 	float degInRad = (float) (i * DEG2RAD);
 	glVertex3f((GLfloat) (x + cos(degInRad) * radius),
 		   (GLfloat) (y + sin(degInRad) * radius),
-		   (GLfloat) zdepth+globalz);
+		   (GLfloat) zdepth + view->Topview->global_z);
     }
 
     glEnd();
 }
 
 drawfunc_t OpFns[] = {
-    DrawEllipse,
-    DrawPolygon,
-    DrawBeziers,
-    DrawPolyline,
-    EmbedText,
-    SetFillColor,
-    SetPenColor,
-    SetFont,
-    SetStyle,
-    InsertImage,
+    (drawfunc_t)DrawEllipse,
+    (drawfunc_t)DrawPolygon,
+    (drawfunc_t)DrawBeziers,
+    (drawfunc_t)DrawPolyline,
+    (drawfunc_t)EmbedText,
+    (drawfunc_t)SetFillColor,
+    (drawfunc_t)SetPenColor,
+    (drawfunc_t)SetFont,
+    (drawfunc_t)SetStyle,
+    (drawfunc_t)InsertImage,
 };
 
-RGBColor GetRGBColor(char *color)
+glCompColor GetglCompColor(char *color)
 {
     gvcolor_t cl;
-    RGBColor c;
+    glCompColor c;
     if (color != '\0') {
-
 	colorxlate(color, &cl, RGBA_DOUBLE);
 	c.R = (float) cl.u.RGBA[0];
 	c.G = (float) cl.u.RGBA[1];
@@ -860,103 +822,128 @@ RGBColor GetRGBColor(char *color)
     }
     return c;
 }
-void drawEllipse(float xradius, float yradius,int angle1,int angle2)
+void drawEllipse(float xradius, float yradius, int angle1, int angle2)
 {
-	int i;
-	glBegin(GL_LINE_STRIP);
+    int i;
+    glBegin(GL_LINE_STRIP);
 
-   for (i=angle1; i<=angle2; i++)
-   {
-      //convert degrees into radians
-      float degInRad = (float)i*(float)DEG2RAD;
-      glVertex3f((GLfloat)(cos(degInRad)*xradius),(GLfloat)(sin(degInRad)*yradius),globalz);
-   }
- 
-   glEnd();
+    for (i = angle1; i <= angle2; i++) {
+	//convert degrees into radians
+	float degInRad = (float) i * (float) DEG2RAD;
+	glVertex3f((GLfloat) (cos(degInRad) * xradius),
+		   (GLfloat) (sin(degInRad) * yradius), view->Topview->global_z);
+    }
+
+    glEnd();
 }
-int draw_node_hintbox_gl_polygon(GLfloat x,GLfloat y,GLfloat z,GLfloat fs,char* text)
-
+int draw_node_hintbox_gl_polygon(GLfloat x, GLfloat y, GLfloat z,
+				 GLfloat fs, char *text)
 {
 
 
-	GLfloat X,Y,Z,pad;
-	pad=fs/(GLfloat)5.0;
-	X=x;Y=y;Z=z+(GLfloat)0.0005;
-	glBegin(GL_POLYGON);
-	glVertex3f(X,Y,Z);
-	Y=Y + fs;
-	glVertex3f(X,Y,Z);
-	X=X+fs;
-	glVertex3f(X,Y,Z);
-	X=x;y=y;
-	glVertex3f(X,Y,Z);
-	glEnd();
+    GLfloat X, Y, Z, pad;
+    pad = fs / (GLfloat) 5.0;
+    X = x;
+    Y = y;
+    Z = z + (GLfloat) 0.0005;
+    glBegin(GL_POLYGON);
+    glVertex3f(X, Y, Z);
+    Y = Y + fs;
+    glVertex3f(X, Y, Z);
+    X = X + fs;
+    glVertex3f(X, Y, Z);
+    X = x;
+    y = y;
+    glVertex3f(X, Y, Z);
+    glEnd();
 
-	X=x;Y=y+fs;
-	glBegin(GL_POLYGON);
-	glVertex3f(X,Y,Z);
-	X=x;Y=Y+fs+2*pad;
-	glVertex3f(X,Y,Z);
-	X=x+strlen(text)*fs/(GLfloat)2.0+(GLfloat)2.0*pad;
-	glVertex3f(X,Y,Z);
-	Y=y+fs;
-	glVertex3f(X,Y,Z);
-	X=x;
-	glVertex3f(X,Y,Z);
-	glEnd();
+    X = x;
+    Y = y + fs;
+    glBegin(GL_POLYGON);
+    glVertex3f(X, Y, Z);
+    X = x;
+    Y = Y + fs + 2 * pad;
+    glVertex3f(X, Y, Z);
+    X = x + strlen(text) * fs / (GLfloat) 2.0 + (GLfloat) 2.0 *pad;
+    glVertex3f(X, Y, Z);
+    Y = y + fs;
+    glVertex3f(X, Y, Z);
+    X = x;
+    glVertex3f(X, Y, Z);
+    glEnd();
 
 
-	return 1;
+    return 1;
 
 }
-int draw_node_hintbox_gl_line(GLfloat x,GLfloat y,GLfloat z,GLfloat fs,char* text)
+int draw_node_hintbox_gl_line(GLfloat x, GLfloat y, GLfloat z, GLfloat fs,
+			      char *text)
 {
 
 
-	GLfloat X,Y,Z,pad;
-	pad=fs/(GLfloat)5.0;
-	X=x;Y=y;Z=z+(GLfloat)0.001;
-	glBegin(GL_LINE_STRIP);
-	glVertex3f(X,Y,Z);
-	Y=Y + 2*fs+2*pad;
-	glVertex3f(X,Y,Z);
-	X=X+2*pad+strlen(text)*fs/(GLfloat)2.0;
-	glVertex3f(X,Y,Z);
-	Y=y+fs;
-	glVertex3f(X,Y,Z);
-	X=x+fs;
-	glVertex3f(X,Y,Z);
-	X=x;Y=y;
-	glVertex3f(X,Y,Z);
-	glEnd();
+    GLfloat X, Y, Z, pad;
+    pad = fs / (GLfloat) 5.0;
+    X = x;
+    Y = y;
+    Z = z + (GLfloat) 0.001;
+    glBegin(GL_LINE_STRIP);
+    glVertex3f(X, Y, Z);
+    Y = Y + 2 * fs + 2 * pad;
+    glVertex3f(X, Y, Z);
+    X = X + 2 * pad + strlen(text) * fs / (GLfloat) 2.0;
+    glVertex3f(X, Y, Z);
+    Y = y + fs;
+    glVertex3f(X, Y, Z);
+    X = x + fs;
+    glVertex3f(X, Y, Z);
+    X = x;
+    Y = y;
+    glVertex3f(X, Y, Z);
+    glEnd();
 
 
 
-	return 1;
+    return 1;
 
 }
 
 
-int draw_node_hintbox(GLfloat x,GLfloat y,GLfloat z,GLfloat fs,char* text)
+int draw_node_hintbox(GLfloat x, GLfloat y, GLfloat z, GLfloat fs,
+		      char *text)
 {
-	
-	glColor3f(1,1,0);
-		draw_node_hintbox_gl_polygon(x,y,z,fs,text);
-	glColor3f(0,0,1);
-		draw_node_hintbox_gl_line(x,y,z,fs,text);
-	return 1;
+
+
+    glColor3f(1, 1, 0);
+    draw_node_hintbox_gl_polygon(x, y, z, fs, text);
+    glColor3f(0, 0, 1);
+    draw_node_hintbox_gl_line(x, y, z, fs, text);
+    return 1;
 
 }
 
-static GLUquadric* sphere;
-void draw_sphere(float x,float y,float z,float r)
+static GLUquadric *sphere;
+void draw_sphere(float x, float y, float z, float r)
 {
-	if(!sphere)
-			fisheyesphere=gluNewQuadric();
-	gluQuadricDrawStyle ( fisheyesphere, GLU_FILL );
-	glTranslatef(x,y,z);
-	gluSphere(fisheyesphere,r,SPHERE_SLICE_COUNT,SPHERE_SLICE_COUNT);
-	glTranslatef(-x,-y,-z);
+    if (!sphere)
+	fisheyesphere = gluNewQuadric();
+    gluQuadricDrawStyle(fisheyesphere, GLU_FILL);
+    glTranslatef(x, y, z);
+    gluSphere(fisheyesphere, r, SPHERE_SLICE_COUNT, SPHERE_SLICE_COUNT);
+    glTranslatef(-x, -y, -z);
 }
 
-
+#ifdef UNUSED
+void draw_xdot_set(xdot_set * s)
+{
+    int ind = 0;
+    int ind2 = 0;
+    for (ind = 0; ind < s->cnt; ind++) {
+	for (ind2 = 0; ind2 < s->xdots[ind]->cnt; ind2++) {
+	    xdot_op *op;
+	    op = &s->xdots[ind]->ops[ind2];
+	    if (op->drawfunc)
+		op->drawfunc(op, 0);
+	}
+    }
+}
+#endif
