@@ -1,4 +1,4 @@
-/* $Id: filter.h,v 1.2 2008/03/19 21:43:58 erg Exp $ $Revision: 1.2 $ */
+/* $Id: filter.h,v 1.5 2009/10/09 18:28:17 erg Exp $ $Revision: 1.5 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -18,16 +18,23 @@
 #define FILTER_H
 #include "btree.h"
 
-typedef struct _tv_filters {
-    tv_filter **filters;
-    int filter_count;
-} tv_filters;
+#ifdef __cplusplus
+extern "C" {
+#endif
 
-int clear_filter(tv_filter * f);
-int init_filters(tv_filters * filters);
-int add_filter_to_filters(tv_filters * filters, tv_filter * filter);
-int clear_filters(tv_filters * filters);
-int union_filter(tv_filter * f1, tv_filter * f2);
-int intersect_filter(tv_filter * f1, tv_filter * f2);
+    typedef struct _tv_filters {
+	tv_filter **filters;
+	int filter_count;
+    } tv_filters;
 
+    int clear_filter(tv_filter * f);
+    int init_filters(tv_filters * filters);
+    int add_filter_to_filters(tv_filters * filters, tv_filter * filter);
+    int clear_filters(tv_filters * filters);
+    int union_filter(tv_filter * f1, tv_filter * f2);
+    int intersect_filter(tv_filter * f1, tv_filter * f2);
+
+#ifdef __cplusplus
+}				/* end extern "C" */
+#endif
 #endif
