@@ -1,3 +1,4 @@
+/* $Id: glexpose.h,v 1.7 2009/10/09 18:28:17 erg Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -17,12 +18,20 @@
 #define GLEXPOSE_H
 
 #include "viewport.h"
-int glupdatecamera(ViewInfo * v);
-int glexpose_main(ViewInfo * v);
-void glexpose_grid(ViewInfo * v);
-int glexpose_drawgraph(ViewInfo * view);
-void drawRotatingTools(void);
-void drawtestpoly(void);
-
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+    int glupdatecamera(ViewInfo * v);
+    int glexpose_main(ViewInfo * v);
+    void glexpose_grid(ViewInfo * v);
+    int glexpose_drawgraph(ViewInfo * view);
+    void drawRotatingTools(void);
+    void drawtestpoly(void);
+    void draw_cube(void);
+
+#ifdef __cplusplus
+}				/* end extern "C" */
+#endif
 #endif
