@@ -1,4 +1,4 @@
-/* $Id: gltemplate.c,v 1.41 2009/03/10 22:58:49 arif Exp $ $Revision: 1.41 $ */
+/* $Id: gltemplate.c,v 1.74 2009/12/03 19:16:04 arif Exp $ $Revision: 1.74 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -17,23 +17,42 @@
 #include <stdlib.h>
 #include <math.h>
 #include "gui.h"
+#include "beacon.h"
 #include "viewport.h"
 #include "topview.h"
-#include "topfisheyeview.h"
 #include "gltemplate.h"
 #include "glutils.h"
 #include "glexpose.h"
 #include "glmotion.h"
-#include "glmenu.h"
 #include "selection.h"
 #include "glcompset.h"
 #include "viewportcamera.h"
 #include "gui/menucallbacks.h"
+#include "arcball.h"
+#include "appmouse.h"
 static float begin_x = 0.0;
 static float begin_y = 0.0;
 static float dx = 0.0;
 static float dy = 0.0;
 
+/*mouse mode mapping funvtion from gtk to glcomp*/
+static glMouseButtonType getGlCompMouseType(int n)
+{
+    switch (n) {
+    case 1:
+	return glMouseLeftButton;
+    case 2:
+	return glMouseMiddleButton;
+    case 3:
+	return glMouseRightButton;
+
+    default:
+	return glMouseLeftButton;
+    }
+}
+
+
+
 /*
 	test opengl parameters, configuration.Run this function to see machine's open gl capabilities
 	params:gtk gl config class ,gtk takes care of all these tests
@@ -130,22 +149,17 @@ static void realize(GtkWidget * widget, gpointer data)
     GLfloat lmodel_ambient[] = { 0.2f, 0.2f, 0.2f, 1.0f };
     GLfloat local_view[] = { 0.0 };
 
-    static char *smyrna_font;
+    /* static char *smyrna_font; */
 
-#ifdef WIN32
-    smyrna_font = "c:/pango_font.tga";
-#else
-    smyrna_font = smyrnaPath("arial.tga");
-#endif
-//    g_print("loading font....%i\n", fontLoad(smyrna_font));
 
-	add_font(view->fontset,"Times 14");//wired in default font
 	/*** OpenGL BEGIN ***/
     if (!gdk_gl_drawable_gl_begin(gldrawable, glcontext))
 	return;
 
     glClearColor(view->bgColor.R, view->bgColor.G, view->bgColor.B, view->bgColor.A);	//background color
     glClearDepth(1.0);
+    glClear(GL_COLOR_BUFFER_BIT);
+
 
     glLightfv(GL_LIGHT0, GL_AMBIENT, ambient);
     glLightfv(GL_LIGHT0, GL_DIFFUSE, diffuse);
@@ -158,13 +172,14 @@ static void realize(GtkWidget * widget, gpointer data)
 // glEnable (GL_LIGHT0);
 //  glEnable (GL_AUTO_NORMAL);
 //  glEnable (GL_NORMALIZE);
-    glEnable(GL_DEPTH_TEST);
     glEnable(GL_BLEND);
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
     glDepthFunc(GL_LESS);
 //  glEnable(GL_LINE_SMOOTH);
 
     gdk_gl_drawable_gl_end(gldrawable);
+
+
   /*** OpenGL END ***/
     return;
 }
@@ -177,13 +192,17 @@ static void realize(GtkWidget * widget, gpointer data)
 static gboolean configure_event(GtkWidget * widget,
 				GdkEventConfigure * event, gpointer data)
 {
-	/* static int doonce=0; */
-	int vPort[4];
+    /* static int doonce=0; */
+    int vPort[4];
     float aspect;
     GdkGLContext *glcontext = gtk_widget_get_gl_context(widget);
     GdkGLDrawable *gldrawable = gtk_widget_get_gl_drawable(widget);
     view->w = widget->allocation.width;
     view->h = widget->allocation.height;
+    if (view->widgets)
+	glcompsetUpdateBorder(view->widgets, view->w, view->h);
+
+
 	/*** OpenGL BEGIN ***/
     if (!gdk_gl_drawable_gl_begin(gldrawable, glcontext))
 	return FALSE;
@@ -193,6 +212,9 @@ static gboolean configure_event(GtkWidget * widget,
     /* setup various opengl things that we need */
     glMatrixMode(GL_PROJECTION);
     glLoadIdentity();
+    if (widget->allocation.width > 1)
+	init_arcBall(view->arcball, (GLfloat) view->w, (GLfloat) view->h);
+
     if (view->w > view->h) {
 	aspect = (float) view->w / (float) view->h;
 	glOrtho(-aspect * GL_VIEWPORT_FACTOR, aspect * GL_VIEWPORT_FACTOR,
@@ -207,6 +229,8 @@ static gboolean configure_event(GtkWidget * widget,
     glMatrixMode(GL_MODELVIEW);
     gdk_gl_drawable_gl_end(gldrawable);
 	/*** OpenGL END ***/
+
+
     return TRUE;
 }
 
@@ -220,6 +244,7 @@ gboolean expose_event(GtkWidget * widget, GdkEventExpose * event,
 {
     GdkGLContext *glcontext = gtk_widget_get_gl_context(widget);
     GdkGLDrawable *gldrawable = gtk_widget_get_gl_drawable(widget);
+
 	/*** OpenGL BEGIN ***/
     if (!gdk_gl_drawable_gl_begin(gldrawable, glcontext))
 	return FALSE;
@@ -233,24 +258,15 @@ gboolean expose_event(GtkWidget * widget, GdkEventExpose * event,
 	glFlush();
     gdk_gl_drawable_gl_end(gldrawable);
   /*** OpenGL END ***/
+    if (view->initFile) {
+	view->initFile = 0;
+	if (view->activeGraph == 0)
+	    close_graph(view, 0);
+	add_graph_to_viewport_from_file(view->initFileName);
+    }
     return TRUE;
 }
 
-static gboolean key_release_event(GtkWidget * widget,
-				     GdkEventButton * event, gpointer data)
-{
-	printf ("a key is released\n");
-
-}
-
-static gboolean key_press_event(GtkWidget * widget, GdkEventKey * event,
-				gpointer data)
-{
-	printf ("a key is pressed\n");
-
-}
-
-
 /*
 	when a mouse button is clicked this function is called
 	params:gtk opgn gl canvas , GdkEventButton object and custom data
@@ -259,43 +275,21 @@ static gboolean key_press_event(GtkWidget * widget, GdkEventKey * event,
 static gboolean button_press_event(GtkWidget * widget,
 				   GdkEventButton * event, gpointer data)
 {
-    if (view->graphCount)
-	{
-		if (glCompSetClick(view->Topview->topviewmenu, (int) event->x, (int) event->y))
-	    expose_event(view->drawing_area, NULL, NULL);
-    }
+    Agraph_t* g=view->g[view->activeGraph];
 
     begin_x = (float) event->x;
     begin_y = (float) event->y;
-	//update mouse coordinates of view if there is left or right click
-	if ((event->button == 1) || (event->button == 3))
-	{
-		GetOGLPosRef    ((int) begin_x, (int) begin_y, &(view->GLx), &(view->GLy),&(view->GLz));
-			view->Selection.X = view->GLx;
-			view->Selection.Y = view->GLy;
-
-	}
-	
-	if (event->button == 3)	//right click
-	{
-		view->mouse.button = rightmousebutton;
-				expose_event(view->drawing_area, NULL, NULL);
-
-	}
+    view->widgets->common.functions.mousedown((glCompObj*)view->widgets,(GLfloat) event->x,(GLfloat) event->y,getGlCompMouseType(event->button));
     if (event->button == 1)	//left click
-    {
-		view->prevpanx = view->panx;
-		view->prevpany = view->pany;
-		view->mouse.mouse_down = 1;
-		view->mouse.button = leftmousebutton;
-		if (view->mouse.mouse_mode == MM_SINGLE_SELECT)	//single select
-		{
-			view->Selection.Active = 1;
-			view->Selection.Type = 0;
-			view->Selection.AlreadySelected = 0;
-			expose_event(view->drawing_area, NULL, NULL);
-		}
-    }
+	appmouse_left_click_down(view,(int) event->x,(int) event->y);
+
+    if (event->button == 3)	//right click
+	appmouse_right_click_down(view,(int) event->x,(int) event->y);
+    if (event->button == 2)	//middle click
+	appmouse_middle_click_down(view,(int) event->x,(int) event->y);
+
+    expose_event(view->drawing_area, NULL, NULL);
+
     return FALSE;
 }
 
@@ -307,76 +301,64 @@ static gboolean button_press_event(GtkWidget * widget,
 static gboolean button_release_event(GtkWidget * widget,
 				     GdkEventButton * event, gpointer data)
 {
-	view->FontSizeConst=GetOGLDistance(14);
+    view->FontSizeConst = GetOGLDistance(14);
+    view->arcball->isDragging = 0;
+    view->widgets->common.functions.mouseup((glCompObj*)view->widgets,(GLfloat) event->x,(GLfloat) event->y,getGlCompMouseType(event->button));
 
-	if (event->button == 1)	//left click release
-    {
-		if (glCompSetRelease
-	    (view->Topview->topviewmenu, (int) event->x_root,
-	     (int) event->y_root))		{
-			 expose_event(view->drawing_area, NULL, NULL);	}
-	view->mouse.mouse_down = 0;
-	if ((view->mouse.mouse_mode == MM_RECTANGULAR_SELECT)
-	    || (view->mouse.mouse_mode == MM_RECTANGULAR_X_SELECT)) {
-	    if (view->GLx <= view->GLx2)
-		view->Selection.X = view->GLx;
-	    else
-		view->Selection.X = view->GLx2;
-	    if (view->GLy <= view->GLy2)
-		view->Selection.Y = view->GLy;
-	    else
-		view->Selection.Y = view->GLy2;
-	    view->Selection.W = view->GLx2 - view->GLx;
-	    if (view->Selection.W < 0)
-		view->Selection.W = view->Selection.W * -1;
-	    view->Selection.H = view->GLy2 - view->GLy;
-	    if (view->Selection.H < 0)
-		view->Selection.H = view->Selection.H * -1;
-	    if (view->mouse.mouse_mode == 4)
-		view->Selection.Type = 1;
-	    else
-		view->Selection.Type = 2;
-	    view->Selection.Active = 1;
-	    expose_event(view->drawing_area, NULL, NULL);
-	}
 
-	if (view->mouse.mouse_mode == MM_MOVE) {
-	    if (GD_TopView(view->g[view->activeGraph]) == 0)
-		move_nodes(view->g[view->activeGraph]);
-	    else
-		move_TVnodes();
-	}
-
-	if ((view->mouse.mouse_mode == MM_FISHEYE_MAGNIFIER) || (view->mouse.mouse_mode == MM_MAGNIFIER))	//fisheye mag mouse release, stop distortion
-	{
-	    originate_distorded_coordinates(view->Topview);
-	    expose_event(view->drawing_area, NULL, NULL);
-	}
-	if (view->mouse.mouse_mode==MM_PAN)
-		{
-			expose_event(view->drawing_area, NULL, NULL);
-
-		}
-
-	}
+    if (event->button == 1)	//left click release
+	appmouse_left_click_up(view,(int) event->x,(int) event->y);
     if (event->button == 3)	//right click
-	{
-
-		if ((view->activeGraph >= 0) && (GD_TopView(view->g[view->activeGraph])))
-		{
-			if(view->Topview->is_top_fisheye)
-			{
-				GetFixedOGLPoslocal((int) event->x, (int) event->y,view->GLDepth, &(view->GLx2),&(view->GLy2), &(view->GLz2));
-				changetopfishfocus(view->Topview, &view->GLx2, &view->GLy2, 0,1);
-				expose_event(view->drawing_area, NULL, NULL);
-			}
-		}
-	}
+	appmouse_right_click_up(view,(int) event->x,(int) event->y);
+    if (event->button == 2)	//right click
+	appmouse_middle_click_up(view,(int) event->x,(int) event->y);
 
+    expose_event(view->drawing_area, NULL, NULL);
     dx = 0.0;
     dy = 0.0;
+
     return FALSE;
 }
+static gboolean key_press_event(GtkWidget * widget, GdkEventKey * event, gpointer data)
+{
+    view->keymap.down=1;
+    view->keymap.keyVal=event->keyval;
+        return FALSE;
+
+
+
+}
+static gboolean key_release_event(GtkWidget * widget, GdkEventKey * event, gpointer data)
+{
+ //   printf ("key is released:%d\n",event->keyval);
+    view->keymap.down=0;
+    view->keymap.keyVal=0;
+    originate_distorded_coordinates(view->Topview);
+        return FALSE;
+
+
+}
+
+
+static gboolean
+scroll_event(GtkWidget * widget, GdkEventScroll * event, gpointer data)
+{
+    gdouble seconds;
+
+    seconds = g_timer_elapsed(view->timer2, NULL);
+    if (seconds > 0.005) {
+	g_timer_stop(view->timer2);
+	if (event->direction == 0)
+	    view->mouse.dragX = -30;
+	if (event->direction == 1)
+	    view->mouse.dragX = +30;
+	glmotion_zoom(view);
+	glexpose();
+	g_timer_start(view->timer2);
+
+    }
+    return TRUE;
+}
 
 /*
 	when  mouse is moved over glcanvas this function is called
@@ -386,73 +368,43 @@ static gboolean button_release_event(GtkWidget * widget,
 static gboolean motion_notify_event(GtkWidget * widget,
 				    GdkEventMotion * event, gpointer data)
 {
-    /* float w = (float)widget->allocation.width; */
-    /* float h = (float)widget->allocation.height; */
     float x = (float) event->x;
     float y = (float) event->y;
 
-
     gboolean redraw = FALSE;
+    if (view->widgets)
+	view->widgets->common.functions.mouseover((glCompObj*)view->widgets, (GLfloat) x,(GLfloat) y);
+
     dx = x - begin_x;
     dy = y - begin_y;
+    view->mouse.dragX = dx;
+    view->mouse.dragY = dy;
+    if((view->mouse.t==glMouseLeftButton) && (view->mouse.down)  )
+    {
+	appmouse_left_drag(view,(int)event->x,(int)event->y);
+	redraw = TRUE;
 
-    view->mouse.dx = dx;
-    view->mouse.dy = dy;
-
-	view->mouse.mouse_X = x;
-	view->mouse.mouse_Y = y;
-
-	/*panning */
-    if ((event->state & GDK_BUTTON1_MASK)
-	&& (view->mouse.mouse_mode == MM_PAN)) {
-	if (glmotion_main(view, event, widget))
-	    redraw = TRUE;
     }
-    /*rotating, only in 3d view */
-    if ((view->active_camera >= 0) && (view->mouse.mouse_mode == MM_ROTATE)
-	&& (event->state & GDK_BUTTON1_MASK)) {
-	if (glmotion_main(view, event, widget))
-	    redraw = TRUE;
-    }
-    /*zooming */
-    if ((event->state & GDK_BUTTON1_MASK)
-	&& (view->mouse.mouse_mode == MM_ZOOM))
-	{
-
-		if (glmotion_main(view, event, widget))
-		    redraw = TRUE;
-	}
-
-    /*selection rect */
-    if ((event->state & GDK_BUTTON1_MASK)
-	&& ((view->mouse.mouse_mode == MM_RECTANGULAR_SELECT)
-	    || (view->mouse.mouse_mode == 5))) {
-	GetFixedOGLPos((int) x, (int) y, view->GLDepth, &(view->GLx2),
-		       &(view->GLy2), &(view->GLz2));
+    if((view->mouse.t==glMouseRightButton) && (view->mouse.down))
+    {
+	appmouse_right_drag(view,(int)event->x,(int)event->y);
 	redraw = TRUE;
     }
-    if ((event->state & GDK_BUTTON1_MASK)
-	&& (view->mouse.mouse_mode == MM_MOVE)) {
-	GetFixedOGLPos((int) x, (int) y, view->GLDepth, &(view->GLx2),
-		       &(view->GLy2), &(view->GLz2));
-	redraw = TRUE;
-    }
-    if ((event->state & GDK_BUTTON1_MASK)
-	&& ((view->mouse.mouse_mode == MM_MAGNIFIER)
-	    || (view->mouse.mouse_mode == MM_FISHEYE_MAGNIFIER))) {
-	view->mouse.mouse_X = x;
-	view->mouse.mouse_Y = y;
+    if((view->mouse.t==glMouseMiddleButton) && (view->mouse.down))
+    {
+	appmouse_middle_drag(view,(int)event->x,(int)event->y);
 	redraw = TRUE;
     }
 
 
+
+
     begin_x = x;
     begin_y = y;
 
 
     if (redraw)
-	gdk_window_invalidate_rect(widget->window, &widget->allocation,
-				   FALSE);
+	gdk_window_invalidate_rect(widget->window, &widget->allocation,FALSE);
     return TRUE;
 }
 
@@ -476,53 +428,13 @@ static gboolean key_press_event(GtkWidget * widget, GdkEventKey * event,
 }
 #endif
 
-/*
-	call back for mouse mode changes,
-	params:GtkMenuItem is not used, mouse_mode is the new mouse_mode
-	return value:none
-*/
-void switch_Mouse(GtkMenuItem * menuitem, int mouse_mode)
-{
-	switch (mouse_mode)
-	{
-
-	case -1:
-		change_cursor(GDK_TOP_LEFT_ARROW);
-		break;
-	case 0:
-		change_cursor(GDK_HAND2);
-		break;
-	case 1:
-		change_cursor(GDK_SIZING);
-		break;
-	case 3:
-		change_cursor(GDK_CROSS);
-		break;
-	case 4:
-		change_cursor(GDK_TCROSS);
-		break;
-	case 5:
-		change_cursor(GDK_CROSSHAIR);
-		break;
-	case 10:
-		change_cursor(GDK_FLEUR);
-		break;
-	case MM_ROTATE:
-		change_cursor(GDK_EXCHANGE);
-		break;
-	default:
-		break;
-	};
-	view->mouse.mouse_mode = mouse_mode;
-}
-
 
 /*
 	call back for mouse right click, this function activates the gtk right click pop up menu
 	params:widget to shop popup , event handler to check click type and custom data
 	return value:true or false, fails (false) if listed keys (in switch) are not pressed
 */
-#if 0
+#ifdef UNUSED
 static gboolean button_press_event_popup_menu(GtkWidget * widget,
 					      GdkEventButton * event,
 					      gpointer data)
@@ -581,7 +493,6 @@ void create_window(GdkGLConfig * glconfig, GtkWidget * vbox)
      */
 
     gdk_gl_query_version(&major, &minor);
-    g_print("\nOpenGL extension version - %d.%d\n", major, minor);
 
     /* Try double-buffered visual */
 
@@ -597,10 +508,10 @@ void create_window(GdkGLConfig * glconfig, GtkWidget * vbox)
     gtk_widget_add_events(view->drawing_area,
 //  GDK_BUTTON_MOTION_MASK      = 1 << 4,
 			  GDK_BUTTON_MOTION_MASK |
-			   GDK_POINTER_MOTION_MASK|
-			  GDK_BUTTON_PRESS_MASK |GDK_KEY_PRESS |
+			  GDK_POINTER_MOTION_MASK |
+			  GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS |
 			  GDK_BUTTON_RELEASE_MASK |
-			  GDK_VISIBILITY_NOTIFY_MASK);
+			  GDK_SCROLL | GDK_VISIBILITY_NOTIFY_MASK |  GDK_KEY_PRESS_MASK	| GDK_KEY_RELEASE_MASK	);
 
     g_signal_connect_after(G_OBJECT(view->drawing_area), "realize",
 			   G_CALLBACK(realize), NULL);
@@ -611,23 +522,43 @@ void create_window(GdkGLConfig * glconfig, GtkWidget * vbox)
 
     g_signal_connect(G_OBJECT(view->drawing_area), "button_press_event",
 		     G_CALLBACK(button_press_event), NULL);
-    g_signal_connect(G_OBJECT(view->drawing_area), "button_release_event",
-		     G_CALLBACK(button_release_event), NULL);
-    g_signal_connect(G_OBJECT(view->drawing_area), "key_release_event",
-		     G_CALLBACK(button_release_event), NULL);
-    g_signal_connect(G_OBJECT(view->drawing_area), "key_press_event",
-		     G_CALLBACK(button_release_event), NULL);
-	g_signal_connect(G_OBJECT(view->drawing_area), "motion_notify_event",
+/*    g_signal_connect(G_OBJECT(view->drawing_area), "2button_press_event",
+		     G_CALLBACK(button_press_event), NULL);*/
+
+    g_signal_connect(G_OBJECT(view->drawing_area), "button_release_event",G_CALLBACK(button_release_event), NULL);
+    g_signal_connect(G_OBJECT(view->drawing_area), "key_release_event", G_CALLBACK(key_release_event), NULL);
+    g_signal_connect(G_OBJECT(view->drawing_area), "key_press_event", G_CALLBACK(key_press_event), NULL);
+    g_signal_connect(G_OBJECT(view->drawing_area), "scroll_event",
+		     G_CALLBACK(scroll_event), NULL);
+
+    g_signal_connect(G_OBJECT(view->drawing_area), "motion_notify_event",
 		     G_CALLBACK(motion_notify_event), NULL);
 
 
+//gtk_accel_group_connect (GTK_ACCEL_GROUP (mainw->accel_group), GDK_Page_Up, GDK_CONTROL_MASK, 0, g_cclosure_new (G_CALLBACK (prevclip_callback),NULL,NULL));
+
+
     gtk_box_pack_start(GTK_BOX(vbox), view->drawing_area, TRUE, TRUE, 0);
 
     gtk_widget_show(view->drawing_area);
 
+
+
+    gtk_widget_add_events(glade_xml_get_widget(xml, "frmMain"),
+			  GDK_BUTTON_MOTION_MASK |
+			  GDK_POINTER_MOTION_MASK |
+			  GDK_BUTTON_PRESS_MASK | GDK_KEY_PRESS |
+			  GDK_BUTTON_RELEASE_MASK |
+			  GDK_SCROLL | GDK_VISIBILITY_NOTIFY_MASK |  GDK_KEY_PRESS_MASK	| GDK_KEY_RELEASE_MASK	);
+
+
+    g_signal_connect(G_OBJECT(glade_xml_get_widget(xml, "frmMain")), "key_release_event", G_CALLBACK(key_release_event), NULL);
+    g_signal_connect(G_OBJECT(glade_xml_get_widget(xml, "frmMain")), "key_press_event", G_CALLBACK(key_press_event), NULL);
+
+
     /* Popup menu. */
 
-#if 0
+#ifdef UNUSED
     menu = create_popup_menu(view->drawing_area);
 
     /* Signal handler */
