@@ -1,4 +1,4 @@
-/* $Id: gltemplate.h,v 1.3 2008/03/19 21:43:58 erg Exp $ $Revision: 1.3 $ */
+/* $Id: gltemplate.h,v 1.6 2009/10/09 18:28:17 erg Exp $ $Revision: 1.6 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -32,20 +32,28 @@
 #include <gtk/gtkgl.h>
 #include <gdk/gdkcursor.h>
 
-void examine_gl_config_attrib(GdkGLConfig * glconfig);
-void print_gl_config_attrib(GdkGLConfig * glconfig,
-			    const gchar * attrib_str, int attrib,
-			    gboolean is_boolean);
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+    void examine_gl_config_attrib(GdkGLConfig * glconfig);
+    void print_gl_config_attrib(GdkGLConfig * glconfig,
+				const gchar * attrib_str, int attrib,
+				gboolean is_boolean);
 /* static void realize (GtkWidget *widget,gpointer   data); */
 /* static gboolean configure_event (GtkWidget *widget,GdkEventConfigure *event, gpointer data); */
-gboolean expose_event(GtkWidget * widget, GdkEventExpose * event,
-		      gpointer data);
+    gboolean expose_event(GtkWidget * widget, GdkEventExpose * event,
+			  gpointer data);
 /* static gboolean button_press_event (GtkWidget *widget,GdkEventButton *event,gpointer data); */
 /* static gboolean button_release_event (GtkWidget *widget,GdkEventButton *event,gpointer data); */
 /* static gboolean motion_notify_event (GtkWidget *widget,GdkEventMotion *event,gpointer data); */
 /* static gboolean key_press_event (GtkWidget *widget, GdkEventKey *event,gpointer data); */
-void switch_Mouse(GtkMenuItem * menuitem, int mouse_mode);
+    void switch_Mouse(GtkMenuItem * menuitem, int mouse_mode);
 /* static gboolean button_press_event_popup_menu (GtkWidget *widget,GdkEventButton *event,gpointer data); */
-extern GdkGLConfig *configure_gl(void);
-void create_window(GdkGLConfig * glconfig, GtkWidget * vbox);
+    extern GdkGLConfig *configure_gl(void);
+    void create_window(GdkGLConfig * glconfig, GtkWidget * vbox);
+
+#ifdef __cplusplus
+}				/* end extern "C" */
+#endif
 #endif
