@@ -1,4 +1,4 @@
-/* $Id: datalistcallbacks.c,v 1.5 2008/04/23 18:14:00 arif Exp $ $Revision: 1.5 $ */
+/* $Id: datalistcallbacks.c,v 1.10 2009/11/13 21:05:54 arif Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -29,9 +29,8 @@ void btnTVFilter_clicked_cb(GtkWidget * widget, gpointer user_data)
 
 //      gtk_dialog_set_response_sensitive   (glade_xml_get_widget(xml, "dlgOpenGraph"),1,1);
 //      gtk_dialog_set_response_sensitive   (glade_xml_get_widget(xml, "dlgOpenGraph"),2,1);
-    respond =
-	gtk_dialog_run((GtkDialog *)
-		       glade_xml_get_widget(xml, "dlgTVFilter"));
+    respond = gtk_dialog_run((GtkDialog *)
+			     glade_xml_get_widget(xml, "dlgTVFilter"));
 //      respond=gtk_dialog_run (glade_xml_get_widget(xml, "dlgFilters"));
     gtk_widget_hide(glade_xml_get_widget(xml, "dlgTVFilter"));
     if (respond == 1)
@@ -82,6 +81,14 @@ void btnTVReverse_clicked_cb(GtkWidget * widget, gpointer user_data)
 void cgbTVSelect_toggled_cb(GtkWidget * widget, gpointer user_data)
 {
 }
+void cgbTVVisible_toggled_cb(GtkWidget * widget, gpointer user_data)
+{
+
+}
+void cgbTVHighlighted_toggled_cb(GtkWidget * widget, gpointer user_data)
+{
+
+}
 
 
 
@@ -144,16 +151,6 @@ void btnTVUnselectAll_clicked_cb(GtkWidget * widget, gpointer user_data)
     tv_unselect_all();
 }
 
-void btnTVHighlightAll_clicked_cb(GtkWidget * widget, gpointer user_data)
-{
-    tv_highligh_all();
-}
-
-void btnTVUnhighlightAll_clicked_cb(GtkWidget * widget, gpointer user_data)
-{
-    tv_unhighligh_all();
-}
-
 
 void btnTVShowAll_clicked_cb(GtkWidget * widget, gpointer user_data)
 {
@@ -164,7 +161,8 @@ void btnTVHideAll_clicked_cb(GtkWidget * widget, gpointer user_data)
 {
     tv_hide_all();
 }
+
 void btnTVSaveAs_clicked_cb(GtkWidget * widget, gpointer user_data)
 {
-	tv_save_as();
-}
\ No newline at end of file
+    tv_save_as();
+}
