@@ -1,4 +1,4 @@
-/* $Id: gvprpipe.h,v 1.5 2009/06/03 01:10:49 ellson Exp $Revision:*/
+/* $Id: gvprpipe.h,v 1.8 2009/11/18 22:05:48 arif Exp $Revision:*/
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -19,6 +19,13 @@
 
 #include "cgraph.h"
 
-extern int run_gvpr(Agraph_t* srcGraph, char* script);
+#ifdef __cplusplus
+extern "C" {
+#endif
+    extern int run_gvpr(Agraph_t * srcGraph, int argc, char *argv[]);
 
+
+#ifdef __cplusplus
+}				/* end extern "C" */
+#endif
 #endif
