@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.22 2008/12/03 20:09:51 north Exp $ $Revision: 1.22 $ */
+/* $Id: main.c,v 1.58 2009/12/09 23:45:26 erg Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -22,18 +22,23 @@
 #if defined(_WIN32) && !defined(__CYGWIN__)
 #define WIN32_LEAN_AND_MEAN 1
 #include <windows.h>
+#include <windowsx.h>
 #endif
 #include <gtk/gtk.h>
 #include <gtk/gtkgl.h>
 #include <glade/glade.h>
 #include "gui.h"
 #include "viewport.h"
+#include "support.h"
 #include "menucallbacks.h"
 #include "gltemplate.h"
 #include "memory.h"
+#include "gvprpipe.h"
+#include "frmobjectui.h"
 #ifdef ENABLE_NLS
 #include "libintl.h"
 #endif
+#include <assert.h>
 
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
@@ -46,24 +51,42 @@ gchar *package_prefix;
 gchar *package_data_dir;
 #endif
 gchar *package_locale_dir;
-static char* smyrnaDir;
-char* smyrnaGlade;
+static char *smyrnaDir;		/* path to directory containin smyrna data files */
+char *smyrnaGlade;
 unsigned char SmyrnaVerbose;
 
-char*
-smyrnaPath (char* suffix)
+
+/* smyrnaPath:
+ * Construct pathname for smyrna data file.
+ * Base file name is given as suffix.
+ * The function resolves the directory containing the data files,
+ * and constructs a complete pathname.
+ * The returned string is malloced, so the application should free
+ * it later.
+ * Returns NULL on error.
+ */
+char *smyrnaPath(char *suffix)
 {
-    char* buf;
-    if (!smyrnaDir) return NULL;
-    buf = N_NEW(strlen(smyrnaDir)+strlen(suffix)+2,char);
-    sprintf (buf, "%s/%s", smyrnaDir, suffix);
+    char *buf;
+    static int baselen;
+    int slen;
+#ifdef WIN32
+    char *pathSep = "\\";
+#else
+    char *pathSep = "/";
+#endif
+    assert(smyrnaDir);
+
+    if (baselen == 0) {
+	baselen = (int)strlen(smyrnaDir) + 2;
+    }
+    slen = (int)strlen(suffix);
+    buf = N_NEW(baselen+slen, char);
+    sprintf(buf, "%s%s%s", smyrnaDir, pathSep, suffix);
     return buf;
 }
 
-static char *useString = "Usage: smyrn [-txv?] [-K<engine>] <file>\n\
-  -n         - use TopView mode\n\
-  -e         - use XDOT mode\n\
-  -K<engine> - layout graph using <engine>\n\
+static char *useString = "Usage: smyrns [-v?] <file>\n\
   -v         - verbose\n\
   -?         - print usage\n";
 
@@ -74,8 +97,7 @@ static void usage(int v)
 }
 
 
-static char*
-parseArgs (int argc, char *argv[], ViewInfo* view)
+static char *parseArgs(int argc, char *argv[], ViewInfo * view)
 {
     unsigned int c;
 
@@ -84,45 +106,71 @@ parseArgs (int argc, char *argv[], ViewInfo* view)
 	case 'v':
 	    SmyrnaVerbose = 1;
 	    break;
+#if 0
 	case 't':
-	    view->dfltViewType = VT_TOPVIEW; 
+	    view->dfltViewType = VT_TOPVIEW;
 	    break;
 	case 'x':
-	    view->dfltViewType = VT_XDOT; 
+	    view->dfltViewType = VT_XDOT;
 	    break;
 	case 'K':
-	    view->dfltEngine = s2layout (optarg);
+	    view->dfltEngine = s2layout(optarg);
 	    break;
+#endif
 	case '?':
 	    if (optopt == '?')
 		usage(0);
 	    else
-		fprintf(stderr, "smyrna: option -%c unrecognized - ignored\n",
+		fprintf(stderr,
+			"smyrna: option -%c unrecognized - ignored\n",
 			optopt);
 	    break;
 	}
     }
 
     if (optind < argc)
-	 return argv[optind];
+	return argv[optind];
     else
 	return NULL;
 }
-extern int create_font_file(char* fontdescription,float gw,float gh);
-extern int load_png_font(char* file_name);
+
+#ifdef UNUSED
+static void close_cgraph(Agraph_t * g)
+{
+    Agnode_t *v;
+    for (v = agfstnode(g); v; v = agnxtnode(g, v)) {
+	agdelrec(v, "temp_node_record");
+    }
+    agclose(g);
+}
+
+#endif
 
 int main(int argc, char *argv[])
 {
     GdkGLConfig *glconfig;
-    char* initFileName;
+    char *initFileName;
+    /*combo box to show loaded graphs */
+    GtkComboBox *graphComboBox;
 
-    smyrnaDir = getenv ("SMYRNA_PATH");
-#ifndef _WIN32
-    if (!smyrnaDir)
+
+
+    smyrnaDir = getenv("SMYRNA_PATH");
+    if (!smyrnaDir) {
+#ifdef _WIN32
+	int sz =
+	    GetCurrentDirectory(0,
+				NULL) +
+	    strlen("\\share\\graphviz\\smyrna") + 1;
+	smyrnaDir = N_NEW(sz, char);
+	GetCurrentDirectory(sz, smyrnaDir);
+	smyrnaDir[strlen(smyrnaDir) - 4] = (char) 0;
+	strcat(smyrnaDir, "\\share\\graphviz\\smyrna");
+#else
 	smyrnaDir = SMYRNA_PATH;
 #endif
-
-	load_attributes();
+    }
+    load_attributes();
 
 #ifdef G_OS_WIN32
     package_prefix =
@@ -130,50 +178,59 @@ int main(int argc, char *argv[])
     package_data_dir = g_build_filename(package_prefix, "share", NULL);
     package_locale_dir =
 	g_build_filename(package_prefix, "share", "locale", NULL);
-	add_pixmap_directory("C:/");
 #else
-    if (smyrnaDir)
-	package_locale_dir = g_build_filename(smyrnaDir, "locale", NULL);
-    else
-	package_locale_dir = g_build_filename(SMYRNA_PATH, "locale", NULL);
-#endif	/* # */
+    package_locale_dir = g_build_filename(smyrnaDir, "locale", NULL);
+#endif				/* # */
 #ifdef ENABLE_NLS
     bindtextdomain(GETTEXT_PACKAGE, package_locale_dir);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
 #endif
     view = NEW(ViewInfo);
+
     init_viewport(view);
     gtk_set_locale();
     gtk_init(&argc, &argv);
-    initFileName = parseArgs (argc, argv, view);
-
-#ifdef _WIN32
-#define GTKTOPVIEW_ICONSDIR "C:\\Projects\\ATT\\GTK\\GTKTest2\\GUI\\images\\"
-#endif
-    if (!(smyrnaGlade)) {
-#ifdef _WIN32
-	smyrnaGlade = SMYRNA_GLADE;
-#else
-	smyrnaGlade = smyrnaPath ("smyrna.glade");
-#endif
-    }
+    initFileName = parseArgs(argc, argv, view);
+    if (!(smyrnaGlade))
+	smyrnaGlade = smyrnaPath("smyrna.glade");
     xml = glade_xml_new(smyrnaGlade, NULL, NULL);
+
     gladewidget = glade_xml_get_widget(xml, "frmMain");
     gtk_widget_show(gladewidget);
     g_signal_connect((gpointer) gladewidget, "destroy",
 		     G_CALLBACK(mQuitSlot), NULL);
     glade_xml_signal_autoconnect(xml);
+    if (initFileName) {
+	view->initFile = 1;
+	view->initFileName = strdup(initFileName);
+    }
     gtk_gl_init(0, 0);
     /* Configure OpenGL framebuffer. */
     glconfig = configure_gl();
-    gladewidget = glade_xml_get_widget(xml, "vbox2");
+//      gladewidget = glade_xml_get_widget(xml, "vbox2");
+    gladewidget = glade_xml_get_widget(xml, "hbox11");
+
+    gtk_widget_hide(glade_xml_get_widget(xml, "vbox13"));
+    gtk_window_set_deletable ((GtkWindow*)glade_xml_get_widget(xml, "dlgSettings"),0);
+    gtk_window_set_deletable ((GtkWindow*)glade_xml_get_widget(xml, "dlgTVFilter"),0);
+    gtk_window_set_deletable ((GtkWindow*)glade_xml_get_widget(xml, "frmTVNodes"),0);
+
+
     create_window(glconfig, gladewidget);
 
-    if (initFileName)
-	add_graph_to_viewport_from_file(initFileName);
-	change_cursor(GDK_TOP_LEFT_ARROW);
-	gtk_main();
+    change_cursor(GDK_TOP_LEFT_ARROW);
+
+#ifndef WIN32
+    glutInit(&argc, argv);
+#endif
+
+    gladewidget = glade_xml_get_widget(xml, "hbox13");
+    graphComboBox = (GtkComboBox *) gtk_combo_box_new_text();
+    gtk_box_pack_end((GtkBox*)gladewidget, (GtkWidget*)graphComboBox, 1, 1, 10);
+    gtk_widget_show((GtkWidget*)graphComboBox);
+    view->graphComboBox = graphComboBox;
+    gtk_main();
 
 
 
@@ -182,6 +239,5 @@ int main(int argc, char *argv[])
     g_free(package_data_dir);
 #endif
     g_free(package_locale_dir);
-    clear_viewport(view);
     return 0;
 }
