@@ -1,3 +1,4 @@
+/* $Id: topfisheyeview.h,v 1.14 2009/10/09 18:28:17 erg Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -18,15 +19,25 @@
 #include "smyrnadefs.h"
 #include "hier.h"
 
-void fisheye_polar(double x_focus, double y_focus, topview * t);
-void fisheye_spherical(double x_focus, double y_focus, double z_focus,
-		       topview * t);
-void prepare_topological_fisheye(topview*);
-void drawtopologicalfisheye(topview * t);
-void drawtopologicalfisheye2(topview * t);
-void changetopfishfocus(topview * t, float *x, float *y,
-				   float *z, int num_foci);
-void refresh_old_values(topview* t);
-void get_interpolated_coords(double x0,double y0,double x1,double y1,int fr,int total_fr, double* x,double* y);
-int get_active_frame(topview* t);
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+    void fisheye_polar(double x_focus, double y_focus, topview * t);
+    void fisheye_spherical(double x_focus, double y_focus, double z_focus,
+			   topview * t);
+    void prepare_topological_fisheye(topview *);
+    void drawtopologicalfisheye(topview * t);
+    void drawtopologicalfisheye2(topview * t);
+    void changetopfishfocus(topview * t, float *x, float *y,
+			    float *z, int num_foci);
+    void refresh_old_values(topview * t);
+    void get_interpolated_coords(double x0, double y0, double x1,
+				 double y1, int fr, int total_fr,
+				 double *x, double *y);
+    int get_active_frame(topview * t);
+
+#ifdef __cplusplus
+}				/* end extern "C" */
+#endif
 #endif
