@@ -1,4 +1,4 @@
-/* $Id: topview.h,v 1.18 2009/02/23 16:16:28 ellson Exp $ $Revision: 1.18 $ */
+/* $Id: topview.h,v 1.29 2009/11/07 13:37:06 ellson Exp $ $Revision: 1.29 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -18,20 +18,25 @@
 #define TOPVIEW_H
 
 #include "smyrnadefs.h"
-#ifdef	WIN32			//this is needed on WIN32 to get libglade see the callback
-#define _BB  __declspec(dllexport)
-#else
-#define _BB
+
+#ifdef __cplusplus
+extern "C" {
 #endif
 
-void cleartopview(topview * t);
-void preparetopview(Agraph_t * g, topview * t);
-void drawTopViewGraph(Agraph_t * g);
-int set_update_required(topview * t);
-int move_TVnodes(void);
-void local_zoom(topview * t);
-void originate_distorded_coordinates(topview * t);
-float calcfontsize(float totaledgelength,int totallabelsize,int edgecount,int totalnodecount);
-void select_with_regex(char* exp);
+    extern void cleartopview(topview * t);
+    extern void preparetopview(Agraph_t * g, topview * t);
+    extern void update_topview(Agraph_t * g, topview * t, int init);
+    extern void drawTopViewGraph(Agraph_t * g);
+    extern int move_TVnodes(void);
+    extern void local_zoom(topview * t);
+    extern void originate_distorded_coordinates(topview * t);
+    extern float calcfontsize(float totaledgelength, int totallabelsize,
+		       int edgecount, int totalnodecount);
+    extern void select_with_regex(char *exp);
+    extern void settvcolorinfo(Agraph_t * g, topview * t);
+    extern void setMultiedges(Agraph_t * g, char *attrname);
 
+#ifdef __cplusplus
+}				/* end extern "C" */
+#endif
 #endif
