@@ -21,12 +21,19 @@
 #include "smyrnadefs.h"
 #include "tvnodes.h"
 
-int prepare_nodes_for_groups(topview * t, topviewdata * td,
-			     int groupindex);
-int load_host_buttons(topview * t, Agraph_t * g, glCompSet * s);
-int click_group_button(int groupindex);
-void glhost_button_clicked_Slot(void *p);
-_BB void host_button_clicked_Slot(GtkWidget * widget, gpointer user_data);
+#ifdef __cplusplus
+extern "C" {
+#endif
 
+    int prepare_nodes_for_groups(topview * t, topviewdata * td,
+				 int groupindex);
+    int load_host_buttons(topview * t, Agraph_t * g, glCompSet * s);
+    int click_group_button(int groupindex);
+    void glhost_button_clicked_Slot(void *p);
+    _BB void host_button_clicked_Slot(GtkWidget * widget,
+				      gpointer user_data);
 
+#ifdef __cplusplus
+}				/* end extern "C" */
+#endif
 #endif
