@@ -1,4 +1,4 @@
-/* $Id: bcomps.c,v 1.6 2008/08/07 17:17:46 ellson Exp $ $Revision: 1.6 $ */
+/* $Id: bcomps.c,v 1.10 2010/01/08 21:28:39 erg Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -340,7 +340,8 @@ static void init(int argc, char *argv[])
 {
     int c;
 
-    while ((c = getopt(argc, argv, ":o:xstv?")) != -1) {
+    opterr = 0;
+    while ((c = getopt(argc, argv, ":o:xstv")) != -1) {
 	switch (c) {
 	case 'o':
 	    outfile = optarg;
