@@ -1,4 +1,4 @@
-/* $Id: ccomps.c,v 1.14 2009/03/04 18:19:11 arif Exp $ $Revision: 1.14 $ */
+/* $Id: ccomps.c,v 1.19 2010/01/08 21:28:39 erg Exp $ $Revision: 1.19 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -132,7 +132,8 @@ static void init(int argc, char *argv[])
 {
     int c;
 
-    while ((c = getopt(argc, argv, ":zo:xCX:nsv?")) != -1) {
+    opterr = 0;
+    while ((c = getopt(argc, argv, ":zo:xCX:nsv")) != -1) {
 	switch (c) {
 	case 'o':
 	    outfile = optarg;
@@ -560,11 +561,8 @@ static int processClusters(Agraph_t * g)
 		return 0;
 	    }
 	}
-#if 0
-  until bug 1515 is fixed
 	if (printMode != INTERNAL)
 	    agdelete(g, out);
-#endif
 	agdelete(dg, dout);
 	if (verbose)
 	    fprintf(stderr, "(%4ld) %7ld nodes %7ld edges\n",
@@ -665,11 +663,8 @@ static int process(Agraph_t * g)
 		return 0;
 	    }
 	}
-#if 0
-  until bug 1515 is fixed
 	if (printMode != INTERNAL)
 	    agdelete(g, out);
-#endif
 	if (verbose)
 	    fprintf(stderr, "(%4ld) %7ld nodes %7ld edges\n",
 		    c_cnt, n_cnt, e_cnt);
