@@ -1,4 +1,4 @@
-/* $Id: cvtgxl.c,v 1.7 2008/08/04 20:43:06 ellson Exp $ $Revision: 1.7 $ */
+/* $Id: cvtgxl.c,v 1.11 2010/01/08 21:28:39 erg Exp $ $Revision: 1.11 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -145,7 +145,8 @@ static void initargs(int argc, char **argv)
     int c;
 
     CmdName = cmdName(argv[0]);
-    while ((c = getopt(argc, argv, ":gdo:?")) != -1) {
+    opterr = 0;
+    while ((c = getopt(argc, argv, ":gdo:")) != -1) {
 	switch (c) {
 	case 'd':
 	    act = ToGV;
