@@ -1,4 +1,4 @@
-/* $Id: gc.c,v 1.5 2008/08/07 17:17:46 ellson Exp $ $Revision: 1.5 $ */
+/* $Id: gc.c,v 1.9 2010/01/08 21:28:39 erg Exp $ $Revision: 1.9 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -94,7 +94,8 @@ static void init(int argc, char *argv[])
 {
     unsigned int c;
 
-    while ((c = getopt(argc, argv, ":necCaDUrsv?")) != -1) {
+    opterr = 0;
+    while ((c = getopt(argc, argv, ":necCaDUrsv")) != -1) {
 	switch (c) {
 	case 'e':
 	    flags |= EDGES;
