@@ -1,4 +1,4 @@
-/* $Id: gvcolor.c,v 1.7 2008/08/07 17:17:46 ellson Exp $ $Revision: 1.7 $ */
+/* $Id: gvcolor.c,v 1.11 2010/01/08 21:28:39 erg Exp $ $Revision: 1.11 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -96,7 +96,8 @@ static void init(int argc, char *argv[])
 {
     int c;
 
-    while ((c = getopt(argc, argv, ":?")) != -1) {
+    opterr = 0;
+    while ((c = getopt(argc, argv, ":")) != -1) {
 	switch (c) {
 	case '?':
 	    if (optopt == '?')
