@@ -1,4 +1,4 @@
-/* $Id: gvpack.c,v 1.34 2009/09/01 22:23:07 erg Exp $ $Revision: 1.34 $ */
+/* $Id: gvpack.c,v 1.35 2010/01/08 21:28:39 erg Exp $ $Revision: 1.35 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -194,7 +194,8 @@ static void init(int argc, char *argv[], pack_info* pinfo)
     pinfo->doSplines = TRUE; /* Use edges in packing */
     pinfo->fixed = 0;
 
-    while ((c = getopt(argc, argv, ":na:gvum:o:G:?")) != -1) {
+    opterr = 0;
+    while ((c = getopt(argc, argv, ":na:gvum:o:G:")) != -1) {
 	switch (c) {
 	case 'a':
 	    len = strlen(optarg) + 2;
