@@ -1,4 +1,4 @@
-/* $Id: matrix_market.c,v 1.4 2008/07/31 22:08:21 erg Exp $Revision:  */
+/* $Id: matrix_market.c,v 1.7 2010/01/08 21:28:39 erg Exp $Revision:  */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -17,7 +17,8 @@
 #include "SparseMatrix.h"
 #include "mmio.h"
 #include "matrix_market.h"
-#include "render.h"
+#include "memory.h"
+#include "assert.h"
 #define MALLOC gmalloc
 #define REALLOC grealloc
 #define FREE free
