@@ -1,4 +1,4 @@
-/* $Id: nop.c,v 1.8 2008/08/07 17:17:46 ellson Exp $ $Revision: 1.8 $ */
+/* $Id: nop.c,v 1.12 2010/01/08 21:28:39 erg Exp $ $Revision: 1.12 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -50,7 +50,8 @@ static void init(int argc, char *argv[])
 {
     int c;
 
-    while ((c = getopt(argc, argv, ":p?")) != -1) {
+    opterr = 0;
+    while ((c = getopt(argc, argv, ":p")) != -1) {
 	switch (c) {
 	case 'p':
 	    chkOnly = 1;
