@@ -1,4 +1,4 @@
-/* $Id: unflatten.c,v 1.7 2009/03/11 17:11:33 north Exp $ $Revision: 1.7 $ */
+/* $Id: unflatten.c,v 1.11 2010/01/08 21:28:39 erg Exp $ $Revision: 1.11 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -179,8 +179,8 @@ static char **scanargs(int argc, char **argv)
     int c, ival;
 
     cmd = argv[0];
-
-    while ((c = getopt(argc, argv, ":fl:c:o:?")) != -1) {
+    opterr = 0;
+    while ((c = getopt(argc, argv, ":fl:c:o:")) != -1) {
 	switch (c) {
 	case 'f':
 	    Do_fans = 1;
