@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,47 +54,20 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum aagtokentype {
-     T_graph = 258,
-     T_node = 259,
-     T_edge = 260,
-     T_digraph = 261,
-     T_subgraph = 262,
-     T_strict = 263,
-     T_edgeop = 264,
-     T_list = 265,
-     T_attr = 266,
-     T_atom = 267,
-     T_qatom = 268
-   };
-#endif
-/* Tokens.  */
-#define T_graph 258
-#define T_node 259
-#define T_edge 260
-#define T_digraph 261
-#define T_subgraph 262
-#define T_strict 263
-#define T_edgeop 264
-#define T_list 265
-#define T_attr 266
-#define T_atom 267
-#define T_qatom 268
-
-
-
-
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 17 "../../lib/cgraph/grammar.y"
 
 
@@ -154,6 +126,9 @@ static Agraph_t *G;
 
 
 
+/* Line 189 of yacc.c  */
+#line 131 "y.tab.c"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -172,29 +147,69 @@ static Agraph_t *G;
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum aagtokentype {
+     T_graph = 258,
+     T_node = 259,
+     T_edge = 260,
+     T_digraph = 261,
+     T_subgraph = 262,
+     T_strict = 263,
+     T_edgeop = 264,
+     T_list = 265,
+     T_attr = 266,
+     T_atom = 267,
+     T_qatom = 268
+   };
+#endif
+/* Tokens.  */
+#define T_graph 258
+#define T_node 259
+#define T_edge 260
+#define T_digraph 261
+#define T_subgraph 262
+#define T_strict 263
+#define T_edgeop 264
+#define T_list 265
+#define T_attr 266
+#define T_atom 267
+#define T_qatom 268
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 74 "../../lib/cgraph/grammar.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 74 "../../lib/cgraph/grammar.y"
+
 			int				i;
 			char			*str;
 			struct Agnode_s	*n;
-}
-/* Line 187 of yacc.c.  */
-#line 185 "y.tab.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 201 "y.tab.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define aagstype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 198 "y.tab.c"
+/* Line 264 of yacc.c  */
+#line 213 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -269,14 +284,14 @@ typedef short int aagtype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int aagi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (aagi)
+    int aagi;
 #endif
 {
-  return i;
+  return aagi;
 }
 #endif
 
@@ -357,9 +372,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union aagalloc
 {
-  aagtype_int16 aagss;
-  YYSTYPE aagvs;
-  };
+  aagtype_int16 aagss_alloc;
+  YYSTYPE aagvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union aagalloc) - 1)
@@ -393,12 +408,12 @@ union aagalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T aagnewbytes;						\
-	YYCOPY (&aagptr->Stack, Stack, aagsize);				\
-	Stack = &aagptr->Stack;						\
+	YYCOPY (&aagptr->Stack_alloc, Stack, aagsize);			\
+	Stack = &aagptr->Stack_alloc;					\
 	aagnewbytes = aagstacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	aagptr += aagnewbytes / sizeof (*aagptr);				\
       }									\
@@ -516,10 +531,10 @@ static const char *const aagtname[] =
   "T_atom", "T_qatom", "'{'", "'}'", "';'", "','", "':'", "'='", "'['",
   "']'", "'@'", "'+'", "$accept", "graph", "body", "hdr", "optgraphname",
   "optstrict", "graphtype", "optstmtlist", "stmtlist", "optsemi", "stmt",
-  "compound", "simple", "rcompound", "@1", "nodelist", "node", "attrstmt",
+  "compound", "simple", "rcompound", "$@1", "nodelist", "node", "attrstmt",
   "attrtype", "optmacroname", "optattr", "attrlist", "optattrdefs",
   "attrdefs", "attritem", "attrassignment", "attrmacro", "graphattrdefs",
-  "subgraph", "@2", "optsubghdr", "optseparator", "atom", "qatom", 0
+  "subgraph", "$@2", "optsubghdr", "optseparator", "atom", "qatom", 0
 };
 #endif
 
@@ -827,17 +842,20 @@ aag_symbol_print (aagoutput, aagtype, aagvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-aag_stack_print (aagtype_int16 *bottom, aagtype_int16 *top)
+aag_stack_print (aagtype_int16 *aagbottom, aagtype_int16 *aagtop)
 #else
 static void
-aag_stack_print (bottom, top)
-    aagtype_int16 *bottom;
-    aagtype_int16 *top;
+aag_stack_print (aagbottom, aagtop)
+    aagtype_int16 *aagbottom;
+    aagtype_int16 *aagtop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; aagbottom <= aagtop; aagbottom++)
+    {
+      int aagbot = *aagbottom;
+      YYFPRINTF (stderr, " %d", aagbot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -871,11 +889,11 @@ aag_reduce_print (aagvsp, aagrule)
   /* The symbols being reduced.  */
   for (aagi = 0; aagi < aagnrhs; aagi++)
     {
-      fprintf (stderr, "   $%d = ", aagi + 1);
+      YYFPRINTF (stderr, "   $%d = ", aagi + 1);
       aag_symbol_print (stderr, aagrhs[aagprhs[aagrule] + aagi],
 		       &(aagvsp[(aagi + 1) - (aagnrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1155,10 +1173,8 @@ aagdestruct (aagmsg, aagtype, aagvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int aagparse (void *YYPARSE_PARAM);
@@ -1174,11 +1190,10 @@ int aagparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int aagchar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE aaglval;
 
 /* Number of syntax errors so far.  */
@@ -1186,9 +1201,9 @@ int aagnerrs;
 
 
 
-/*----------.
-| aagparse.  |
-`----------*/
+/*-------------------------.
+| aagparse or aagpush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1212,14 +1227,39 @@ aagparse ()
 #endif
 #endif
 {
-  
-  int aagstate;
+
+
+    int aagstate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int aagerrstatus;
+
+    /* The stacks and their tools:
+       `aagss': related to states.
+       `aagvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow aagoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    aagtype_int16 aagssa[YYINITDEPTH];
+    aagtype_int16 *aagss;
+    aagtype_int16 *aagssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE aagvsa[YYINITDEPTH];
+    YYSTYPE *aagvs;
+    YYSTYPE *aagvsp;
+
+    YYSIZE_T aagstacksize;
+
   int aagn;
   int aagresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int aagerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int aagtoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int aagtoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE aagval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char aagmsgbuf[128];
@@ -1227,51 +1267,28 @@ aagparse ()
   YYSIZE_T aagmsg_alloc = sizeof aagmsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `aagss': related to states,
-     `aagvs': related to semantic values,
-     `aagls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow aagoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  aagtype_int16 aagssa[YYINITDEPTH];
-  aagtype_int16 *aagss = aagssa;
-  aagtype_int16 *aagssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE aagvsa[YYINITDEPTH];
-  YYSTYPE *aagvs = aagvsa;
-  YYSTYPE *aagvsp;
-
-
-
 #define YYPOPSTACK(N)   (aagvsp -= (N), aagssp -= (N))
 
-  YYSIZE_T aagstacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE aagval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int aaglen = 0;
 
+  aagtoken = 0;
+  aagss = aagssa;
+  aagvs = aagvsa;
+  aagstacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   aagstate = 0;
   aagerrstatus = 0;
   aagnerrs = 0;
-  aagchar = YYEMPTY;		/* Cause a token to be read.  */
+  aagchar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   aagssp = aagss;
   aagvsp = aagvs;
 
@@ -1301,7 +1318,6 @@ aagparse ()
 	YYSTYPE *aagvs1 = aagvs;
 	aagtype_int16 *aagss1 = aagss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1309,7 +1325,6 @@ aagparse ()
 	aagoverflow (YY_("memory exhausted"),
 		    &aagss1, aagsize * sizeof (*aagssp),
 		    &aagvs1, aagsize * sizeof (*aagvsp),
-
 		    &aagstacksize);
 
 	aagss = aagss1;
@@ -1332,9 +1347,8 @@ aagparse ()
 	  (union aagalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (aagstacksize));
 	if (! aagptr)
 	  goto aagexhaustedlab;
-	YYSTACK_RELOCATE (aagss);
-	YYSTACK_RELOCATE (aagvs);
-
+	YYSTACK_RELOCATE (aagss_alloc, aagss);
+	YYSTACK_RELOCATE (aagvs_alloc, aagvs);
 #  undef YYSTACK_RELOCATE
 	if (aagss1 != aagssa)
 	  YYSTACK_FREE (aagss1);
@@ -1345,7 +1359,6 @@ aagparse ()
       aagssp = aagss + aagsize - 1;
       aagvsp = aagvs + aagsize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) aagstacksize));
 
@@ -1355,6 +1368,9 @@ aagparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", aagstate));
 
+  if (aagstate == YYFINAL)
+    YYACCEPT;
+
   goto aagbackup;
 
 /*-----------.
@@ -1363,16 +1379,16 @@ aagparse ()
 aagbackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   aagn = aagpact[aagstate];
   if (aagn == YYPACT_NINF)
     goto aagdefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (aagchar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1404,20 +1420,16 @@ aagbackup:
       goto aagreduce;
     }
 
-  if (aagn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (aagerrstatus)
     aagerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", aagtoken, &aaglval, &aaglloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (aagchar != YYEOF)
-    aagchar = YYEMPTY;
+  /* Discard the shifted token.  */
+  aagchar = YYEMPTY;
 
   aagstate = aagn;
   *++aagvsp = aaglval;
@@ -1457,178 +1469,247 @@ aagreduce:
   switch (aagn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 91 "../../lib/cgraph/grammar.y"
     {endgraph();}
     break;
 
   case 3:
+
+/* Line 1455 of yacc.c  */
 #line 92 "../../lib/cgraph/grammar.y"
     {if (G) {agclose(G); G = Ag_G_global = NIL(Agraph_t*);}}
     break;
 
   case 6:
+
+/* Line 1455 of yacc.c  */
 #line 98 "../../lib/cgraph/grammar.y"
     {startgraph((aagvsp[(3) - (3)].str),(aagvsp[(2) - (3)].i),(aagvsp[(1) - (3)].i));}
     break;
 
   case 7:
+
+/* Line 1455 of yacc.c  */
 #line 101 "../../lib/cgraph/grammar.y"
     {(aagval.str)=(aagvsp[(1) - (1)].str);}
     break;
 
   case 8:
+
+/* Line 1455 of yacc.c  */
 #line 101 "../../lib/cgraph/grammar.y"
     {(aagval.str)=0;}
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 103 "../../lib/cgraph/grammar.y"
     {(aagval.i)=1;}
     break;
 
   case 10:
+
+/* Line 1455 of yacc.c  */
 #line 103 "../../lib/cgraph/grammar.y"
     {(aagval.i)=0;}
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 105 "../../lib/cgraph/grammar.y"
     {(aagval.i) = 0;}
     break;
 
   case 12:
+
+/* Line 1455 of yacc.c  */
 #line 105 "../../lib/cgraph/grammar.y"
     {(aagval.i) = 1;}
     break;
 
   case 21:
+
+/* Line 1455 of yacc.c  */
 #line 118 "../../lib/cgraph/grammar.y"
     {if ((aagvsp[(2) - (3)].i)) endedge(); else endnode();}
     break;
 
   case 24:
+
+/* Line 1455 of yacc.c  */
 #line 123 "../../lib/cgraph/grammar.y"
     {bufferedges();}
     break;
 
   case 25:
+
+/* Line 1455 of yacc.c  */
 #line 123 "../../lib/cgraph/grammar.y"
     {(aagval.i) = 1;}
     break;
 
   case 26:
+
+/* Line 1455 of yacc.c  */
 #line 124 "../../lib/cgraph/grammar.y"
     {(aagval.i) = 0;}
     break;
 
   case 29:
+
+/* Line 1455 of yacc.c  */
 #line 130 "../../lib/cgraph/grammar.y"
     {appendnode((aagvsp[(1) - (1)].str),NIL(char*),NIL(char*));}
     break;
 
   case 30:
+
+/* Line 1455 of yacc.c  */
 #line 131 "../../lib/cgraph/grammar.y"
     {appendnode((aagvsp[(1) - (3)].str),(aagvsp[(3) - (3)].str),NIL(char*));}
     break;
 
   case 31:
+
+/* Line 1455 of yacc.c  */
 #line 132 "../../lib/cgraph/grammar.y"
     {appendnode((aagvsp[(1) - (5)].str),(aagvsp[(3) - (5)].str),(aagvsp[(5) - (5)].str));}
     break;
 
   case 32:
+
+/* Line 1455 of yacc.c  */
 #line 135 "../../lib/cgraph/grammar.y"
     {attrstmt((aagvsp[(1) - (3)].i),(aagvsp[(2) - (3)].str));}
     break;
 
   case 33:
+
+/* Line 1455 of yacc.c  */
 #line 136 "../../lib/cgraph/grammar.y"
     {attrstmt(T_graph,NIL(char*));}
     break;
 
   case 34:
+
+/* Line 1455 of yacc.c  */
 #line 139 "../../lib/cgraph/grammar.y"
     {(aagval.i) = T_graph;}
     break;
 
   case 35:
+
+/* Line 1455 of yacc.c  */
 #line 140 "../../lib/cgraph/grammar.y"
     {(aagval.i) = T_node;}
     break;
 
   case 36:
+
+/* Line 1455 of yacc.c  */
 #line 141 "../../lib/cgraph/grammar.y"
     {(aagval.i) = T_edge;}
     break;
 
   case 37:
+
+/* Line 1455 of yacc.c  */
 #line 144 "../../lib/cgraph/grammar.y"
     {(aagval.str) = (aagvsp[(1) - (2)].str);}
     break;
 
   case 38:
+
+/* Line 1455 of yacc.c  */
 #line 145 "../../lib/cgraph/grammar.y"
     {(aagval.str) = NIL(char*); }
     break;
 
   case 47:
+
+/* Line 1455 of yacc.c  */
 #line 160 "../../lib/cgraph/grammar.y"
     {appendattr((aagvsp[(1) - (3)].str),(aagvsp[(3) - (3)].str));}
     break;
 
   case 48:
+
+/* Line 1455 of yacc.c  */
 #line 163 "../../lib/cgraph/grammar.y"
     {appendattr((aagvsp[(2) - (2)].str),NIL(char*));}
     break;
 
   case 50:
+
+/* Line 1455 of yacc.c  */
 #line 169 "../../lib/cgraph/grammar.y"
     {opensubg((aagvsp[(1) - (1)].str));}
     break;
 
   case 51:
+
+/* Line 1455 of yacc.c  */
 #line 169 "../../lib/cgraph/grammar.y"
     {closesubg();}
     break;
 
   case 52:
+
+/* Line 1455 of yacc.c  */
 #line 172 "../../lib/cgraph/grammar.y"
     {(aagval.str)=(aagvsp[(2) - (2)].str);}
     break;
 
   case 53:
+
+/* Line 1455 of yacc.c  */
 #line 173 "../../lib/cgraph/grammar.y"
     {(aagval.str)=NIL(char*);}
     break;
 
   case 54:
+
+/* Line 1455 of yacc.c  */
 #line 174 "../../lib/cgraph/grammar.y"
     {(aagval.str)=NIL(char*);}
     break;
 
   case 58:
+
+/* Line 1455 of yacc.c  */
 #line 179 "../../lib/cgraph/grammar.y"
     {(aagval.str) = (aagvsp[(1) - (1)].str);}
     break;
 
   case 59:
+
+/* Line 1455 of yacc.c  */
 #line 180 "../../lib/cgraph/grammar.y"
     {(aagval.str) = (aagvsp[(1) - (1)].str);}
     break;
 
   case 60:
+
+/* Line 1455 of yacc.c  */
 #line 183 "../../lib/cgraph/grammar.y"
     {(aagval.str) = (aagvsp[(1) - (1)].str);}
     break;
 
   case 61:
+
+/* Line 1455 of yacc.c  */
 #line 184 "../../lib/cgraph/grammar.y"
     {(aagval.str) = concat((aagvsp[(1) - (3)].str),(aagvsp[(3) - (3)].str));}
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1632 "y.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 1713 "y.tab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", aagr1[aagn], &aagval, &aagloc);
@@ -1639,7 +1720,6 @@ aagreduce:
 
   *++aagvsp = aagval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1704,7 +1784,7 @@ aagerrlab:
 
   if (aagerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (aagchar <= YYEOF)
@@ -1721,7 +1801,7 @@ aagerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto aagerrlab1;
 
@@ -1778,9 +1858,6 @@ aagerrlab1:
       YY_STACK_PRINT (aagss, aagssp);
     }
 
-  if (aagn == YYFINAL)
-    YYACCEPT;
-
   *++aagvsp = aaglval;
 
 
@@ -1805,7 +1882,7 @@ aagabortlab:
   aagresult = 1;
   goto aagreturn;
 
-#ifndef aagoverflow
+#if !defined(aagoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | aagexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1816,7 +1893,7 @@ aagexhaustedlab:
 #endif
 
 aagreturn:
-  if (aagchar != YYEOF && aagchar != YYEMPTY)
+  if (aagchar != YYEMPTY)
      aagdestruct ("Cleanup: discarding lookahead",
 		 aagtoken, &aaglval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -1842,6 +1919,8 @@ aagreturn:
 }
 
 
+
+/* Line 1675 of yacc.c  */
 #line 186 "../../lib/cgraph/grammar.y"
 
 
