@@ -1,4 +1,4 @@
-/* $Id: node.c,v 1.2 2008/09/10 12:26:27 north Exp $ $Revision: 1.2 $ */
+/* $Id: node.c,v 1.5 2009/06/03 01:10:51 ellson Exp $ $Revision: 1.5 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -198,10 +198,12 @@ int agdelnode(Agraph_t * g, Agnode_t * n)
 	agrecclose((Agobj_t *) n);
 	agfreeid(g, AGNODE, AGID(n));
     }
-    return agapply(g, (Agobj_t *) n, (agobjfn_t) agdelnodeimage, NILnode,
-		   FALSE);
-    if (g == agroot(g))
-	agfree(g, n);
+    if (agapply (g, (Agobj_t *) n, (agobjfn_t) agdelnodeimage, NILnode, FALSE) == SUCCESS) {
+	if (g == agroot(g))
+	    agfree(g, n);
+	return SUCCESS;
+    } else
+	return FAILURE;
 }
 
 static void dict_relabel(Agnode_t * n, void *arg)
