@@ -1,4 +1,4 @@
-/* $Id: obj.c,v 1.3 2008/09/08 17:09:09 erg Exp $ $Revision: 1.3 $ */
+/* $Id: obj.c,v 1.6 2009/06/03 01:10:51 ellson Exp $ $Revision: 1.6 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -18,11 +18,7 @@
 
 int agdelete(Agraph_t * g, void *obj)
 {
-    Agraph_t *h;
-
-    h = agraphof(obj);
-    if ((g != h)
-	&& ((AGTYPE((Agobj_t *) obj) != AGRAPH) || (g != agparent(h))))
+    if ((AGTYPE((Agobj_t *) obj) == AGRAPH) && (g != agparent(obj)))
 	agerr(AGERR, "agdelete on wrong graph");
 
     switch (AGTYPE((Agobj_t *) obj)) {
