@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,47 +54,20 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     T_graph = 258,
-     T_node = 259,
-     T_edge = 260,
-     T_digraph = 261,
-     T_subgraph = 262,
-     T_strict = 263,
-     T_edgeop = 264,
-     T_list = 265,
-     T_attr = 266,
-     T_atom = 267,
-     T_qatom = 268
-   };
-#endif
-/* Tokens.  */
-#define T_graph 258
-#define T_node 259
-#define T_edge 260
-#define T_digraph 261
-#define T_subgraph 262
-#define T_strict 263
-#define T_edgeop 264
-#define T_list 265
-#define T_attr 266
-#define T_atom 267
-#define T_qatom 268
-
-
-
-
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 17 "../../lib/cgraph/grammar.y"
 
 
@@ -154,6 +126,9 @@ static Agraph_t *G;
 
 
 
+/* Line 189 of yacc.c  */
+#line 131 "y.tab.c"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -172,29 +147,69 @@ static Agraph_t *G;
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     T_graph = 258,
+     T_node = 259,
+     T_edge = 260,
+     T_digraph = 261,
+     T_subgraph = 262,
+     T_strict = 263,
+     T_edgeop = 264,
+     T_list = 265,
+     T_attr = 266,
+     T_atom = 267,
+     T_qatom = 268
+   };
+#endif
+/* Tokens.  */
+#define T_graph 258
+#define T_node 259
+#define T_edge 260
+#define T_digraph 261
+#define T_subgraph 262
+#define T_strict 263
+#define T_edgeop 264
+#define T_list 265
+#define T_attr 266
+#define T_atom 267
+#define T_qatom 268
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 74 "../../lib/cgraph/grammar.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 74 "../../lib/cgraph/grammar.y"
+
 			int				i;
 			char			*str;
 			struct Agnode_s	*n;
-}
-/* Line 187 of yacc.c.  */
-#line 185 "y.tab.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 201 "y.tab.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 198 "y.tab.c"
+/* Line 264 of yacc.c  */
+#line 213 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -269,14 +284,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -357,9 +372,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -393,12 +408,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -516,10 +531,10 @@ static const char *const yytname[] =
   "T_atom", "T_qatom", "'{'", "'}'", "';'", "','", "':'", "'='", "'['",
   "']'", "'@'", "'+'", "$accept", "graph", "body", "hdr", "optgraphname",
   "optstrict", "graphtype", "optstmtlist", "stmtlist", "optsemi", "stmt",
-  "compound", "simple", "rcompound", "@1", "nodelist", "node", "attrstmt",
+  "compound", "simple", "rcompound", "$@1", "nodelist", "node", "attrstmt",
   "attrtype", "optmacroname", "optattr", "attrlist", "optattrdefs",
   "attrdefs", "attritem", "attrassignment", "attrmacro", "graphattrdefs",
-  "subgraph", "@2", "optsubghdr", "optseparator", "atom", "qatom", 0
+  "subgraph", "$@2", "optsubghdr", "optseparator", "atom", "qatom", 0
 };
 #endif
 
@@ -827,17 +842,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -871,11 +889,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1155,10 +1173,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1174,11 +1190,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1186,9 +1201,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1212,14 +1227,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1227,51 +1267,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1301,7 +1318,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1309,7 +1325,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1332,9 +1347,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1345,7 +1359,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1355,6 +1368,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1363,16 +1379,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1404,20 +1420,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1457,178 +1469,247 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 91 "../../lib/cgraph/grammar.y"
     {endgraph();}
     break;
 
   case 3:
+
+/* Line 1455 of yacc.c  */
 #line 92 "../../lib/cgraph/grammar.y"
     {if (G) {agclose(G); G = Ag_G_global = NIL(Agraph_t*);}}
     break;
 
   case 6:
+
+/* Line 1455 of yacc.c  */
 #line 98 "../../lib/cgraph/grammar.y"
     {startgraph((yyvsp[(3) - (3)].str),(yyvsp[(2) - (3)].i),(yyvsp[(1) - (3)].i));}
     break;
 
   case 7:
+
+/* Line 1455 of yacc.c  */
 #line 101 "../../lib/cgraph/grammar.y"
     {(yyval.str)=(yyvsp[(1) - (1)].str);}
     break;
 
   case 8:
+
+/* Line 1455 of yacc.c  */
 #line 101 "../../lib/cgraph/grammar.y"
     {(yyval.str)=0;}
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 103 "../../lib/cgraph/grammar.y"
     {(yyval.i)=1;}
     break;
 
   case 10:
+
+/* Line 1455 of yacc.c  */
 #line 103 "../../lib/cgraph/grammar.y"
     {(yyval.i)=0;}
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 105 "../../lib/cgraph/grammar.y"
     {(yyval.i) = 0;}
     break;
 
   case 12:
+
+/* Line 1455 of yacc.c  */
 #line 105 "../../lib/cgraph/grammar.y"
     {(yyval.i) = 1;}
     break;
 
   case 21:
+
+/* Line 1455 of yacc.c  */
 #line 118 "../../lib/cgraph/grammar.y"
     {if ((yyvsp[(2) - (3)].i)) endedge(); else endnode();}
     break;
 
   case 24:
+
+/* Line 1455 of yacc.c  */
 #line 123 "../../lib/cgraph/grammar.y"
     {bufferedges();}
     break;
 
   case 25:
+
+/* Line 1455 of yacc.c  */
 #line 123 "../../lib/cgraph/grammar.y"
     {(yyval.i) = 1;}
     break;
 
   case 26:
+
+/* Line 1455 of yacc.c  */
 #line 124 "../../lib/cgraph/grammar.y"
     {(yyval.i) = 0;}
     break;
 
   case 29:
+
+/* Line 1455 of yacc.c  */
 #line 130 "../../lib/cgraph/grammar.y"
     {appendnode((yyvsp[(1) - (1)].str),NIL(char*),NIL(char*));}
     break;
 
   case 30:
+
+/* Line 1455 of yacc.c  */
 #line 131 "../../lib/cgraph/grammar.y"
     {appendnode((yyvsp[(1) - (3)].str),(yyvsp[(3) - (3)].str),NIL(char*));}
     break;
 
   case 31:
+
+/* Line 1455 of yacc.c  */
 #line 132 "../../lib/cgraph/grammar.y"
     {appendnode((yyvsp[(1) - (5)].str),(yyvsp[(3) - (5)].str),(yyvsp[(5) - (5)].str));}
     break;
 
   case 32:
+
+/* Line 1455 of yacc.c  */
 #line 135 "../../lib/cgraph/grammar.y"
     {attrstmt((yyvsp[(1) - (3)].i),(yyvsp[(2) - (3)].str));}
     break;
 
   case 33:
+
+/* Line 1455 of yacc.c  */
 #line 136 "../../lib/cgraph/grammar.y"
     {attrstmt(T_graph,NIL(char*));}
     break;
 
   case 34:
+
+/* Line 1455 of yacc.c  */
 #line 139 "../../lib/cgraph/grammar.y"
     {(yyval.i) = T_graph;}
     break;
 
   case 35:
+
+/* Line 1455 of yacc.c  */
 #line 140 "../../lib/cgraph/grammar.y"
     {(yyval.i) = T_node;}
     break;
 
   case 36:
+
+/* Line 1455 of yacc.c  */
 #line 141 "../../lib/cgraph/grammar.y"
     {(yyval.i) = T_edge;}
     break;
 
   case 37:
+
+/* Line 1455 of yacc.c  */
 #line 144 "../../lib/cgraph/grammar.y"
     {(yyval.str) = (yyvsp[(1) - (2)].str);}
     break;
 
   case 38:
+
+/* Line 1455 of yacc.c  */
 #line 145 "../../lib/cgraph/grammar.y"
     {(yyval.str) = NIL(char*); }
     break;
 
   case 47:
+
+/* Line 1455 of yacc.c  */
 #line 160 "../../lib/cgraph/grammar.y"
     {appendattr((yyvsp[(1) - (3)].str),(yyvsp[(3) - (3)].str));}
     break;
 
   case 48:
+
+/* Line 1455 of yacc.c  */
 #line 163 "../../lib/cgraph/grammar.y"
     {appendattr((yyvsp[(2) - (2)].str),NIL(char*));}
     break;
 
   case 50:
+
+/* Line 1455 of yacc.c  */
 #line 169 "../../lib/cgraph/grammar.y"
     {opensubg((yyvsp[(1) - (1)].str));}
     break;
 
   case 51:
+
+/* Line 1455 of yacc.c  */
 #line 169 "../../lib/cgraph/grammar.y"
     {closesubg();}
     break;
 
   case 52:
+
+/* Line 1455 of yacc.c  */
 #line 172 "../../lib/cgraph/grammar.y"
     {(yyval.str)=(yyvsp[(2) - (2)].str);}
     break;
 
   case 53:
+
+/* Line 1455 of yacc.c  */
 #line 173 "../../lib/cgraph/grammar.y"
     {(yyval.str)=NIL(char*);}
     break;
 
   case 54:
+
+/* Line 1455 of yacc.c  */
 #line 174 "../../lib/cgraph/grammar.y"
     {(yyval.str)=NIL(char*);}
     break;
 
   case 58:
+
+/* Line 1455 of yacc.c  */
 #line 179 "../../lib/cgraph/grammar.y"
     {(yyval.str) = (yyvsp[(1) - (1)].str);}
     break;
 
   case 59:
+
+/* Line 1455 of yacc.c  */
 #line 180 "../../lib/cgraph/grammar.y"
     {(yyval.str) = (yyvsp[(1) - (1)].str);}
     break;
 
   case 60:
+
+/* Line 1455 of yacc.c  */
 #line 183 "../../lib/cgraph/grammar.y"
     {(yyval.str) = (yyvsp[(1) - (1)].str);}
     break;
 
   case 61:
+
+/* Line 1455 of yacc.c  */
 #line 184 "../../lib/cgraph/grammar.y"
     {(yyval.str) = concat((yyvsp[(1) - (3)].str),(yyvsp[(3) - (3)].str));}
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1632 "y.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 1713 "y.tab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1639,7 +1720,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1704,7 +1784,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1721,7 +1801,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1778,9 +1858,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -1805,7 +1882,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1816,7 +1893,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -1842,6 +1919,8 @@ yyreturn:
 }
 
 
+
+/* Line 1675 of yacc.c  */
 #line 186 "../../lib/cgraph/grammar.y"
 
 
