@@ -1,4 +1,4 @@
-/* $Id: blockpath.c,v 1.7 2008/10/23 20:23:55 ellson Exp $ $Revision: 1.7 $ */
+/* $Id: blockpath.c,v 1.10 2009/08/10 20:15:19 erg Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -86,23 +86,6 @@ static Agraph_t *clone_graph(Agraph_t * ing, Agraph_t ** xg)
 	}
     }
     *xg = xclone;
-#ifdef OLD
-    clone = agopen("clone", root->kind);
-
-    for (n = agfstnode(root); n; n = agnxtnode(root, n)) {
-	cn = agnode(clone, n->name);
-	ND_alg(cn) = DATA(n);
-	BCDONE(cn) = 0;
-    }
-
-    for (n = agfstnode(root); n; n = agnxtnode(root, n)) {
-	Agnode_t *t = agnode(clone, n);
-	for (e = agfstout(root, n); e; e = agnxtout(root, e)) {
-	    Agnode_t *h = agnode(clone, agnameof(aghead(e)));
-	    agedge(clone, t, h);
-	}
-    }
-#endif
     return clone;
 }
 
