@@ -1,4 +1,4 @@
-/* $Id: arrows.c,v 1.34 2008/10/23 20:23:55 ellson Exp $ $Revision: 1.34 $ */
+/* $Id: arrows.c,v 1.38 2009/10/05 13:06:08 ellson Exp $ $Revision: 1.38 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -199,14 +199,14 @@ void arrow_flags(Agedge_t * e, int *sflag, int *eflag)
 	}
     }
 #ifdef WITH_CGRAPH
-    if (E_arrowhead && ((attr = agxget(e, E_arrowhead)))[0])
+    if (E_arrowhead && (*eflag == ARR_TYPE_NORM) && ((attr = agxget(e, E_arrowhead)))[0])
 	arrow_match_name(attr, eflag);
-    if (E_arrowtail && ((attr = agxget(e, E_arrowtail)))[0])
+    if (E_arrowtail && (*sflag == ARR_TYPE_NORM) && ((attr = agxget(e, E_arrowtail)))[0])
 	arrow_match_name(attr, sflag);
 #else
-    if (E_arrowhead && ((attr = agxget(e, E_arrowhead->index)))[0])
+    if (E_arrowhead && (*eflag == ARR_TYPE_NORM) && ((attr = agxget(e, E_arrowhead->index)))[0])
 	arrow_match_name(attr, eflag);
-    if (E_arrowtail && ((attr = agxget(e, E_arrowtail->index)))[0])
+    if (E_arrowtail && (*sflag == ARR_TYPE_NORM) && ((attr = agxget(e, E_arrowtail->index)))[0])
 	arrow_match_name(attr, sflag);
 #endif
     if (ED_conc_opp_flag(e)) {
@@ -571,7 +571,6 @@ void arrow_gen(GVJ_t * job, emit_state_t emit_state, pointf p, pointf u, double
 
     /* Dotted and dashed styles on the arrowhead are ugly (dds) */
     /* linewidth needs to be reset */
-    gvrender_begin_context(job);
     gvrender_set_style(job, job->gvc->defaultlinestyle);
 
     /* generate arrowhead vector */
@@ -592,7 +591,5 @@ void arrow_gen(GVJ_t * job, emit_state_t emit_state, pointf p, pointf u, double
         p = arrow_gen_type(job, p, u, arrowsize, penwidth, f);
     }
 
-    gvrender_end_context(job);
-
     obj->emit_state = old_emit_state;
 }
