@@ -1,4 +1,4 @@
-/* $Id: const.h,v 1.28 2008/04/08 21:34:51 erg Exp $ $Revision: 1.28 $ */
+/* $Id: const.h,v 1.31 2009/08/28 19:46:42 erg Exp $ $Revision: 1.31 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -178,10 +178,12 @@
 #define GVSPLINES       1
 
 /* existence of labels */
-#define EDGE_LABEL		1
-#define HEAD_LABEL		2
-#define TAIL_LABEL		4
-#define GRAPH_LABEL		8
+#define EDGE_LABEL		(1 << 0)
+#define HEAD_LABEL		(1 << 1)
+#define TAIL_LABEL		(1 << 2)
+#define GRAPH_LABEL		(1 << 3)
+#define NODE_XLABEL		(1 << 4)
+#define EDGE_XLABEL		(1 << 5)
 
 /* type of graph label: GD_label_pos */
 #define LABEL_AT_BOTTOM	0
