@@ -1,4 +1,4 @@
-/* $Id: emit.c,v 1.286 2009/01/02 17:49:14 ellson Exp $ $Revision: 1.286 $ */
+/* $Id: emit.c,v 1.301 2009/12/05 20:13:06 erg Exp $ $Revision: 1.301 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -24,15 +24,39 @@
 
 #include <string.h>
 #include <ctype.h>
+#include <locale.h>
 #include "render.h"
 #include "agxbuf.h"
 #include "htmltable.h"
 #include "gvc.h"
+#include "xdot.h"
 
 #define P2RECT(p, pr, sx, sy) (pr[0].x = p.x - sx, pr[0].y = p.y - sy, pr[1].x = p.x + sx, pr[1].y = p.y + sy)
 #define FUZZ 3
 #define EPSILON .0001
 
+typedef struct {
+    xdot_op op;
+    boxf bb;
+    textpara_t* para;
+} exdot_op;
+
+void* init_xdot (Agraph_t* g)
+{
+    char* p;
+    xdot* xd = NULL;
+
+    if ((p = agget(g, "_draw_")) && p[0]) {
+	xd = parseXDotF (p, NULL, sizeof (exdot_op));
+
+	if (!xd) {
+	    agerr(AGWARN, "Could not parse \"_draw_\" attribute in graph %s\n", agnameof(g));
+	    agerr(AGPREV, "  \"%s\"\n", p);
+	}
+    }
+    return xd;
+}
+
 static char *defaultlinestyle[3] = { "solid\0", "setlinewidth\0001\0", 0 };
 
 /* push empty graphic state for current object */
@@ -336,7 +360,7 @@ void update_bb_bz(boxf *bb, pointf *cp)
     }
 }
 
-#ifdef DEBUG
+#if (DEBUG==2)
 static void psmapOutput (pointf* ps, int n)
 {
    int i;
@@ -384,7 +408,7 @@ static void map_bspline_poly(pointf **pbs_p, int **pbs_n, int *pbs_poly_n, int n
         (*pbs_p)[nump+i] = p1[i];
         (*pbs_p)[nump+last-i] = p2[i];
     }
-#ifdef DEBUG
+#if (DEBUG==2)
     psmapOutput (*pbs_p + nump, last+1);
 #endif
 }
@@ -818,8 +842,99 @@ static boolean write_node_test(Agraph_t * g, Agnode_t * n)
     return TRUE;
 }
 
+#define INITPTS 1000
+
+static pointf*
+copyPts (pointf* pts, int* ptsize, xdot_point* inpts, int numpts)
+{
+    int i, sz = *ptsize;
+
+    if (numpts > sz) {
+	sz = MAX(2*sz, numpts);
+	pts = RALLOC(sz, pts, pointf);
+	*ptsize = sz;
+    }
+
+    for (i = 0; i < numpts; i++) {
+	pts[i].x = inpts[i].x;
+	pts[i].y = inpts[i].y;
+    }
+
+    return pts;
+}
+
+static void emit_xdot (GVJ_t * job, xdot* xd)
+{
+    int image_warn = 1;
+    int ptsize = INITPTS;
+    pointf* pts = N_GNEW(INITPTS, pointf);
+    double fontsize;
+    char* fontname;
+    exdot_op* op;
+    int i;
+
+    op = (exdot_op*)(xd->ops);
+    for (i = 0; i < xd->cnt; i++) {
+	switch (op->op.kind) {
+	case xd_filled_ellipse :
+	case xd_unfilled_ellipse :
+    	    if (!boxf_overlap(op->bb, job->clip)) continue;
+	    pts[0].x = op->op.u.ellipse.x - op->op.u.ellipse.w;
+	    pts[0].y = op->op.u.ellipse.y - op->op.u.ellipse.h;
+	    pts[1].x = op->op.u.ellipse.w;
+	    pts[1].y = op->op.u.ellipse.h;
+	    gvrender_ellipse(job, pts, 2, op->op.kind == xd_filled_ellipse);
+	    break;
+	case xd_filled_polygon :
+	case xd_unfilled_polygon :
+    	    if (!boxf_overlap(op->bb, job->clip)) continue;
+	    pts = copyPts (pts, &ptsize, op->op.u.polygon.pts, op->op.u.polygon.cnt);
+	    gvrender_polygon(job, pts, op->op.u.polygon.cnt, op->op.kind == xd_filled_polygon);
+	    break;
+	case xd_filled_bezier :
+	case xd_unfilled_bezier :
+    	    if (!boxf_overlap(op->bb, job->clip)) continue;
+	    pts = copyPts (pts, &ptsize, op->op.u.bezier.pts, op->op.u.bezier.cnt);
+	    gvrender_beziercurve(job, pts, op->op.u.bezier.cnt, 0, 0, op->op.kind == xd_filled_bezier);
+	    break;
+	case xd_polyline :
+    	    if (!boxf_overlap(op->bb, job->clip)) continue;
+	    pts = copyPts (pts, &ptsize, op->op.u.polyline.pts, op->op.u.polyline.cnt);
+	    gvrender_polyline(job, pts, op->op.u.polyline.cnt);
+	    break;
+	case xd_text :
+    	    if (!boxf_overlap(op->bb, job->clip)) continue;
+	    pts[0].x = op->op.u.text.x;
+	    pts[0].y = op->op.u.text.y;
+	    gvrender_textpara(job, pts[0], op->para);
+	    break;
+	case xd_fill_color :
+            gvrender_set_fillcolor(job, op->op.u.color);
+	    break;
+	case xd_pen_color :
+            gvrender_set_pencolor(job, op->op.u.color);
+	    break;
+	case xd_font :
+	    fontsize = op->op.u.font.size;
+	    fontname = op->op.u.font.name;
+	    break;
+	case xd_style :
+	    break;
+	case xd_image :
+	    if (image_warn) {
+	        agerr(AGWARN, "Images unsupported in \"background\" attribute\n");
+	        image_warn = 0;
+	    }
+	    break;
+	}
+	op++;
+    }
+    free (pts);
+}
+
 static void emit_background(GVJ_t * job, graph_t *g)
 {
+    xdot* xd;
     char *str;
     
     /* if no bgcolor specified - first assume default of "white" */
@@ -837,6 +952,9 @@ static void emit_background(GVJ_t * job, graph_t *g)
         gvrender_set_pencolor(job, str);
         gvrender_box(job, job->clip, TRUE);	/* filled */
     }
+
+    if ((xd = (xdot*)GD_drawing(g)->xdots))
+	emit_xdot (job, xd);
 }
 
 static void setup_page(GVJ_t * job, graph_t * g)
@@ -860,11 +978,6 @@ static void setup_page(GVJ_t * job, graph_t * g)
     else
         EXPANDBB(job->boundingBox, job->pageBoundingBox);
 
-#ifdef WITH_CODEGENS
-    job->pageOffset.x = - job->pageSize.x * pagesArrayElem.x;
-    job->pageOffset.y = - job->pageSize.y * pagesArrayElem.y;
-#endif
-
     if (job->flags & GVDEVICE_EVENTS) {
         job->clip.LL.x = job->focus.x - job->view.x / 2.;
         job->clip.LL.y = job->focus.y - job->view.y / 2.;
@@ -1191,28 +1304,26 @@ static void emit_begin_node(GVJ_t * job, node_t * n)
         obj->url_map_n = nump;
     }
 
-#ifdef WITH_CODEGENS
-    Obj = NODE;
-#endif
     setColorScheme (agget (n, "colorscheme"));
-    gvrender_begin_context(job);
     gvrender_begin_node(job, n);
 }
 
 static void emit_end_node(GVJ_t * job)
 {
     gvrender_end_node(job);
-    gvrender_end_context(job);
-#ifdef WITH_CODEGENS
-    Obj = NONE;
-#endif
     pop_obj_state(job);
 }
 
+/* emit_node:
+ */
 static void emit_node(GVJ_t * job, node_t * n)
 {
     GVC_t *gvc = job->gvc;
     char *s;
+    char *style;
+    char **styles = 0;
+    char **sp;
+    char *p;
 
     if (ND_shape(n) 				     /* node has a shape */
 	    && node_in_layer(job, agraphof(n), n)    /* and is in layer */
@@ -1226,8 +1337,19 @@ static void emit_node(GVJ_t * job, node_t * n)
 	if (s[0])
 	    gvrender_comment(job, s);
         
+	style = late_string(n, N_style, "");
+	if (style[0]) {
+	    styles = parse_style(style);
+	    sp = styles;
+	    while ((p = *sp++)) {
+		if (streq(p, "invis")) return;
+	    }
+	}
+
 	emit_begin_node(job, n);
 	ND_shape(n)->fns->codefn(job, n);
+	if (ND_xlabel(n))
+	    emit_label(job, EMIT_NLABEL, ND_xlabel(n));
 	emit_end_node(job);
     }
 }
@@ -1515,6 +1637,10 @@ static boolean edge_in_box(edge_t *e, boxf b)
     if (lp && overlap_label(lp, b))
         return TRUE;
 
+    lp = ED_xlabel(e);
+    if (lp && overlap_label(lp, b))
+        return TRUE;
+
     return FALSE;
 }
 
@@ -1563,7 +1689,9 @@ static void emit_begin_edge(GVJ_t * job, edge_t * e, char** styles)
     if (flags & GVRENDER_DOES_LABELS) {
 	if ((lab = ED_label(e)))
 	    obj->label = lab->text;
-	obj->taillabel = obj->headlabel = obj->label;
+	obj->taillabel = obj->headlabel = obj->xlabel = obj->label;
+	if ((tlab = ED_xlabel(e)))
+	    obj->xlabel = tlab->text;
 	if ((tlab = ED_tail_label(e)))
 	    obj->taillabel = tlab->text;
 	if ((hlab = ED_head_label(e)))
@@ -1690,10 +1818,6 @@ static void emit_begin_edge(GVJ_t * job, edge_t * e, char** styles)
 	}
     }
 
-#ifdef WITH_CODEGENS
-    Obj = EDGE;
-#endif
-    gvrender_begin_context(job);
     gvrender_begin_edge(job, e);
     if (obj->url || obj->explicit_tooltip)
 	gvrender_begin_anchor(job,
@@ -1827,6 +1951,10 @@ static void emit_end_edge(GVJ_t * job)
 	obj->explicit_labeltooltip, 
 	obj->labelurl, obj->labeltooltip, obj->labeltarget, obj->id, 
 	((mapbool(late_string(e, E_decorate, "false")) && ED_spl(e)) ? ED_spl(e) : 0));
+    emit_edge_label(job, ED_xlabel(e), EMIT_ELABEL,
+	obj->explicit_labeltooltip, 
+	obj->labelurl, obj->labeltooltip, obj->labeltarget, obj->id, 
+	((mapbool(late_string(e, E_decorate, "false")) && ED_spl(e)) ? ED_spl(e) : 0));
     emit_edge_label(job, ED_head_label(e), EMIT_HLABEL, 
 	obj->explicit_headtooltip,
 	obj->headurl, obj->headtooltip, obj->headtarget, obj->id,
@@ -1837,10 +1965,6 @@ static void emit_end_edge(GVJ_t * job)
 	0);
 
     gvrender_end_edge(job);
-    gvrender_end_context(job);
-#ifdef WITH_CODEGENS
-    Obj = NONE;
-#endif
     pop_obj_state(job);
 }
 
@@ -1888,6 +2012,147 @@ static void emit_edge(GVJ_t * job, edge_t * e)
     }
 }
 
+static char adjust[] = {'l', 'n', 'r'};
+
+static void
+expandBB (boxf* bb, pointf p)
+{
+    if (p.x > bb->UR.x)
+	bb->UR.x = p.x;
+    if (p.x < bb->LL.x)
+	bb->LL.x = p.x;
+    if (p.y > bb->UR.y)
+	bb->UR.y = p.y;
+    if (p.y < bb->LL.y)
+	bb->LL.y = p.y;
+}
+
+static boxf
+ptsBB (xdot_point* inpts, int numpts, boxf* bb)
+{
+    boxf opbb;
+    int i;
+
+    opbb.LL.x = opbb.UR.x = inpts->x;
+    opbb.LL.y = opbb.UR.y = inpts->y;
+    for (i = 1; i < numpts; i++) {
+	inpts++;
+	if (inpts->x < opbb.LL.x)
+	    opbb.LL.x = inpts->x;
+	else if (inpts->x > opbb.UR.x)
+	    opbb.UR.x = inpts->x;
+	if (inpts->y < opbb.LL.y)
+	    opbb.LL.y = inpts->y;
+	else if (inpts->y > opbb.UR.y)
+	    opbb.UR.y = inpts->y;
+
+    }
+    expandBB (bb, opbb.LL);
+    expandBB (bb, opbb.UR);
+    return opbb;
+}
+
+static boxf
+textBB (double x, double y, textpara_t* para)
+{
+    boxf bb;
+    double wd = para->width;
+    double ht = para->height;
+
+    switch (para->just) {
+    case 'l':
+	bb.LL.x = x;
+	bb.UR.x = bb.LL.x + wd;
+	break; 
+    case 'n':
+	bb.LL.x = x - wd/2.0; 
+	bb.UR.x = x + wd/2.0; 
+	break; 
+    case 'r':
+	bb.UR.x = x; 
+	bb.LL.x = bb.UR.x - wd;
+	break; 
+    }
+    bb.UR.y = y + para->yoffset_layout;
+    bb.LL.y = bb.UR.y - ht;
+    return bb;
+}
+
+static void
+freePara (exdot_op* op)
+{
+    if (op->op.kind == xd_text)
+	free_textpara (op->para);
+}
+
+boxf xdotBB (Agraph_t* g)
+{
+    exdot_op* op;
+    int i;
+    double fontsize;
+    char* fontname;
+    pointf pts[2];
+    pointf sz;
+    boxf bb0;
+    boxf bb = GD_bb(g);
+    xdot* xd = (xdot*)GD_drawing(g)->xdots;
+
+    if (!xd) return bb;
+
+    if ((bb.LL.x == bb.UR.x) && (bb.LL.y == bb.UR.y)) {
+	bb.LL.x = bb.LL.y = MAXDOUBLE;
+	bb.UR.x = bb.UR.y = -MAXDOUBLE;
+    }
+
+    op = (exdot_op*)(xd->ops);
+    for (i = 0; i < xd->cnt; i++) {
+	switch (op->op.kind) {
+	case xd_filled_ellipse :
+	case xd_unfilled_ellipse :
+	    pts[0].x = op->op.u.ellipse.x - op->op.u.ellipse.w;
+	    pts[0].y = op->op.u.ellipse.y - op->op.u.ellipse.h;
+	    pts[1].x = op->op.u.ellipse.x + op->op.u.ellipse.w;
+	    pts[1].y = op->op.u.ellipse.y + op->op.u.ellipse.h;
+	    op->bb.LL = pts[0];
+	    op->bb.UR = pts[1];
+	    expandBB (&bb, pts[0]);
+	    expandBB (&bb, pts[1]);
+	    break;
+	case xd_filled_polygon :
+	case xd_unfilled_polygon :
+	    op->bb = ptsBB (op->op.u.polygon.pts, op->op.u.polygon.cnt, &bb);
+	    break;
+	case xd_filled_bezier :
+	case xd_unfilled_bezier :
+	    op->bb = ptsBB (op->op.u.polygon.pts, op->op.u.polygon.cnt, &bb);
+	    break;
+	case xd_polyline :
+	    op->bb = ptsBB (op->op.u.polygon.pts, op->op.u.polygon.cnt, &bb);
+	    break;
+	case xd_text :
+	    op->para = NEW(textpara_t);
+	    op->para->str = strdup (op->op.u.text.text);
+	    op->para->just = adjust [op->op.u.text.align];
+	    sz = textsize (g, op->para, fontname, fontsize);
+	    bb0 = textBB (op->op.u.text.x, op->op.u.text.y, op->para);
+	    op->bb = bb0;
+	    expandBB (&bb, bb0.LL);
+	    expandBB (&bb, bb0.UR);
+	    if (!xd->freefunc)
+		xd->freefunc = (freefunc_t)freePara;
+	    break;
+	case xd_font :
+	    fontsize = op->op.u.font.size;
+	    fontname = op->op.u.font.name;
+	    break;
+	default :
+	    break;
+	}
+	op++;
+    }
+    return bb;
+}
+
 static void init_gvc(GVC_t * gvc, graph_t * g)
 {
     double xf, yf;
@@ -1937,6 +2202,7 @@ static void init_gvc(GVC_t * gvc, graph_t * g)
     if ((p = agget(g, "pagedir")) && p[0])
             gvc->pagedir = p;
 
+
     /* bounding box */
     gvc->bb = GD_bb(g);
 
@@ -2037,15 +2303,16 @@ static void init_job_dpi(GVJ_t *job, graph_t *g)
 static void init_job_viewport(GVJ_t * job, graph_t * g)
 {
     GVC_t *gvc = job->gvc;
-    pointf UR, size, sz;
+    pointf LL, UR, size, sz;
     double X, Y, Z, x, y;
     int rv;
     Agnode_t *n;
     char *str, *nodename = NULL, *junk = NULL;
 
     UR = gvc->bb.UR;
-    job->bb.LL.x = -job->pad.x;           /* job->bb is bb of graph and padding - graph units */
-    job->bb.LL.y = -job->pad.y;
+    LL = gvc->bb.LL;
+    job->bb.LL.x = LL.x - job->pad.x;           /* job->bb is bb of graph and padding - graph units */
+    job->bb.LL.y = LL.y - job->pad.y;
     job->bb.UR.x = UR.x + job->pad.x;
     job->bb.UR.y = UR.y + job->pad.y;
     sz.x = job->bb.UR.x - job->bb.LL.x;   /* size, including padding - graph units */
@@ -2065,8 +2332,8 @@ static void init_job_viewport(GVJ_t * job, graph_t * g)
     }
     
     /* default focus, in graph units = center of bb */
-    x = UR.x / 2.;
-    y = UR.y / 2.;
+    x = (LL.x + UR.x) / 2.;
+    y = (LL.y + UR.y) / 2.;
 
     /* rotate and scale bb to give default absolute size in points*/
     job->rotation = job->gvc->rotation;
@@ -2246,24 +2513,17 @@ static void emit_begin_graph(GVJ_t * job, graph_t * g)
     initObjMapData (job, GD_label(g), "graph", AGID(g), g);
 #endif
 
-#ifdef WITH_CODEGENS
-    Obj = NONE;
-#endif
     gvrender_begin_graph(job, g);
 }
 
 static void emit_end_graph(GVJ_t * job, graph_t * g)
 {
     gvrender_end_graph(job);
-#ifdef WITH_CODEGENS
-    Obj = NONE;
-#endif
     pop_obj_state(job);
 }
 
 static void emit_page(GVJ_t * job, graph_t * g)
 {
-    GVC_t *gvc = job->gvc;
     obj_state_t *obj = job->obj;
     int nump = 0, flags = job->flags;
     textlabel_t *lab;
@@ -2274,7 +2534,6 @@ static void emit_page(GVJ_t * job, graph_t * g)
     gvrender_begin_page(job);
     gvrender_set_pencolor(job, DEFAULT_COLOR);
     gvrender_set_fillcolor(job, DEFAULT_FILL);
-    gvrender_set_font(job, gvc->defaultfontname, gvc->defaultfontsize);
     if ((flags & (GVRENDER_DOES_MAPS | GVRENDER_DOES_TOOLTIPS))
 	    && (obj->url || obj->explicit_tooltip)) {
 	if (flags & (GVRENDER_DOES_MAP_RECTANGLE | GVRENDER_DOES_MAP_POLYGON)) {
@@ -2468,18 +2727,12 @@ static void emit_begin_cluster(GVJ_t * job, Agraph_t * sg)
     initObjMapData (job, GD_label(sg), "graph", AGID(sg), sg);
 #endif
     
-#ifdef WITH_CODEGENS
-    Obj = CLST;
-#endif
     gvrender_begin_cluster(job, sg);
 }
 
 static void emit_end_cluster(GVJ_t * job, Agraph_t * g)
 {
     gvrender_end_cluster(job, g);
-#ifdef WITH_CODEGENS
-    Obj = NONE;
-#endif
     pop_obj_state(job);
 }
 
@@ -2507,7 +2760,6 @@ void emit_clusters(GVJ_t * job, Agraph_t * g, int flags)
 	obj = job->obj;
 	doAnchor = (obj->url || obj->explicit_tooltip);
 	setColorScheme (agget (sg, "colorscheme"));
-	gvrender_begin_context(job);
 	if (doAnchor && !(flags & EMIT_CLUSTERS_LAST)) {
 	    emit_map_rect(job, GD_bb(sg));
 	    gvrender_begin_anchor(job, obj->url, obj->tooltip, obj->target, obj->id);
@@ -2541,17 +2793,20 @@ void emit_clusters(GVJ_t * job, Agraph_t * g, int flags)
 	    filled = TRUE;
 	}
 	else {
+	    if (((color = agget(sg, "color")) != 0) && color[0])
+		fillcolor = pencolor = color;
 	    if (((color = agget(sg, "pencolor")) != 0) && color[0])
 		pencolor = color;
-	    else if (((color = agget(sg, "color")) != 0) && color[0])
-		fillcolor = pencolor = color;
-	    /* bgcolor is supported for backward compatability */
-	    else if (((color = agget(sg, "bgcolor")) != 0) && color[0]) {
+	    if (((color = agget(sg, "fillcolor")) != 0) && color[0])
+		fillcolor = color;
+	    /* bgcolor is supported for backward compatability 
+	       if fill is set, fillcolor trumps bgcolor, so
+               don't bother checking.
+             */
+	    if (!filled && ((color = agget(sg, "bgcolor")) != 0) && color[0]) {
 		fillcolor = color;
 	        filled = TRUE;
             }
-	    if (((color = agget(sg, "fillcolor")) != 0) && color[0])
-		fillcolor = color;
 	}
 	if (!pencolor) pencolor = DEFAULT_COLOR;
 	if (!fillcolor) fillcolor = DEFAULT_FILL;
@@ -2573,7 +2828,7 @@ void emit_clusters(GVJ_t * job, Agraph_t * g, int flags)
 		AF[1].y = AF[0].y;
 		AF[3].x = AF[0].x;
 		AF[3].y = AF[2].y;
-		round_corners(job, fillcolor, pencolor, AF, 4, istyle);
+		round_corners(job, fillcolor, pencolor, AF, 4, istyle,istyle & FILLED);
 	    }
 	}
 	else {
@@ -2605,7 +2860,6 @@ void emit_clusters(GVJ_t * job, Agraph_t * g, int flags)
 		    emit_edge(job, e);
 	    }
 	}
-	gvrender_end_context(job);
 	emit_end_cluster(job, g);
 	/* when drawing, lay down clusters before sub_clusters */
 	if (!(flags & EMIT_CLUSTERS_LAST))
@@ -2844,6 +3098,36 @@ extern gvevent_key_binding_t gvevent_key_binding[];
 extern int gvevent_key_binding_size;
 extern gvdevice_callbacks_t gvdevice_callbacks;
 
+/* gv_fixLocale:
+ * Set LC_NUMERIC to "C" to get expected interpretation of %f
+ * in printf functions. Languages like postscript and dot expect
+ * floating point numbers to use a decimal point.
+ * 
+ * If set is non-zero, the "C" locale set;
+ * if set is zero, the original locale is reset.
+ * Calls to the function can nest.
+ */
+void gv_fixLocale (int set)
+{
+    static char* save_locale;
+    static int cnt;
+
+    if (set) {
+	cnt++;
+	if (cnt == 1) {
+	    save_locale = strdup (setlocale (LC_NUMERIC, NULL));
+	    setlocale (LC_NUMERIC, "C");
+	}
+    }
+    else if (cnt > 0) {
+	cnt--;
+	if (cnt == 0) {
+	    setlocale (LC_NUMERIC, save_locale);
+	    free (save_locale);
+	}
+    }
+}
+
 int gvRenderJobs (GVC_t * gvc, graph_t * g)
 {
     static GVJ_t *prevjob;
@@ -2860,6 +3144,7 @@ int gvRenderJobs (GVC_t * gvc, graph_t * g)
 
     gvc->keybindings = gvevent_key_binding;
     gvc->numkeys = gvevent_key_binding_size;
+    gv_fixLocale (1);
     for (job = gvjobs_first(gvc); job; job = gvjobs_next(gvc)) {
 	if (gvc->gvg) {
 	    job->input_filename = gvc->gvg->input_filename;
@@ -2873,17 +3158,16 @@ int gvRenderJobs (GVC_t * gvc, graph_t * g)
 	job->layout_type = gvc->layout.type;
 	if (!GD_drawing(g)) {
 	    agerr (AGERR, "layout was not done\n");
+	    gv_fixLocale (0);
 	    return -1;
 	}
 
         job->output_lang = gvrender_select(job, job->output_langname);
         if (job->output_lang == NO_SUPPORT) {
             agerr (AGERR, "renderer for %s is unavailable\n", job->output_langname);
+	    gv_fixLocale (0);
             return -1;
         }
-#ifdef WITH_CODEGENS
-	Output_lang = job->output_lang;
-#endif
 
         switch (job->output_lang) {
         case VTX:
@@ -2945,9 +3229,10 @@ int gvRenderJobs (GVC_t * gvc, graph_t * g)
 	}
 
         /* the last job, after all input graphs are processed,
-         *      is finalized from gvFreeContext()
+         *      is finalized from gvFinalize()
          */
 	prevjob = job;
     }
+    gv_fixLocale (0);
     return 0;
 }
