@@ -1,4 +1,4 @@
-/* $Id: geom.c,v 1.29 2009/01/21 16:47:00 arif Exp $ $Revision: 1.29 $ */
+/* $Id: geom.c,v 1.33 2009/12/04 21:08:05 arif Exp $ $Revision: 1.33 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -17,6 +17,10 @@
 /* geometric functions (e.g. on points and boxes) with application to, but
  * no specific dependance on graphs */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "geom.h"
 #include "geomprocs.h"
 #ifdef WIN32
@@ -407,6 +411,7 @@ double ptToLine2 (pointf a, pointf b, pointf p)
  */
 int line_intersect (pointf a, pointf b, pointf c, pointf d, pointf* p)
 {
+
     pointf mv = sub_pointf(b,a);
     pointf lv = sub_pointf(d,c);
     pointf ln = perp (lv);
