@@ -1,4 +1,4 @@
-/* $Id: htmltable.c,v 1.73 2009/02/18 13:36:50 glenlow Exp $ $Revision: 1.73 $ */
+/* $Id: htmltable.c,v 1.82 2009/12/05 22:33:14 erg Exp $ $Revision: 1.82 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -17,7 +17,7 @@
 
 /* Implementation of HTML-like tables.
  * 
- * The CodeGen graphics model, especially with integral coodinates, is
+ * The (now purged) CodeGen graphics model, especially with integral coodinates, is
  * not adequate to handle this as we would like. In particular, it is
  * difficult to handle notions of adjacency and correct rounding to pixels.
  * For example, if 2 adjacent boxes bb1.UR.x == bb2.LL.x, the rectangles
@@ -112,7 +112,7 @@ static void popFontInfo(htmlenv_t * env, htmlfont_t * savp)
 
 static void 
 emit_htextparas(GVJ_t* job, int nparas, htextpara_t* paras, pointf p,
-         double halfwidth_x, char* fname, double fsize, char* fcolor, boxf b)
+         double halfwidth_x, htmlfont_t finfo, boxf b)
 {
     int i,j;
     double center_x, left_x, right_x, fsize_;
@@ -130,8 +130,7 @@ emit_htextparas(GVJ_t* job, int nparas, htextpara_t* paras, pointf p,
 	 */
     p_.y = p.y + (b.UR.y-b.LL.y)/2.0;
 
- 	gvrender_begin_label(job, LABEL_HTML);
-    gvrender_begin_context(job);
+    gvrender_begin_label(job, LABEL_HTML);
     for(i=0; i<nparas; i++) {
 	/* set p.x to leftmost point where the line of text begins */
 	switch (paras[i].just) {
@@ -153,18 +152,17 @@ emit_htextparas(GVJ_t* job, int nparas, htextpara_t* paras, pointf p,
 	    if (ti->font && (ti->font->size > 0))
 		fsize_ = ti->font->size;
 	    else
-	        fsize_ = fsize;
+	        fsize_ = finfo.size;
 	    if (ti->font && ti->font->name)
 		fname_ = ti->font->name;
 	    else
-	        fname_ = fname;
+	        fname_ = finfo.name;
 	    if (ti->font && ti->font->color)
 		fcolor_ = ti->font->color;
 	    else
-	        fcolor_ = fcolor;
+	        fcolor_ = finfo.color;
 
     	    gvrender_set_pencolor(job, fcolor_);
-   	    gvrender_set_font(job, fname_, fsize_);
 
 	    tl.str = ti->str;
 	    tl.fontname = fname_;
@@ -175,21 +173,15 @@ emit_htextparas(GVJ_t* job, int nparas, htextpara_t* paras, pointf p,
 	    tl.layout = ti->layout;
 	    tl.width = ti->size;
 	    tl.height = paras[i].lfsize;
-
 	    tl.just = 'l';
+
 	    p_.x = p.x;
-#if 0
-/* or */
-	    tl.just = 'c';
-	    p_.x = p.x + (ti->size/2.0);
-#endif
 	    gvrender_textpara(job, p_, &tl);
 	    p.x += ti->size;
             ti++;
 	}
     }
 
-	gvrender_end_context(job);
     gvrender_end_label(job);
 }
 
@@ -198,24 +190,16 @@ emit_html_txt(GVJ_t* job, htmltxt_t* tp, htmlenv_t* env)
 {
     double halfwidth_x;
     pointf p;
-    char *fname;
-    char *fcolor;
-    double fsize;
 
     /* make sure that there is something to do */
     if (tp->nparas < 1)
 	return;
 
-    fsize = env->finfo.size;
-    fname = env->finfo.name;
-    fcolor = env->finfo.color;
-
     halfwidth_x = ((double) (tp->box.UR.x - tp->box.LL.x)) / 2.0;
     p.x = env->pos.x + ((double) (tp->box.UR.x + tp->box.LL.x)) / 2.0;
     p.y = env->pos.y + ((double) (tp->box.UR.y + tp->box.LL.y)) / 2.0;
 
-    emit_htextparas(job, tp->nparas, tp->paras, p, halfwidth_x, fname,
-		    fsize, fcolor, tp->box);
+    emit_htextparas(job, tp->nparas, tp->paras, p, halfwidth_x, env->finfo, tp->box);
 }
 
 static void doSide(GVJ_t * job, pointf p, double wd, double ht)
@@ -243,10 +227,8 @@ static void doBorder(GVJ_t * job, char *color, int border, boxf BF)
     pointf pt;
     double wd, ht;
 
-    gvrender_begin_context(job);
-
     if (!color)
-	color = "black";
+	color = DEFAULT_COLOR;
     gvrender_set_fillcolor(job, color);
     gvrender_set_pencolor(job, color);
 
@@ -265,8 +247,6 @@ static void doBorder(GVJ_t * job, char *color, int border, boxf BF)
 	pt.y = BF.LL.y;
 	doSide(job, pt, -wd, border);
     }
-
-    gvrender_end_context(job);
 }
 
 static void doFill(GVJ_t * job, char *color, boxf BF)
@@ -483,27 +463,15 @@ allocObj (GVJ_t * job)
     switch (obj->type) {
     case NODE_OBJTYPE :
 	obj->u.n = parent->u.n;
-#ifdef WITH_CODEGENS
-	Obj = NODE;
-#endif
 	break;
     case ROOTGRAPH_OBJTYPE :
 	obj->u.g = parent->u.g;
-#ifdef WITH_CODEGENS
-	Obj = NONE;
-#endif
 	break;
     case CLUSTER_OBJTYPE :
 	obj->u.sg = parent->u.sg;
-#ifdef WITH_CODEGENS
-	Obj = CLST;
-#endif
 	break;
     case EDGE_OBJTYPE :
 	obj->u.e = parent->u.e;
-#ifdef WITH_CODEGENS
-	Obj = EDGE;
-#endif
 	break;
     }
     obj->url = parent->url;
@@ -543,7 +511,6 @@ emit_html_label(GVJ_t * job, htmllabel_t * lp, textlabel_t * tp)
 	htmltbl_t *tbl = lp->u.tbl;
 
 	/* set basic graphics context */
-	gvrender_begin_context(job);
 	/* Need to override line style set by node. */
 	gvrender_set_style(job, job->gvc->defaultlinestyle);
 	if (tbl->data.pencolor)
@@ -551,7 +518,6 @@ emit_html_label(GVJ_t * job, htmllabel_t * lp, textlabel_t * tp)
 	else
 	    gvrender_set_pencolor(job, DEFAULT_COLOR);
 	emit_html_tbl(job, tbl, &env);
-	gvrender_end_context(job);
     } else {
 	emit_html_txt(job, lp->u.txt, &env);
     }
@@ -1203,7 +1169,7 @@ void makeGraphs(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
             x += minc[cp->col + c];
 	ED_minlen(e) = x;
 	/* ED_minlen(e) = cp->data.box.UR.x; */
-#ifdef DEBUG
+#if (DEBUG==2)
 	fprintf(stderr, "col edge %s -> %s %d\n", t->name, h->name,
 		ED_minlen(e));
 #endif
@@ -1222,7 +1188,7 @@ void makeGraphs(htmltbl_t * tbl, graph_t * rowg, graph_t * colg)
             y += minr[cp->row + r];
 	ED_minlen(e) = y;
 	/* ED_minlen(e) = cp->data.box.UR.y; */
-#ifdef DEBUG
+#if (DEBUG==2)
 	fprintf(stderr, "row edge %s -> %s %d\n", agnameof(t), agnameof(h),
 		ED_minlen(e));
 #endif
@@ -1333,8 +1299,8 @@ static void pos_html_cell(htmlcell_t * cp, boxf pos, int sides)
     pointf oldsz;
     boxf cbox;
 
-    if (!cp->data.pencolor)
-	cp->data.pencolor = cp->parent->data.pencolor;
+    if (!cp->data.pencolor && cp->parent->data.pencolor)
+	cp->data.pencolor = strdup(cp->parent->data.pencolor);
 
     /* If fixed, align cell */
     if (cp->data.flags & FIXED_FLAG) {
@@ -1451,14 +1417,14 @@ static void pos_html_cell(htmlcell_t * cp, boxf pos, int sides)
  */
 static void pos_html_tbl(htmltbl_t * tbl, boxf pos, int sides)
 {
-    double x, y, delx, dely, extra, oldsz;
-    int i, plus;
+    int x, y, delx, dely, oldsz;
+    int i, extra, plus;
     htmlcell_t **cells = tbl->u.n.cells;
     htmlcell_t *cp;
     boxf cbox;
 
-    if (tbl->u.n.parent && !tbl->data.pencolor)
-	tbl->data.pencolor = tbl->u.n.parent->data.pencolor;
+    if (tbl->u.n.parent && tbl->u.n.parent->data.pencolor && !tbl->data.pencolor)
+	tbl->data.pencolor = strdup (tbl->u.n.parent->data.pencolor);
 
     oldsz = tbl->data.box.UR.x;
     delx = (pos.UR.x - pos.LL.x) - oldsz;
@@ -1702,7 +1668,7 @@ void printTbl(htmltbl_t * tbl, int ind)
 {
     htmlcell_t **cells = tbl->u.n.cells;
     indent(ind);
-    fprintf(stderr, "tbl %d %d ", tbl->cc, tbl->rc);
+    fprintf(stderr, "tbl (%x) %d %d ", tbl, tbl->cc, tbl->rc);
     printData(&tbl->data);
     fputs("\n", stderr);
     while (*cells)
