@@ -1,4 +1,4 @@
-/* $Id: htmltable.h,v 1.27 2008/09/10 02:51:34 ellson Exp $ $Revision: 1.27 $ */
+/* $Id: htmltable.h,v 1.32 2009/07/14 13:18:07 ellson Exp $ $Revision: 1.32 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -38,6 +38,11 @@ extern "C" {
 
 #define UNSET_ALIGN 0
 
+/* Bold, Italic, Underline */
+#define HTML_BF 1
+#define HTML_IF 2
+#define HTML_UL 4
+
     /* font information
      * If name or color is NULL, or size < 0, that attribute
      * is unspecified. 
@@ -45,8 +50,9 @@ extern "C" {
     typedef struct {
 	char*  name;
 	char*  color;
-	double size;
+        int    flags:7;  /* HTML_UL, HTML_IF, HTML_BF */
 	int    cnt;   /* reference count */
+	double size;
     } htmlfont_t;
 
     /* paras of text within a cell
@@ -54,7 +60,7 @@ extern "C" {
      * This translation is done when libexpat scans the input.
      */
 	
-	/* atomic unit of text emitted using a single htmlfont_t */
+    /* atomic unit of text emitted using a single htmlfont_t */
     typedef struct {
 	char *str;
 	PostscriptAlias *postscript_alias;
@@ -64,7 +70,7 @@ extern "C" {
 	double size, yoffset_layout, yoffset_centerline;
     } textitem_t;
 	
-	/* line of textitems_t */
+    /* line of textitems_t */
     typedef struct {
 	textitem_t *items;
 	short nitems;
