@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.94 2009/02/11 20:09:28 ellson Exp $ $Revision: 1.94 $ */
+/* $Id: input.c,v 1.112 2009/12/01 16:52:08 ellson Exp $ $Revision: 1.112 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -18,6 +18,8 @@
 #include "render.h"
 #include "htmltable.h"
 #include "gvc.h"
+#include "xdot.h"
+#include "agxbuf.h"
 
 static char *usageFmt =
     "Usage: %s [-Vv?] [-(GNE)name=val] [-(KTlso)<val>] <dot files>\n";
@@ -168,7 +170,7 @@ static void use_library(GVC_t *gvc, const char *name)
 }
 
 #ifdef WITH_CGRAPH
-static void global_def(char *dcl, int kind,
+static void global_def(agxbuf* xb, char *dcl, int kind,
          attrsym_t * ((*dclfun) (Agraph_t *, int kind, char *, char *)) )
 {
     char *p;
@@ -176,14 +178,16 @@ static void global_def(char *dcl, int kind,
 
     attrsym_t *sym;
     if ((p = strchr(dcl, '='))) {
-        *p++ = '\0';
-        rhs = p;
+	agxbput_n (xb, dcl, p-dcl);
+        rhs = p+1;
     }
-    sym = dclfun(NULL, kind, dcl, rhs);
+    else
+	agxbput (xb, dcl);
+    sym = dclfun(NULL, kind, agxbuse (xb), rhs);
     sym->fixed = 1;
 }
 #else
-static void global_def(char *dcl,
+static void global_def(agxbuf* xb, char *dcl,
 	attrsym_t * ((*dclfun) (Agraph_t *, char *, char *)))
 {
     char *p;
@@ -191,10 +195,12 @@ static void global_def(char *dcl,
 
     attrsym_t *sym;
     if ((p = strchr(dcl, '='))) {
-	*p++ = '\0';
-	rhs = p;
+	agxbput_n (xb, dcl, p-dcl);
+        rhs = p+1;
     }
-    sym = dclfun(NULL, dcl, rhs);
+    else
+	agxbput (xb, dcl);
+    sym = dclfun(NULL, agxbuse (xb), rhs);
     sym->fixed = 1;
 }
 #endif
@@ -226,9 +232,11 @@ graph_t *gvPluginsGraph(GVC_t *gvc)
 
 void dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 {
-    char c, *rest;
+    char c, *rest, *layout;
     const char *val;
     int i, v, nfiles;
+    unsigned char buf[SMALLBUF];
+    agxbuf xb;
 
     /* establish if we are running in a CGI environment */
     HTTPServerEnVar = getenv("SERVER_NAME");
@@ -243,16 +251,29 @@ void dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 	    gvc->common.info[1], gvc->common.info[2]);
     }
 
-    /* configure for available plugins and codegens */
-		/* needs to know if "dot -c" is set (gvc->common.config) */
-		/* must happen before trying to select any plugins */
+    /* configure for available plugins */
+    /* needs to know if "dot -c" is set (gvc->common.config) */
+    /* must happen before trying to select any plugins */
     gvconfig(gvc, gvc->common.config);
     if (gvc->common.config)
 	exit (0);
 
-    i = gvlayout_select(gvc, gvc->common.cmdname);
-    if (i == NO_SUPPORT)
-	gvlayout_select(gvc, "dot");
+    layout = gvc->common.cmdname;
+    if (streq(layout, "dot_static")
+	    || streq(layout, "dot_builtins")
+	    || streq(layout, "lt-dot_builtins")
+	    || streq(layout, "")   /* when run as a process from Gvedit on Windows */
+	)
+        layout = "dot";
+    i = gvlayout_select(gvc, layout);
+    if (i == NO_SUPPORT) {
+	fprintf(stderr, "There is no layout engine support for \"%s\"\n", layout);
+        if (streq(layout, "dot"))
+	    fprintf(stderr, "Perhaps \"dot -c\" needs to be run (with installer's privileges) to register the plugins?\n");
+	else 
+	    fprintf(stderr, "Use one of:%s\n", gvplugin_list(gvc, API_layout, ""));
+	exit(1);
+    }
 
     /* feed the globals */
     Verbose = gvc->common.verbose;
@@ -267,6 +288,7 @@ void dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 	    nfiles++;
     gvc->input_filenames = N_NEW(nfiles + 1, char *);
     nfiles = 0;
+    agxbinit(&xb, SMALLBUF, buf);
     for (i = 1; i < argc; i++) {
 	if (argv[i] && argv[i][0] == '-') {
 	    rest = &(argv[i][2]);
@@ -274,9 +296,9 @@ void dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 	    case 'G':
 		if (*rest)
 #ifdef WITH_CGRAPH
-		    global_def(rest, AGRAPH, agattr);
+		    global_def(&xb, rest, AGRAPH, agattr);
 #else
-		    global_def(rest, agraphattr);
+		    global_def(&xb, rest, agraphattr);
 #endif
 		else {
 		    fprintf(stderr, "Missing argument for -G flag\n");
@@ -286,9 +308,9 @@ void dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 	    case 'N':
 		if (*rest)
 #ifdef WITH_CGRAPH
-		    global_def(rest, AGNODE,agattr);
+		    global_def(&xb, rest, AGNODE,agattr);
 #else
-		    global_def(rest, agnodeattr);
+		    global_def(&xb, rest, agnodeattr);
 #endif
 		else {
 		    fprintf(stderr, "Missing argument for -N flag\n");
@@ -298,9 +320,9 @@ void dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 	    case 'E':
 		if (*rest)
 #ifdef WITH_CGRAPH
-		    global_def(rest, AGEDGE,agattr);
+		    global_def(&xb, rest, AGEDGE,agattr);
 #else
-		    global_def(rest, agedgeattr);
+		    global_def(&xb, rest, agedgeattr);
 #endif
 		else {
 		    fprintf(stderr, "Missing argument for -E flag\n");
@@ -330,9 +352,15 @@ void dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
                 }
                 v = gvlayout_select(gvc, val);
                 if (v == NO_SUPPORT) {
-                    fprintf(stderr, "Layout type: \"%s\" not recognized. Use one of:%s\n",
-                        val, gvplugin_list(gvc, API_layout, val));
-                    exit(1);
+	            fprintf(stderr, "There is no layout engine support for \"%s\"\n", val);
+                    if (streq(val, "dot")) {
+                        fprintf(stderr, "Perhaps \"dot -c\" needs to be run (with installer's privileges) to register the plugins?\n");
+                    }
+		    else {
+                        fprintf(stderr, "Use one of:%s\n",
+				gvplugin_list(gvc, API_layout, val));
+		    }
+		    exit(1);
                 }
 		break;
 	    case 'P':
@@ -400,6 +428,7 @@ void dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 	} else if (argv[i])
 	    gvc->input_filenames[nfiles++] = argv[i];
     }
+    agxbfree (&xb);
 
     /* if no -Txxx, then set default format */
     if (!gvc->jobs || !gvc->jobs->output_langname) {
@@ -413,14 +442,18 @@ void dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
     }
 
     /* set persistent attributes here (if not already set from command line options) */
-#ifndef WITH_CGRAPH
+#ifdef WITH_CGRAPH
+    if (!agattr(NULL, AGNODE, "label", 0))
+	agattr(NULL, AGNODE, "label", NODENAME_ESC);
+#else
     if (!(agfindnodeattr(agprotograph(), "label")))
 	agnodeattr(NULL, "label", NODENAME_ESC);
 #endif
 }
 
 /* getdoubles2ptf:
- * converts a graph attribute to floating graph units (POINTS).
+ * converts a graph attribute in inches to a pointf in points.
+ * If only one number is given, it is used for both x and y.
  * Returns true if the attribute ends in '!'.
  */
 static boolean getdoubles2ptf(graph_t * g, char *name, pointf * result)
@@ -439,6 +472,14 @@ static boolean getdoubles2ptf(graph_t * g, char *name, pointf * result)
 	    if (c == '!')
 		rv = TRUE;
 	}
+	else {
+	    c = '\0';
+	    i = sscanf(p, "%lf%c", &xf, &c);
+	    if ((i > 0) && (xf > 0)) {
+		result->y = result->x = POINTS(xf);
+		if (c == '!') rv = TRUE;
+	    }
+	}
     }
     return rv;
 }
@@ -541,6 +582,8 @@ graph_t *gvNextInputGraph(GVC_t *gvc)
 	    gvg_init(gvc, g, fn, gidx++);
 	    break;
 	}
+	if (fp != stdin)
+	    fclose (fp);
 	fp = NULL;
 	gidx = 0;
     }
@@ -736,6 +779,7 @@ void graph_init(graph_t * g, boolean use_rankdir)
     N_fontname = agfindnodeattr(g, "fontname");
     N_fontcolor = agfindnodeattr(g, "fontcolor");
     N_label = agfindnodeattr(g, "label");
+    N_xlabel = agfindnodeattr(g, "xlabel");
     N_showboxes = agfindnodeattr(g, "showboxes");
     N_penwidth = agfindnodeattr(g, "penwidth");
     /* attribs for polygon shapes */
@@ -760,6 +804,7 @@ void graph_init(graph_t * g, boolean use_rankdir)
     E_fontname = agfindedgeattr(g, "fontname");
     E_fontcolor = agfindedgeattr(g, "fontcolor");
     E_label = agfindedgeattr(g, "label");
+    E_xlabel = agfindedgeattr(g, "xlabel");
     E_label_float = agfindedgeattr(g, "labelfloat");
     /* vladimir */
     E_dir = agfindedgeattr(g, "dir");
@@ -784,10 +829,15 @@ void graph_init(graph_t * g, boolean use_rankdir)
     E_tailclip = agfindedgeattr(g, "tailclip");
     E_headclip = agfindedgeattr(g, "headclip");
     E_penwidth = agfindedgeattr(g, "penwidth");
+
+    /* background */
+    GD_drawing(g)->xdots = init_xdot (g);
 }
 
 void graph_cleanup(graph_t *g)
 {
+    if (GD_drawing(g)->xdots)
+	freeXDot ((xdot*)GD_drawing(g)->xdots);
     free(GD_drawing(g));
     GD_drawing(g) = NULL;
     free_label(GD_label(g));
@@ -837,7 +887,7 @@ void do_graph_label(graph_t * sg)
     int pos_ix;
 
     /* it would be nice to allow multiple graph labels in the future */
-    if ((str = agget(sg, "label"))) {
+    if ((str = agget(sg, "label")) && (*str != '\0')) {
 	char pos_flag;
 	pointf dimen;
 
