@@ -1,4 +1,4 @@
-/* $Id: labels.c,v 1.66 2009/06/03 01:10:52 ellson Exp $ $Revision: 1.66 $ */
+/* $Id: labels.c,v 1.68 2009/07/30 22:00:39 erg Exp $ $Revision: 1.68 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -184,7 +184,7 @@ textlabel_t *make_label(void *obj, char *str, int kind, double fontsize, char *f
     return rv;
 }
 
-static void free_textpara(textpara_t * tl)
+void free_textpara(textpara_t * tl)
 {
     if (tl) {
 	if (tl->str)
@@ -228,9 +228,7 @@ void emit_label(GVJ_t * job, emit_state_t emit_state, textlabel_t * lp)
 	return;
 
     gvrender_begin_label(job, LABEL_PLAIN);
-	gvrender_begin_context(job);
-	gvrender_set_pencolor(job, lp->fontcolor);
-    gvrender_set_font(job, lp->fontname, lp->fontsize);
+    gvrender_set_pencolor(job, lp->fontcolor);
 
     /* position for first para */
     switch (lp->valign) {
@@ -264,8 +262,7 @@ void emit_label(GVJ_t * job, emit_state_t emit_state, textlabel_t * lp)
 	p.y -= lp->u.txt.para[i].height;
     }
 
-    gvrender_end_context(job);
-	gvrender_end_label(job);
+    gvrender_end_label(job);
     obj->emit_state = old_emit_state;
 }
 
