@@ -1,4 +1,4 @@
-/* $Id: memory.h,v 1.5 2009/01/21 16:47:00 arif Exp $ $Revision: 1.5 $ */
+/* $Id: memory.h,v 1.8 2009/06/03 01:10:52 ellson Exp $ $Revision: 1.8 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -48,16 +48,13 @@ extern "C" {
 #ifdef GVDLL
 #define extern __declspec(dllexport)
 #else
-#define extern
-#endif
-
-/*visual studio*/
 #ifdef WIN32_DLL
 #ifndef GVC_EXPORTS
 #define extern __declspec(dllimport)
 #endif
 #endif
-/*end visual studio*/
+
+#endif
 
     extern void *zmalloc(size_t);
     extern void *zrealloc(void *, size_t, size_t, size_t);
