@@ -1,4 +1,4 @@
-/* $Id: pointset.c,v 1.7 2009/01/05 20:12:47 ellson Exp $ $Revision: 1.7 $ */
+/* $Id: pointset.c,v 1.10 2009/07/24 21:07:07 erg Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -194,6 +194,21 @@ void freePM(PointMap * ps)
     free(dp);
 }
 
+int updatePM(PointMap * pm, int x, int y, int v)
+{
+    mpair *p;
+    mpair dummy;
+    int old;
+
+    dummy.id.x = x;
+    dummy.id.y = y;
+    dummy.v = v;
+    p = dtinsert(pm, &dummy);
+    old = p->v;
+    p->v = v;
+    return old;
+}
+
 int insertPM(PointMap * pm, int x, int y, int v)
 {
     mpair *p;
