@@ -1,4 +1,4 @@
-/* $Id: postproc.c,v 1.27 2009/01/06 22:58:41 arif Exp $ $Revision: 1.27 $ */
+/* $Id: postproc.c,v 1.31 2009/10/30 18:46:24 erg Exp $ $Revision: 1.31 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -111,6 +111,8 @@ static void map_edge(edge_t * e)
     }
     if (ED_label(e))
 	ED_label(e)->pos = map_point(ED_label(e)->pos);
+    if (ED_xlabel(e))
+	ED_xlabel(e)->pos = map_point(ED_xlabel(e)->pos);
     /* vladimir */
     if (ED_head_label(e))
 	ED_head_label(e)->pos = map_point(ED_head_label(e)->pos);
@@ -154,6 +156,8 @@ static void translate_drawing(graph_t * g)
     for (v = agfstnode(g); v; v = agnxtnode(g, v)) {
 	if (Rankdir) gv_nodesize(v, FALSE);
 	ND_coord(v) = map_point(ND_coord(v));
+	if (ND_xlabel(v))
+	    ND_xlabel(v)->pos = map_point(ND_xlabel(v)->pos);
 	if (State == GVSPLINES)
 	    for (e = agfstout(g, v); e; e = agnxtout(g, e))
 		map_edge(e);
@@ -189,6 +193,25 @@ static void place_root_label(graph_t * g, pointf d)
     GD_label(g)->set = TRUE;
 }
 
+static void 
+addXLabels (Agraph_t* g)
+{
+    textlabel_t* lp;
+    pointf p, pp;
+    Agnode_t* n;
+
+    for (n = agfstnode(g); n; n = agnxtnode(g,n)) {
+	lp = ND_xlabel(n);
+	if (!lp) continue;
+	p = ND_coord(n);
+	
+	pp.y = p.y;
+	pp.x += p.x + ND_rw(n) + lp->dimen.x/2.0; 
+	lp->pos = pp;
+	lp->set = 1;
+    }
+}
+
 /* dotneato_postprocess:
  * Set graph and cluster label positions.
  * Add space for root graph label and translate graph accordingly.
@@ -196,11 +219,15 @@ static void place_root_label(graph_t * g, pointf d)
  * Assumes the boxes of all clusters have been computed.
  * When done, the bounding box of g has LL at origin.
  */
-void dotneato_postprocess(Agraph_t * g)
+void gv_postprocess(Agraph_t *g, int addXLabelsOnly)
 {
     double diff;
     pointf dimen = {0., 0.};
 
+    addXLabels (g);
+    if (addXLabelsOnly)
+	return;
+
     Rankdir = GD_rankdir(g);
     Flip = GD_flip(g);
     if (Flip)
@@ -274,6 +301,11 @@ void dotneato_postprocess(Agraph_t * g)
     }
 }
 
+void dotneato_postprocess(Agraph_t * g)
+{
+    gv_postprocess (g, 0);
+}
+
 /* place_flip_graph_label:
  * Put cluster labels recursively in the flip case.
  */
