@@ -98,6 +98,7 @@ extern "C" {
     extern void dotneato_args_initialize(GVC_t * gvc, int, char **);
     extern void dotneato_usage(int);
     extern void dotneato_postprocess(Agraph_t *);
+    extern void gv_postprocess(Agraph_t *, int);
     extern void dotneato_set_margins(GVC_t * gvc, Agraph_t *);
     extern void dotneato_write(GVC_t * gvc, graph_t *g);
     extern void dotneato_write_one(GVC_t * gvc, graph_t *g);
@@ -113,14 +114,17 @@ extern "C" {
     extern void endpath(path *, Agedge_t *, int, pathend_t *, boolean);
     extern void epsf_init(node_t * n);
     extern void epsf_free(node_t * n);
-    extern shape_desc *find_user_shape(char *);
+    extern shape_desc *find_user_shape(const char *);
     extern void free_line(textpara_t *);
     extern void free_label(textlabel_t *);
+    extern void free_textpara(textpara_t * tl);
     extern void getdouble(graph_t * g, char *name, double *result);
     extern splines *getsplinepoints(edge_t * e);
+    extern void gv_fixLocale (int set);
     extern void gv_free_splines(edge_t * e);
     extern void gv_cleanup_edge(Agedge_t * e);
     extern void gv_cleanup_node(Agnode_t * n);
+    extern void* init_xdot (Agraph_t* g);
     extern int initMapData (GVJ_t*, char*, char*, char*, char*, char*, void*);
     extern boolean isPolygon(node_t *);
     extern void makeSelfEdge(path * P, edge_t * edges[], int ind, int cnt,
@@ -135,7 +139,7 @@ extern "C" {
     extern int rank(graph_t * g, int balance, int maxiter);
     extern port resolvePort(node_t*  n, node_t* other, port* oldport);
     extern void resolvePorts (edge_t* e);
-    extern void round_corners(GVJ_t*, char*, char*, pointf*, int, int);
+    extern void round_corners(GVJ_t*, char*, char*, pointf*, int, int,int);
     extern void routesplinesinit(void);
     extern pointf *routesplines(path *, int *);
     extern void routesplinesterm(void);
@@ -150,13 +154,7 @@ extern "C" {
     extern void update_bb_bz(boxf *bb, pointf *cp);
     extern void write_attributed_dot(graph_t *g, FILE *f);
     extern void write_canonical_dot(graph_t *g, FILE *f);
-
-
-
-#ifdef WITH_CODEGENS
-    extern codegen_info_t *first_codegen(void);
-    extern codegen_info_t *next_codegen(codegen_info_t * p);
-#endif
+    extern boxf xdotBB (graph_t* g);
 
 #undef extern
 
