@@ -1,4 +1,4 @@
-/* $Id: routespl.c,v 1.25 2009/06/03 01:10:52 ellson Exp $ $Revision: 1.25 $ */
+/* $Id: routespl.c,v 1.27 2009/11/05 19:30:18 ellson Exp $ $Revision: 1.27 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -14,6 +14,9 @@
 *              AT&T Research, Florham Park NJ             *
 **********************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "render.h"
 #include "pathplan.h"
