@@ -1,4 +1,4 @@
-/* $Id: types.h,v 1.97 2009/06/03 01:10:52 ellson Exp $ $Revision: 1.97 $ */
+/* $Id: types.h,v 1.101 2009/08/28 19:46:42 erg Exp $ $Revision: 1.101 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -45,6 +45,7 @@ extern "C" {
     typedef int (*bsearch_cmpf) (const void *, const void *);
 
 #ifdef WITH_CGRAPH
+#include <cgraph.h>
     typedef struct Agraph_s graph_t;
     typedef struct Agnode_s node_t;
     typedef struct Agedge_s edge_t;
@@ -193,59 +194,7 @@ extern "C" {
 	boolean usershape;
     } shape_desc;
 
-#include "usershape.h"		/* usershapes needed by gvc even w/o CODEGENS */
-#ifdef WITH_CODEGENS
-
-    struct codegen_s {
-	void (*reset) (void);
-	void (*begin_job) (FILE * ofp, graph_t * g, const char **lib, char *info[], point pages);
-	void (*end_job) (void);
-	void (*begin_graph) (GVC_t * gvc, graph_t * g, box bb, point pb);
-	void (*end_graph) (void);
-	void (*begin_page) (graph_t * g, point page, double scale, int rot,
-			    point offset);
-	void (*end_page) (void);
-	void (*begin_layer) (char *layerName, int n, int nLayers);
-	void (*end_layer) (void);
-	void (*begin_cluster) (graph_t * g);
-	void (*end_cluster) (void);
-	void (*begin_nodes) (void);
-	void (*end_nodes) (void);
-	void (*begin_edges) (void);
-	void (*end_edges) (void);
-	void (*begin_node) (node_t * n);
-	void (*end_node) (void);
-	void (*begin_edge) (edge_t * e);
-	void (*end_edge) (void);
-	void (*begin_context) (void);
-	void (*end_context) (void);
-	void (*begin_anchor) (char *href, char *tooltip, char *target);
-	void (*end_anchor) (void);
-	void (*set_font) (char *fontname, double fontsize);
-	void (*textpara) (point p, textpara_t * para);
-	void (*set_pencolor) (char *name);
-	void (*set_fillcolor) (char *name);
-	void (*set_style) (char **s);
-	void (*ellipse) (point p, int rx, int ry, int filled);
-	void (*polygon) (point * A, int n, int filled);
-	void (*beziercurve) (point * A, int n, int arrow_at_start,
-			     int arrow_at_end, int filled);
-	void (*polyline) (point * A, int n);
-	boolean bezier_has_arrows;
-	void (*comment) (char *str);
-	void (*usershape) (usershape_t *us, boxf b, point * A, int sides, boolean filled);
-	void (*set_penwidth) (double penwidth);
-    };
-
-    struct codegen_info_s {
-	codegen_t *cg;		/* discovered codegen */
-	char *name;		/* output format, null for sentinel */
-	int id;			/* id of output format */
-	void *info;		/* additional info provided by discovery routine */
-	/* Quartz uses this to store the Quicktime Component */
-    };
-
-#endif
+#include "usershape.h"		/* usershapes needed by gvc */
 
     typedef struct nodequeue {
 	node_t **store, **limit, **head, **tail;
@@ -284,6 +233,7 @@ extern "C" {
 	boolean landscape;
 	boolean centered;
 	ratio_t ratio_kind;
+	void* xdots;
     } layout_t;
 
 /* for "record" shapes */
@@ -321,6 +271,9 @@ extern "C" {
 typedef enum {NATIVEFONTS,PSFONTS,SVGFONTS} fontname_kind;
 
     typedef struct Agraphinfo_t {
+#ifdef WITH_CGRAPH
+	Agrec_t hdr;
+#endif
 	/* to generate code */
 	layout_t *drawing;
 	textlabel_t *label;	/* if the cluster has a title */
@@ -497,6 +450,9 @@ typedef enum {NATIVEFONTS,PSFONTS,SVGFONTS} fontname_kind;
 #endif
 
     typedef struct Agnodeinfo_t {
+#ifdef WITH_CGRAPH
+	Agrec_t hdr;
+#endif
 	shape_desc *shape;
 	void *shape_info;
 	pointf coord;
@@ -504,6 +460,7 @@ typedef enum {NATIVEFONTS,PSFONTS,SVGFONTS} fontname_kind;
 	boxf bb;
 	double ht, lw, rw;
 	textlabel_t *label;
+	textlabel_t *xlabel;
 	void *alg;
 	char state;
 	unsigned char gui_state; /* Node state for GUI ops */
@@ -567,6 +524,7 @@ typedef enum {NATIVEFONTS,PSFONTS,SVGFONTS} fontname_kind;
 #define ND_in(n) (((Agnodeinfo_t*)AGDATA(n))->in)
 #define ND_inleaf(n) (((Agnodeinfo_t*)AGDATA(n))->inleaf)
 #define ND_label(n) (((Agnodeinfo_t*)AGDATA(n))->label)
+#define ND_xlabel(n) (((Agnodeinfo_t*)AGDATA(n))->xlabel)
 #define ND_lim(n) (((Agnodeinfo_t*)AGDATA(n))->lim)
 #define ND_low(n) (((Agnodeinfo_t*)AGDATA(n))->low)
 #define ND_lw(n) (((Agnodeinfo_t*)AGDATA(n))->lw)
@@ -623,6 +581,7 @@ typedef enum {NATIVEFONTS,PSFONTS,SVGFONTS} fontname_kind;
 #define ND_in(n) (n)->u.in
 #define ND_inleaf(n) (n)->u.inleaf
 #define ND_label(n) (n)->u.label
+#define ND_xlabel(n) (n)->u.xlabel
 #define ND_lim(n) (n)->u.lim
 #define ND_low(n) (n)->u.low
 #define ND_lw(n) (n)->u.lw
@@ -660,9 +619,12 @@ typedef enum {NATIVEFONTS,PSFONTS,SVGFONTS} fontname_kind;
 #endif
 
     typedef struct Agedgeinfo_t {
+#ifdef WITH_CGRAPH
+	Agrec_t hdr;
+#endif
 	splines *spl;
 	port tail_port, head_port;
-	textlabel_t *label, *head_label, *tail_label;
+	textlabel_t *label, *head_label, *tail_label, *xlabel;
 	char edge_type;
 	char adjacent;          /* true for flat edge with adjacent nodes */
 	char label_ontop;
@@ -699,6 +661,7 @@ typedef enum {NATIVEFONTS,PSFONTS,SVGFONTS} fontname_kind;
 #define ED_head_label(e) (((Agedgeinfo_t*)AGDATA(e))->head_label)
 #define ED_head_port(e) (((Agedgeinfo_t*)AGDATA(e))->head_port)
 #define ED_label(e) (((Agedgeinfo_t*)AGDATA(e))->label)
+#define ED_xlabel(e) (((Agedgeinfo_t*)AGDATA(e))->xlabel)
 #define ED_label_ontop(e) (((Agedgeinfo_t*)AGDATA(e))->label_ontop)
 #define ED_minlen(e) (((Agedgeinfo_t*)AGDATA(e))->minlen)
 #define ED_path(e) (((Agedgeinfo_t*)AGDATA(e))->path)
@@ -727,6 +690,7 @@ typedef enum {NATIVEFONTS,PSFONTS,SVGFONTS} fontname_kind;
 #define ED_head_label(e) (e)->u.head_label
 #define ED_head_port(e) (e)->u.head_port
 #define ED_label(e) (e)->u.label
+#define ED_xlabel(e) (e)->u.xlabel
 #define ED_label_ontop(e) (e)->u.label_ontop
 #define ED_minlen(e) (e)->u.minlen
 #define ED_path(e) (e)->u.path
