@@ -1,4 +1,4 @@
-/* $Id: utils.c,v 1.110 2009/03/04 18:19:11 arif Exp $ $Revision: 1.110 $ */
+/* $Id: utils.c,v 1.125 2010/01/05 17:22:24 arif Exp $ $Revision: 1.125 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -65,30 +65,6 @@ node_t *dequeue(nodequeue * q)
     return n;
 }
 
-#ifndef WITH_CGRAPH
-/* returns index of an attribute if bound, else -1 */
-int late_attr(void *obj, char *name)
-#else /* WITH_CGRAPH */
-/* returns index of an attribute if bound, else NULL */
-attrsym_t* late_attr(void *obj, char *name)
-#endif /* WITH_CGRAPH */
-{
-    attrsym_t *a;
-#ifndef WITH_CGRAPH
-    if ((a = agfindattr(obj, name)) != 0)
-	return a->index;
-#else /* WITH_CGRAPH */
-    if ((a = agget(obj, name)) != 0)
-	return a;
-#endif /* WITH_CGRAPH */
-    else
-#ifndef WITH_CGRAPH
-	return -1;
-#else /* WITH_CGRAPH */
-	return NULL;
-#endif /* WITH_CGRAPH */
-}
-
 int late_int(void *obj, attrsym_t * attr, int def, int low)
 {
     char *p;
@@ -100,7 +76,7 @@ int late_int(void *obj, attrsym_t * attr, int def, int low)
 #else /* WITH_CGRAPH */
     p = agxget(obj, attr);
 #endif /* WITH_CGRAPH */
-    if (p[0] == '\0')
+    if (!p || p[0] == '\0')
 	return def;
     if ((rv = atoi(p)) < low)
 	rv = low;
@@ -109,30 +85,18 @@ int late_int(void *obj, attrsym_t * attr, int def, int low)
 
 double late_double(void *obj, attrsym_t * attr, double def, double low)
 {
-#ifndef WITH_CGRAPH
     char *p;
-#else /* WITH_CGRAPH */
-    char *p=NULL;
-#endif /* WITH_CGRAPH */
     double rv;
 
-    if (attr == NULL)
+    if (!attr || !obj)
 	return def;
 #ifndef WITH_CGRAPH
     p = agxget(obj, attr->index);
-#else /* WITH_CGRAPH */
-	if(!obj)
-		return def;
-	p = agxget(obj, attr);
-    if (!p)
-		return def;
+#else  /* WITH_CGRAPH */
+    p = agxget(obj, attr);
 #endif /* WITH_CGRAPH */
-    if (p[0] == '\0')
+    if (!p || p[0] == '\0')
 	return def;
-#ifdef WITH_CGRAPH
-	if (!obj)
-		return def;
-#endif /* WITH_CGRAPH */
     if ((rv = atof(p)) < low)
 	rv = low;
     return rv;
@@ -140,11 +104,7 @@ double late_double(void *obj, attrsym_t * attr, double def, double low)
 
 char *late_string(void *obj, attrsym_t * attr, char *def)
 {
-#ifndef WITH_CGRAPH
-    if (attr == NULL)
-#else /* WITH_CGRAPH */
-	if ((attr == NULL) || (obj==NULL))
-#endif /* WITH_CGRAPH */
+    if (!attr || !obj)
 	return def;
 #ifndef WITH_CGRAPH
     return agxget(obj, attr->index);
@@ -156,12 +116,7 @@ char *late_string(void *obj, attrsym_t * attr, char *def)
 char *late_nnstring(void *obj, attrsym_t * attr, char *def)
 {
     char *rv = late_string(obj, attr, def);
-#ifndef WITH_CGRAPH
-    if (rv[0] == '\0')
-#else /* WITH_CGRAPH */
-	
-	if ((!rv)||(rv[0] == '\0'))
-#endif /* WITH_CGRAPH */
+    if (!rv || (rv[0] == '\0'))
 	rv = def;
     return rv;
 }
@@ -435,8 +390,12 @@ boolean mapbool(char *p)
 	return FALSE;
     if (!strcasecmp(p, "false"))
 	return FALSE;
+    if (!strcasecmp(p, "no"))
+	return FALSE;
     if (!strcasecmp(p, "true"))
 	return TRUE;
+    if (!strcasecmp(p, "yes"))
+	return TRUE;
     return atoi(p);
 }
 
@@ -582,10 +541,17 @@ int test_toggle()
     return Tflag;
 }
 
-void common_init_node(node_t * n)
+struct fontinfo {
+    double fontsize;
+    char *fontname;
+    char *fontcolor;
+};
+
+void common_init_node_opt(node_t * n, int shape_init_flag)
 {
+    struct fontinfo fi;
     char *str;
-	ND_width(n) =
+    ND_width(n) =
 	late_double(n, N_width, DEFAULT_NODEWIDTH, MIN_NODEWIDTH);
     ND_height(n) =
 	late_double(n, N_height, DEFAULT_NODEHEIGHT, MIN_NODEHEIGHT);
@@ -596,20 +562,29 @@ void common_init_node(node_t * n)
 #else
     str = agxget(n, N_label);
 #endif
+    fi.fontsize = late_double(n, N_fontsize, DEFAULT_FONTSIZE, MIN_FONTSIZE);
+    fi.fontname = late_nnstring(n, N_fontname, DEFAULT_FONTNAME);
+    fi.fontcolor = late_nnstring(n, N_fontcolor, DEFAULT_COLOR);
     ND_label(n) = make_label((void*)n, str,
 	        ((aghtmlstr(str) ? LT_HTML : LT_NONE) | ( (shapeOf(n) == SH_RECORD) ? LT_RECD : LT_NONE)),
-		late_double(n, N_fontsize, DEFAULT_FONTSIZE, MIN_FONTSIZE),
-		late_nnstring(n, N_fontname, DEFAULT_FONTNAME),
-		late_nnstring(n, N_fontcolor, DEFAULT_COLOR));
+		fi.fontsize, fi.fontname, fi.fontcolor);
+#ifndef WITH_CGRAPH
+    if (N_xlabel && (str = agxget(n, N_xlabel->index)) && (str[0])) {
+#else
+    if (N_xlabel && (str = agxget(n, N_xlabel)) && (str[0])) {
+#endif
+	ND_xlabel(n) = make_label((void*)n, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+				fi.fontsize, fi.fontname, fi.fontcolor);
+	GD_has_labels(agraphof(n)) |= NODE_XLABEL;
+    }
+
     ND_showboxes(n) = late_int(n, N_showboxes, 0, 0);
-    ND_shape(n)->fns->initfn(n);
+    if (shape_init_flag) ND_shape(n)->fns->initfn(n);
 }
 
-struct fontinfo {
-    double fontsize;
-    char *fontname;
-    char *fontcolor;
-};
+void common_init_node(node_t * n) {
+    common_init_node_opt(n,TRUE);
+}
 
 static void initFontEdgeAttr(edge_t * e, struct fontinfo *fi)
 {
@@ -701,6 +676,18 @@ int common_init_edge(edge_t * e)
 	    mapbool(late_string(e, E_label_float, "false"));
     }
 
+#ifndef WITH_CGRAPH
+    if (E_xlabel && (str = agxget(e, E_xlabel->index)) && (str[0])) {
+#else
+    if (E_xlabel && (str = agxget(e, E_xlabel)) && (str[0])) {
+#endif
+	if (!fi.fontname)
+	    initFontEdgeAttr(e, &fi);
+	ED_xlabel(e) = make_label((void*)e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+				fi.fontsize, fi.fontname, fi.fontcolor);
+	GD_has_labels(sg) |= EDGE_XLABEL;
+    }
+
 
     /* vladimir */
 #ifndef WITH_CGRAPH
@@ -726,14 +713,25 @@ int common_init_edge(edge_t * e)
     }
     /* end vladimir */
 
-    /* We still accept ports beginning with colons but this is deprecated */
+    /* We still accept ports beginning with colons but this is deprecated 
+     * That is, we allow tailport = ":abc" as well as the preferred 
+     * tailport = "abc".
+     */
     str = agget(e, TAIL_ID);
+#ifdef WITH_CGRAPH
+    /* libgraph always defines tailport/headport; libcgraph doesn't */
+    if (!str) str = "";
+#endif
     if (str && str[0])
 	ND_has_port(agtail(e)) = TRUE;
     ED_tail_port(e) = chkPort (ND_shape(agtail(e))->fns->portfn, agtail(e), str);
     if (noClip(e, E_tailclip))
 	ED_tail_port(e).clip = FALSE;
     str = agget(e, HEAD_ID);
+#ifdef WITH_CGRAPH
+    /* libgraph always defines tailport/headport; libcgraph doesn't */
+    if (!str) str = "";
+#endif
     if (str && str[0])
 	ND_has_port(aghead(e)) = TRUE;
     ED_head_port(e) = chkPort(ND_shape(aghead(e))->fns->portfn, aghead(e), str);
@@ -838,6 +836,9 @@ void compute_bb(graph_t * g)
 	B2BF(GD_bb(GD_clust(g)[i]), BF);
 	EXPANDBB(bb,BF);
     }
+    if (GD_label(g) && GD_label(g)->set) {
+	bb = addLabelBB(bb, GD_label(g), GD_flip(g));
+    }
 
     GD_bb(g) = bb;
 }
@@ -1267,28 +1268,28 @@ void undoClusterEdges(graph_t * g)
 /* safe_dcl:
  * Find the attribute belonging to graph g for objects like obj
  * with given name. If one does not exist, create it with the
- * supplied function fun with default value def.
+ * default value def.
  */ 
 #ifndef WITH_CGRAPH
 attrsym_t*
 safe_dcl(graph_t * g, void *obj, char *name, char *def,
          attrsym_t * (*fun) (Agraph_t *, char *, char *))
-#else /* WITH_CGRAPH */
-attrsym_t*
-safe_dcl(graph_t * g, int obj_kind, char *name, char *def)
-#endif /* WITH_CGRAPH */
 {
-#ifndef WITH_CGRAPH
     attrsym_t *a = agfindattr(obj, name);
     if (a == NULL)
 	a = fun(g, name, def);
-#else /* WITH_CGRAPH */
-	attrsym_t *a = agattr(g,obj_kind,name, NULL);
-	if (!a)	/*attribute exists*/		
-		a=agattr(g,obj_kind,name,def);
-#endif /* WITH_CGRAPH */
     return a;
 }
+#else /* WITH_CGRAPH */
+attrsym_t*
+safe_dcl(graph_t * g, int obj_kind, char *name, char *def)
+{
+    attrsym_t *a = agattr(g,obj_kind,name, NULL);
+    if (!a)	/* attribute does not exist */		
+	a = agattr(g,obj_kind,name,def);
+    return a;
+}
+#endif /* WITH_CGRAPH */
 
 static int comp_entities(const void *e1, const void *e2) {
   return strcmp(((struct entities_s *)e1)->name, ((struct entities_s *)e2)->name);
@@ -1667,6 +1668,7 @@ int edgeType (char* s, int dflt)
     case 'n' :
     case 'N' :
 	if (!strcasecmp (s+1, "one")) return et;
+	if (!strcasecmp (s+1, "o")) return ET_LINE;
 	break;
     case 'o' :
     case 'O' :
@@ -1688,6 +1690,11 @@ int edgeType (char* s, int dflt)
 	if (!strcasecmp (s+1, "rue"))
 	    et = ET_SPLINE;
 	break;
+    case 'y' :
+    case 'Y' :
+	if (!strcasecmp (s+1, "es"))
+	    et = ET_SPLINE;
+	break;
     }
     if (!et) {
 	agerr(AGWARN, "Unknown \"splines\" value: \"%s\" - ignored\n", s);
@@ -1787,6 +1794,9 @@ void gv_cleanup_edge(edge_t * e)
 {
     gv_free_splines(e);
     free_label(ED_label(e));
+    free_label(ED_xlabel(e));
+    free_label(ED_head_label(e));
+    free_label(ED_tail_label(e));
 #ifndef WITH_CGRAPH
     memset(&(e->u), 0, sizeof(Agedgeinfo_t));
 #else /* WITH_CGRAPH */
@@ -1801,6 +1811,7 @@ void gv_cleanup_node(node_t * n)
     if (ND_shape(n))
         ND_shape(n)->fns->freefn(n);
     free_label(ND_label(n));
+    free_label(ND_xlabel(n));
 #ifndef WITH_CGRAPH
     memset(&(n->u), 0, sizeof(Agnodeinfo_t));
 #else /* WITH_CGRAPH */
@@ -1835,8 +1846,9 @@ void fix_fc(void)
 
     if((fp = fopen("fix-fc.exe", "r")) == NULL)
 	    return ;
+    fclose (fp);
     if (!system ("fix-fc.exe")) {
-	system ("del fc-fix.exe");
+	system ("del fix-fc.exe");
 	system ("dot -c");	//run dot -c once too since we already run things :)
     }
 }
