@@ -1,4 +1,4 @@
-/* $Id: utils.h,v 1.34 2009/01/29 20:02:11 arif Exp $ $Revision: 1.34 $ */
+/* $Id: utils.h,v 1.38 2009/10/16 15:47:47 erg Exp $ $Revision: 1.38 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -59,17 +59,14 @@ extern "C" {
     extern void epsf_emit_body(GVJ_t *job, usershape_t *us);
     extern void epsf_define(GVJ_t * job);
     extern void undoClusterEdges(graph_t * g);
-
+	extern void common_init_node_opt(node_t * n, int shape_init_flag);
 #ifndef WITH_CGRAPH
-    extern int late_attr(void *, char *);
     extern attrsym_t* safe_dcl(graph_t*, void*, char*, char*,
              attrsym_t * (*fun) (Agraph_t *, char *, char *));
 #else
-    extern attrsym_t* late_attr(void *obj, char *name);
     extern attrsym_t* safe_dcl(graph_t * g, int obj_kind, char *name, char *def);
 #endif
 
-
     extern int late_int(void *, Agsym_t *, int, int);
     extern double late_double(void *, Agsym_t *, double, double);
     extern char *late_nnstring(void *, Agsym_t *, char *);
