@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton interface for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,10 +28,11 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -50,13 +50,19 @@
      T_end_font = 266,
      T_string = 267,
      T_error = 268,
-     T_BR = 269,
-     T_br = 270,
-     T_IMG = 271,
-     T_img = 272,
-     T_table = 273,
-     T_cell = 274,
-     T_font = 275
+     T_n_italic = 269,
+     T_n_bold = 270,
+     T_n_underline = 271,
+     T_BR = 272,
+     T_br = 273,
+     T_IMG = 274,
+     T_img = 275,
+     T_table = 276,
+     T_cell = 277,
+     T_font = 278,
+     T_italic = 279,
+     T_bold = 280,
+     T_underline = 281
    };
 #endif
 /* Tokens.  */
@@ -71,35 +77,47 @@
 #define T_end_font 266
 #define T_string 267
 #define T_error 268
-#define T_BR 269
-#define T_br 270
-#define T_IMG 271
-#define T_img 272
-#define T_table 273
-#define T_cell 274
-#define T_font 275
+#define T_n_italic 269
+#define T_n_bold 270
+#define T_n_underline 271
+#define T_BR 272
+#define T_br 273
+#define T_IMG 274
+#define T_img 275
+#define T_table 276
+#define T_cell 277
+#define T_font 278
+#define T_italic 279
+#define T_bold 280
+#define T_underline 281
 
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 535 "../../lib/common/htmlparse.y"
 {
+
+/* Line 1676 of yacc.c  */
+#line 409 "../../lib/common/htmlparse.y"
+
   int    i;
   htmltxt_t*  txt;
   htmlcell_t*  cell;
   htmltbl_t*   tbl;
   htmlfont_t*  font;
   htmlimg_t*   img;
-}
-/* Line 1489 of yacc.c.  */
-#line 98 "y.tab.h"
-	YYSTYPE;
+
+
+
+/* Line 1676 of yacc.c  */
+#line 115 "y.tab.h"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 extern YYSTYPE yylval;
 
+
