@@ -1,4 +1,4 @@
-/* $Id: excc.c,v 1.2 2008/08/01 19:31:29 erg Exp $ $Revision: 1.2 $ */
+/* $Id: excc.c,v 1.7 2009/10/19 18:30:21 erg Exp $ $Revision: 1.7 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -264,6 +264,10 @@ static void gen(Excc_t * cc, register Exnode_t * expr)
 	}
 	sfprintf(cc->ccdisc->text, ")");
 	return;
+    case IN_OP:
+        gen(cc, expr->data.variable.index);
+	sfprintf(cc->ccdisc->text, " in %s", expr->data.variable.symbol->name);
+	return;
     case IF:
 	sfprintf(cc->ccdisc->text, "if (");
 	gen(cc, x);
@@ -276,7 +280,7 @@ static void gen(Excc_t * cc, register Exnode_t * expr)
 	sfprintf(cc->ccdisc->text, "}\n");
 	return;
     case FOR:
-	sfprintf(cc->ccdisc->text, "for (;");
+	sfprintf(cc->ccdisc->text, "for (");
 	gen(cc, x);
 	sfprintf(cc->ccdisc->text, ");");
 	if (expr->data.operand.left) {
@@ -302,6 +306,7 @@ static void gen(Excc_t * cc, register Exnode_t * expr)
 	sfprintf(cc->ccdisc->text, "%s++", x->data.variable.symbol->name);
 	return;
     case ITERATE:
+    case ITERATER:
 	if (expr->op == DYNAMIC) {
 	    sfprintf(cc->ccdisc->text, "{ Exassoc_t* %stmp_%d;", cc->id,
 		     ++cc->tmp);
@@ -335,6 +340,20 @@ static void gen(Excc_t * cc, register Exnode_t * expr)
     case SCANF:
 	scan(cc, expr);
 	return;
+    case SPLIT:
+    case TOKENS:
+	if (expr->op == SPLIT)
+	    sfprintf(cc->ccdisc->text, "split (");
+	else
+	    sfprintf(cc->ccdisc->text, "tokens (");
+        gen(cc, expr->data.split.string);
+	sfprintf(cc->ccdisc->text, ", %s", expr->data.split.array->name);
+        if (expr->data.split.seps) {
+	  sfprintf(cc->ccdisc->text, ",");
+          gen(cc, expr->data.split.seps);
+        }
+	sfprintf(cc->ccdisc->text, ")");
+	return;
     case SWITCH:
 	t = x->type;
 	sfprintf(cc->ccdisc->text, "{ %s %stmp_%d = ", extype(t), cc->id,
@@ -391,6 +410,14 @@ static void gen(Excc_t * cc, register Exnode_t * expr)
 	}
 	sfprintf(cc->ccdisc->text, "}");
 	return;
+    case UNSET:
+	sfprintf(cc->ccdisc->text, "unset(%s", expr->data.variable.symbol->name);
+        if (expr->data.variable.index) {
+	  sfprintf(cc->ccdisc->text, ",");
+          gen(cc, expr->data.variable.index);
+        }
+	sfprintf(cc->ccdisc->text, ")");
+	return;
     case WHILE:
 	sfprintf(cc->ccdisc->text, "while (");
 	gen(cc, x);
@@ -399,6 +426,10 @@ static void gen(Excc_t * cc, register Exnode_t * expr)
 	    gen(cc, expr->data.operand.right);
 	sfprintf(cc->ccdisc->text, "}");
 	return;
+    case '#':
+	sfprintf(cc->ccdisc->text, "# %s", 
+	    expr->data.variable.symbol->name);
+	return;
     case '=':
 	sfprintf(cc->ccdisc->text, "(%s%s=", x->data.variable.symbol->name,
 		 expr->subop == '=' ? "" : exopname(expr->subop));
