@@ -1,4 +1,4 @@
-/* $Id: exdata.c,v 1.2 2006/05/24 15:02:32 ellson Exp $ $Revision: 1.2 $ */
+/* $Id: exdata.c,v 1.8 2009/10/19 18:30:21 erg Exp $ $Revision: 1.8 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -22,7 +22,7 @@
  */
 
 static const char id[] =
-    "\n@(#)$Id: exdata.c,v 1.2 2006/05/24 15:02:32 ellson Exp $\0\n";
+    "\n@(#)$Id: exdata.c,v 1.8 2009/10/19 18:30:21 erg Exp $\0\n";
 
 #include <exlib.h>
 
@@ -38,16 +38,18 @@ Exid_t exbuiltin[] = {
 
     EX_ID("break", BREAK, BREAK, 0, 0),
     EX_ID("case", CASE, CASE, 0, 0),
-    EX_ID("char", DECLARE, CHAR, CHAR, 0),
+    EX_ID("char", DECLARE, CHARACTER, CHARACTER, 0),
     EX_ID("continue", CONTINUE, CONTINUE, 0, 0),
     EX_ID("default", DEFAULT, DEFAULT, 0, 0),
     EX_ID("double", DECLARE, FLOATING, FLOATING, 0),
     EX_ID("else", ELSE, ELSE, 0, 0),
     EX_ID("exit", EXIT, EXIT, INTEGER, 0),
     EX_ID("for", FOR, FOR, 0, 0),
+    EX_ID("forr", ITERATER, ITERATER, 0, 0),
     EX_ID("float", DECLARE, FLOATING, FLOATING, 0),
     EX_ID("gsub", GSUB, GSUB, STRING, 0),
     EX_ID("if", IF, IF, 0, 0),
+    EX_ID("in", IN_OP, IN_OP, 0, 0),
     EX_ID("int", DECLARE, INTEGER, INTEGER, 0),
     EX_ID("long", DECLARE, INTEGER, INTEGER, 0),
     EX_ID("print", PRINT, PRINT, INTEGER, 0),
@@ -57,13 +59,16 @@ Exid_t exbuiltin[] = {
     EX_ID("return", RETURN, RETURN, 0, 0),
     EX_ID("scanf", SCANF, SCANF, INTEGER, 0),
     EX_ID("sscanf", SSCANF, SSCANF, INTEGER, 0),
+    EX_ID("split", SPLIT, SPLIT, INTEGER, 0),
     EX_ID("sprintf", SPRINTF, SPRINTF, STRING, 0),
     EX_ID("srand", SRAND, SRAND, INTEGER, 0),
     EX_ID("sub", SUB, SUB, STRING, 0),
     EX_ID("substr", SUBSTR, SUBSTR, STRING, 0),
     EX_ID("switch", SWITCH, SWITCH, 0, 0),
+    EX_ID("tokens", TOKENS, TOKENS, INTEGER, 0),
     EX_ID("unsigned", DECLARE, UNSIGNED, UNSIGNED, 0),
-    EX_ID("void", DECLARE, VOID, 0, 0),
+    EX_ID("void", DECLARE, VOIDTYPE, 0, 0),
+    EX_ID("unset", UNSET, UNSET, 0, 0),
     EX_ID("while", WHILE, WHILE, 0, 0),
     EX_ID({0}, 0, 0, 0, 0)
 
