@@ -1,4 +1,4 @@
-/* $Id: exexpr.c,v 1.1.1.1 2004/12/23 04:05:03 ellson Exp $ $Revision: 1.1.1.1 $ */
+/* $Id: exexpr.c,v 1.4 2009/06/29 16:41:27 erg Exp $ $Revision: 1.4 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -33,7 +33,7 @@ Exnode_t *exexpr(Expr_t * ex, const char *name, Exid_t * sym, int type)
 	if (!sym)
 	    sym = name ? (Exid_t *) dtmatch(ex->symbols, name) : &ex->main;
 	if (sym && sym->lex == PROCEDURE && sym->value) {
-	    if (type != DELETE)
+	    if (type != DELETE_T)
 		return excast(ex, sym->value->data.procedure.body, type,
 			      NiL, 0);
 	    exfreenode(ex, sym->value);
