@@ -1,4 +1,4 @@
-/* $Id: exgram.h,v 1.15 2009/10/19 18:30:21 erg Exp $ $Revision: 1.15 $ */
+/* $Id: exgram.h,v 1.16 2010/01/05 17:22:24 arif Exp $ $Revision: 1.16 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -110,7 +110,7 @@ extern "C" {
 		x->data.variable.symbol->local.pointer = 0;
 	    }
 	    break;
-	case IN_OP:
+//	case IN_OP:
 	case UNSET:
 	    if (x->data.variable.index)
 		exfreenode(p, x->data.variable.index);
