@@ -1,4 +1,4 @@
-/* $Id: exlib.h,v 1.3 2009/06/03 01:10:52 ellson Exp $ $Revision: 1.3 $ */
+/* $Id: exlib.h,v 1.4 2009/07/02 14:59:04 erg Exp $ $Revision: 1.4 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -69,6 +69,12 @@ extern "C" {
 	}		generate;	/* associative array generator	*/ \
 	struct								   \
 	{								   \
+	Exid_t*		array;		/* array 			*/ \
+	Exnode_t*	string;		/* string 			*/ \
+	Exnode_t*	seps;		/* optional separators		*/ \
+	}		split;		/* string split	*/ \
+	struct								   \
+	{								   \
 	Exnode_t*	descriptor;	/* Expr_t.file index		*/ \
 	Print_t*	args;		/* compiler printf args		*/ \
 	}		print;		/* printf			*/ \
