@@ -1,13 +1,11 @@
 static const char* exop[] = {
 	"MINTOKEN",
-	"MINTOKEN",
-	"INT",
 	"INTEGER",
 	"UNSIGNED",
-	"CHAR",
+	"CHARACTER",
 	"FLOATING",
 	"STRING",
-	"VOID",
+	"VOIDTYPE",
 	"ADDRESS",
 	"ARRAY",
 	"BREAK",
@@ -24,6 +22,7 @@ static const char* exop[] = {
 	"FUNCTION",
 	"GSUB",
 	"ITERATE",
+	"ITERATER",
 	"ID",
 	"IF",
 	"LABEL",
@@ -39,12 +38,15 @@ static const char* exop[] = {
 	"RAND",
 	"RETURN",
 	"SCANF",
+	"SPLIT",
 	"SPRINTF",
 	"SRAND",
 	"SSCANF",
 	"SUB",
 	"SUBSTR",
 	"SWITCH",
+	"TOKENS",
+	"UNSET",
 	"WHILE",
 	"F2I",
 	"F2S",
@@ -69,11 +71,9 @@ static const char* exop[] = {
 	"LE",
 	"RS",
 	"LS",
+	"IN_OP",
 	"UNARY",
 	"DEC",
 	"INC",
 	"CAST",
-	"MAXTOKEN",
-	"EXSTYPE_IS_DECLARED",
-	"EXSTYPE_IS_TRIVIAL",
 };
