@@ -1,4 +1,4 @@
-/* $Id: extoken.c,v 1.2 2008/08/01 19:31:29 erg Exp $ $Revision: 1.2 $ */
+/* $Id: extoken.c,v 1.8 2009/10/19 18:30:21 erg Exp $ $Revision: 1.8 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -174,12 +174,18 @@ static void trace(Expr_t * ex, int lev, char *op, int c)
     case FOR:
 	s = " for";
 	break;
+    case ITERATER:
+	s = " forr";
+	break;
     case GSUB:
 	s = " gsub";
 	break;
     case IF:
 	s = " if";
 	break;
+    case IN_OP:
+	s = " in";
+	break;
     case PRAGMA:
 	s = " pragma";
 	break;
@@ -198,6 +204,9 @@ static void trace(Expr_t * ex, int lev, char *op, int c)
     case RETURN:
 	s = " return";
 	break;
+    case SPLIT:
+	s = " split";
+	break;
     case SPRINTF:
 	s = " sprintf";
 	break;
@@ -213,6 +222,12 @@ static void trace(Expr_t * ex, int lev, char *op, int c)
     case SWITCH:
 	s = " switch";
 	break;
+    case TOKENS:
+	s = " tokens";
+	break;
+    case UNSET:
+	s = " unset";
+	break;
     case WHILE:
 	s = " while";
 	break;
@@ -641,7 +656,7 @@ int extoken_fn(register Expr_t * ex)
 
 		switch (exlval.id->lex) {
 		case DECLARE:
-		    if (exlval.id->index == CHAR) {
+		    if (exlval.id->index == CHARACTER) {
 			/*
 			 * `char*' === `string'
 			 * the * must immediately follow char
