@@ -1,4 +1,4 @@
-/* $Id: clusteredges.c,v 1.7 2008/10/21 21:42:04 ellson Exp $ $Revision: 1.7 $ */
+/* $Id: clusteredges.c,v 1.10 2009/08/11 21:21:20 erg Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -295,7 +295,7 @@ int compoundEdges(graph_t * g, expand_t* pm, int edgetype)
 		for (e0 = e; e0; e0 = ED_to_virt(e0)) {
 		    ED_path(e0) =
 			getPath(e0, vconfig, 0, objl->obs, objl->cnt);
-		    makeSpline(e0, objl->obs, objl->cnt, FALSE);
+		    makeSpline(g, e0, objl->obs, objl->cnt, FALSE);
 		}
 		resetObjlist(objl);
 	    }
