@@ -1,4 +1,4 @@
-/* $Id: layout.c,v 1.28 2008/10/23 16:24:20 ellson Exp $ $Revision: 1.28 $ */
+/* $Id: layout.c,v 1.33 2009/09/04 15:53:00 erg Exp $ $Revision: 1.33 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -1064,9 +1064,7 @@ void init_info(graph_t * g, layout_info * infop)
 #endif /* WITH_CGRAPH */
     infop->rootg = g;
     infop->gid = 0;
-    infop->pack.margin = getPack(g, CL_OFFSET / 2, CL_OFFSET / 2);
-    infop->pack.doSplines = 0;
-    infop->pack.mode = getPackMode(g, l_node);
+    infop->pack.mode = getPackInfo(g, l_node, CL_OFFSET / 2, &(infop->pack));
 }
 
 /* mkClusters:
@@ -1183,6 +1181,7 @@ fdpSplines (graph_t * g)
 		spline_edges1(g, et);
 	    }
 	}
+	Nop = 0;
     }
     if (State < GVSPLINES)
 	spline_edges1(g, ET_LINE);
@@ -1190,8 +1189,13 @@ fdpSplines (graph_t * g)
 
 void fdp_layout(graph_t * g)
 {
+    Agnode_t* n;
+
     fdp_init_graph(g);
     fdpLayout(g);
+    /* free ND_alg field so it can be used in spline routing */
+    if ((n = agfstnode(g)))
+	free(ND_alg(n));
     neato_set_aspect(g);
 
     if (EDGE_TYPE(g) != ET_NONE) fdpSplines (g); 
