@@ -1,3 +1,4 @@
+/* $Id: glcomptexture.h,v 1.8 2009/10/09 17:25:34 erg Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -17,8 +18,8 @@
   includes glPanel,glCompButton,glCompCustomButton,clCompLabel,glCompStyle
 */
 
-#ifndef GLCOMPTEXTURE_H
-#define GLCOMPTEXTURE_H
+#ifndef glCompFontURE_H
+#define glCompFontURE_H
 
 #ifdef _WIN32
 #include "windows.h"
@@ -28,9 +29,19 @@
 #include <GL/glu.h>
 #include "glcompdefs.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
+    extern glCompTex *glCompSetAddNewTexImage(glCompSet * s, int width,
+					      int height,
+					      unsigned char *data,
+					      int is2D);
+    extern glCompTex *glCompSetAddNewTexLabel(glCompSet * s, char *def,
+					      int fs, char *text,
+					      int is2D);
 
-glCompTexture *glCompCreateTextureFromRaw(char *filename, int width,
-					  int height, int wrap);
-int glCompDeleteTexture(glCompTexture * t);
+#ifdef __cplusplus
+}
+#endif
 #endif
