@@ -1,4 +1,4 @@
-/* $Id: graphio.c,v 1.21 2009/03/12 19:59:11 ellson Exp $ $Revision: 1.21 $ */
+/* $Id: graphio.c,v 1.24 2009/12/05 22:34:03 erg Exp $ $Revision: 1.24 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -91,11 +91,6 @@ Agraph_t *agread_usergets(FILE * fp, gets_f usergets)
     return AG.parsed_g;
 }
 
-int agerrors(void)
-{
-    return AG.syntax_errors;
-}
-
 static int
 _is_number_char(char c)
 {
