@@ -1,4 +1,4 @@
-/* $Id: libgraph.h,v 1.12 2009/02/26 19:52:42 ellson Exp $ $Revision: 1.12 $ */
+/* $Id: libgraph.h,v 1.15 2009/06/03 01:10:53 ellson Exp $ $Revision: 1.15 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -28,7 +28,7 @@ extern "C" {
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
-#ifndef MSWIN32
+#if !defined(MSWIN32) && !defined(WIN32)
 #include <unistd.h>
 #endif
 #endif
