@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,43 +54,20 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum agtokentype {
-     T_graph = 258,
-     T_digraph = 259,
-     T_strict = 260,
-     T_node = 261,
-     T_edge = 262,
-     T_edgeop = 263,
-     T_symbol = 264,
-     T_qsymbol = 265,
-     T_subgraph = 266
-   };
-#endif
-/* Tokens.  */
-#define T_graph 258
-#define T_digraph 259
-#define T_strict 260
-#define T_node 261
-#define T_edge 262
-#define T_edgeop 263
-#define T_symbol 264
-#define T_qsymbol 265
-#define T_subgraph 266
-
-
-
-
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 17 "../../lib/graph/parser.y"
 
 
@@ -110,7 +86,8 @@ static Agraph_t		*G;
 static Agnode_t		*N;
 static Agedge_t		*E;
 static objstack_t	*SP;
-static Agraph_t		*Gstack[32];
+#define GSTACK_SIZE 64
+static Agraph_t         *Gstack[GSTACK_SIZE];
 static int			GSP;
 
 static void subgraph_warn (void)
@@ -123,6 +100,9 @@ static void subgraph_warn (void)
 
 static void push_subg(Agraph_t *g)
 {
+	if (GSP >= GSTACK_SIZE) {
+		agerr (AGERR, "Gstack overflow in graph parser\n"); exit(1);
+	}
 	G = Gstack[GSP++] = g;
 }
 
@@ -380,6 +360,9 @@ concat3 (char* s1, char* s2, char*s3)
 
 
 
+/* Line 189 of yacc.c  */
+#line 365 "y.tab.c"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -398,30 +381,66 @@ concat3 (char* s1, char* s2, char*s3)
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum agtokentype {
+     T_graph = 258,
+     T_digraph = 259,
+     T_strict = 260,
+     T_node = 261,
+     T_edge = 262,
+     T_edgeop = 263,
+     T_symbol = 264,
+     T_qsymbol = 265,
+     T_subgraph = 266
+   };
+#endif
+/* Tokens.  */
+#define T_graph 258
+#define T_digraph 259
+#define T_strict 260
+#define T_node 261
+#define T_edge 262
+#define T_edgeop 263
+#define T_symbol 264
+#define T_qsymbol 265
+#define T_subgraph 266
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 304 "../../lib/graph/parser.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 308 "../../lib/graph/parser.y"
+
 			int					i;
 			char				*str;
 			struct objport_t	obj;
 			struct Agnode_t		*n;
-}
-/* Line 187 of yacc.c.  */
-#line 412 "y.tab.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 432 "y.tab.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define agstype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 425 "y.tab.c"
+/* Line 264 of yacc.c  */
+#line 444 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -496,14 +515,14 @@ typedef short int agtype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int agi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (agi)
+    int agi;
 #endif
 {
-  return i;
+  return agi;
 }
 #endif
 
@@ -584,9 +603,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union agalloc
 {
-  agtype_int16 agss;
-  YYSTYPE agvs;
-  };
+  agtype_int16 agss_alloc;
+  YYSTYPE agvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union agalloc) - 1)
@@ -620,12 +639,12 @@ union agalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T agnewbytes;						\
-	YYCOPY (&agptr->Stack, Stack, agsize);				\
-	Stack = &agptr->Stack;						\
+	YYCOPY (&agptr->Stack_alloc, Stack, agsize);			\
+	Stack = &agptr->Stack_alloc;					\
 	agnewbytes = agstacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	agptr += agnewbytes / sizeof (*agptr);				\
       }									\
@@ -726,13 +745,13 @@ static const agtype_int8 agrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const agtype_uint16 agrline[] =
 {
-       0,   322,   322,   321,   325,   332,   335,   335,   338,   340,
-     342,   344,   348,   350,   352,   356,   357,   360,   361,   364,
-     367,   368,   371,   374,   378,   379,   383,   384,   387,   388,
-     391,   392,   393,   396,   397,   398,   399,   402,   404,   408,
-     418,   421,   422,   423,   427,   426,   433,   435,   432,   440,
-     442,   439,   448,   450,   449,   452,   455,   454,   460,   461,
-     461,   462,   462,   463,   466,   476,   477,   480,   481
+       0,   326,   326,   325,   329,   336,   339,   339,   342,   344,
+     346,   348,   352,   354,   356,   360,   361,   364,   365,   368,
+     371,   372,   375,   378,   382,   383,   387,   388,   391,   392,
+     395,   396,   397,   400,   401,   402,   403,   406,   408,   412,
+     422,   425,   426,   427,   431,   430,   437,   439,   436,   444,
+     446,   443,   452,   454,   453,   456,   459,   458,   464,   465,
+     465,   466,   466,   467,   470,   480,   481,   484,   485
 };
 #endif
 
@@ -744,12 +763,13 @@ static const char *const agtname[] =
   "$end", "error", "$undefined", "T_graph", "T_digraph", "T_strict",
   "T_node", "T_edge", "T_edgeop", "T_symbol", "T_qsymbol", "T_subgraph",
   "'{'", "'}'", "','", "'['", "']'", "'='", "';'", "':'", "'+'", "$accept",
-  "file", "@1", "optgraphname", "graph_type", "attr_class",
+  "file", "$@1", "optgraphname", "graph_type", "attr_class",
   "inside_attr_list", "optcomma", "attr_list", "rec_attr_list",
   "opt_attr_list", "attr_set", "iattr_set", "stmt_list", "stmt_list1",
   "stmt", "stmt1", "attr_stmt", "node_id", "node_name", "node_port",
-  "node_stmt", "@2", "edge_stmt", "@3", "@4", "@5", "@6", "edgeRHS", "@7",
-  "@8", "subg_stmt", "@9", "@10", "subg_hdr", "symbol", "qsymbol", 0
+  "node_stmt", "$@2", "edge_stmt", "$@3", "$@4", "$@5", "$@6", "edgeRHS",
+  "$@7", "$@8", "subg_stmt", "$@9", "$@10", "subg_hdr", "symbol",
+  "qsymbol", 0
 };
 #endif
 
@@ -1066,17 +1086,20 @@ ag_symbol_print (agoutput, agtype, agvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-ag_stack_print (agtype_int16 *bottom, agtype_int16 *top)
+ag_stack_print (agtype_int16 *agbottom, agtype_int16 *agtop)
 #else
 static void
-ag_stack_print (bottom, top)
-    agtype_int16 *bottom;
-    agtype_int16 *top;
+ag_stack_print (agbottom, agtop)
+    agtype_int16 *agbottom;
+    agtype_int16 *agtop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; agbottom <= agtop; agbottom++)
+    {
+      int agbot = *agbottom;
+      YYFPRINTF (stderr, " %d", agbot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -1110,11 +1133,11 @@ ag_reduce_print (agvsp, agrule)
   /* The symbols being reduced.  */
   for (agi = 0; agi < agnrhs; agi++)
     {
-      fprintf (stderr, "   $%d = ", agi + 1);
+      YYFPRINTF (stderr, "   $%d = ", agi + 1);
       ag_symbol_print (stderr, agrhs[agprhs[agrule] + agi],
 		       &(agvsp[(agi + 1) - (agnrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1394,10 +1417,8 @@ agdestruct (agmsg, agtype, agvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int agparse (void *YYPARSE_PARAM);
@@ -1413,11 +1434,10 @@ int agparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int agchar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE aglval;
 
 /* Number of syntax errors so far.  */
@@ -1425,9 +1445,9 @@ int agnerrs;
 
 
 
-/*----------.
-| agparse.  |
-`----------*/
+/*-------------------------.
+| agparse or agpush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1451,14 +1471,39 @@ agparse ()
 #endif
 #endif
 {
-  
-  int agstate;
+
+
+    int agstate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int agerrstatus;
+
+    /* The stacks and their tools:
+       `agss': related to states.
+       `agvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow agoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    agtype_int16 agssa[YYINITDEPTH];
+    agtype_int16 *agss;
+    agtype_int16 *agssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE agvsa[YYINITDEPTH];
+    YYSTYPE *agvs;
+    YYSTYPE *agvsp;
+
+    YYSIZE_T agstacksize;
+
   int agn;
   int agresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int agerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int agtoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int agtoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE agval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char agmsgbuf[128];
@@ -1466,51 +1511,28 @@ agparse ()
   YYSIZE_T agmsg_alloc = sizeof agmsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `agss': related to states,
-     `agvs': related to semantic values,
-     `agls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow agoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  agtype_int16 agssa[YYINITDEPTH];
-  agtype_int16 *agss = agssa;
-  agtype_int16 *agssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE agvsa[YYINITDEPTH];
-  YYSTYPE *agvs = agvsa;
-  YYSTYPE *agvsp;
-
-
-
 #define YYPOPSTACK(N)   (agvsp -= (N), agssp -= (N))
 
-  YYSIZE_T agstacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE agval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int aglen = 0;
 
+  agtoken = 0;
+  agss = agssa;
+  agvs = agvsa;
+  agstacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   agstate = 0;
   agerrstatus = 0;
   agnerrs = 0;
-  agchar = YYEMPTY;		/* Cause a token to be read.  */
+  agchar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   agssp = agss;
   agvsp = agvs;
 
@@ -1540,7 +1562,6 @@ agparse ()
 	YYSTYPE *agvs1 = agvs;
 	agtype_int16 *agss1 = agss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1548,7 +1569,6 @@ agparse ()
 	agoverflow (YY_("memory exhausted"),
 		    &agss1, agsize * sizeof (*agssp),
 		    &agvs1, agsize * sizeof (*agvsp),
-
 		    &agstacksize);
 
 	agss = agss1;
@@ -1571,9 +1591,8 @@ agparse ()
 	  (union agalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (agstacksize));
 	if (! agptr)
 	  goto agexhaustedlab;
-	YYSTACK_RELOCATE (agss);
-	YYSTACK_RELOCATE (agvs);
-
+	YYSTACK_RELOCATE (agss_alloc, agss);
+	YYSTACK_RELOCATE (agvs_alloc, agvs);
 #  undef YYSTACK_RELOCATE
 	if (agss1 != agssa)
 	  YYSTACK_FREE (agss1);
@@ -1584,7 +1603,6 @@ agparse ()
       agssp = agss + agsize - 1;
       agvsp = agvs + agsize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) agstacksize));
 
@@ -1594,6 +1612,9 @@ agparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", agstate));
 
+  if (agstate == YYFINAL)
+    YYACCEPT;
+
   goto agbackup;
 
 /*-----------.
@@ -1602,16 +1623,16 @@ agparse ()
 agbackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   agn = agpact[agstate];
   if (agn == YYPACT_NINF)
     goto agdefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (agchar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1643,20 +1664,16 @@ agbackup:
       goto agreduce;
     }
 
-  if (agn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (agerrstatus)
     agerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", agtoken, &aglval, &aglloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (agchar != YYEOF)
-    agchar = YYEMPTY;
+  /* Discard the shifted token.  */
+  agchar = YYEMPTY;
 
   agstate = agn;
   *++agvsp = aglval;
@@ -1696,17 +1713,23 @@ agreduce:
   switch (agn)
     {
         case 2:
-#line 322 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 326 "../../lib/graph/parser.y"
     {begin_graph((agvsp[(2) - (2)].str)); agstrfree((agvsp[(2) - (2)].str));}
     break;
 
   case 3:
-#line 324 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 328 "../../lib/graph/parser.y"
     {AG.accepting_state = TRUE; end_graph();}
     break;
 
   case 4:
-#line 326 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 330 "../../lib/graph/parser.y"
     {
 					if (AG.parsed_g)
 						agclose(AG.parsed_g);
@@ -1716,87 +1739,121 @@ agreduce:
     break;
 
   case 5:
-#line 332 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 336 "../../lib/graph/parser.y"
     {AG.parsed_g = NULL;}
     break;
 
   case 6:
-#line 335 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 339 "../../lib/graph/parser.y"
     {(agval.str)=(agvsp[(1) - (1)].str);}
     break;
 
   case 7:
-#line 335 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 339 "../../lib/graph/parser.y"
     {(agval.str)=0;}
     break;
 
   case 8:
-#line 339 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 343 "../../lib/graph/parser.y"
     {Agraph_type = AGRAPH; AG.edge_op = "--";}
     break;
 
   case 9:
-#line 341 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 345 "../../lib/graph/parser.y"
     {Agraph_type = AGRAPHSTRICT; AG.edge_op = "--";}
     break;
 
   case 10:
-#line 343 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 347 "../../lib/graph/parser.y"
     {Agraph_type = AGDIGRAPH; AG.edge_op = "->";}
     break;
 
   case 11:
-#line 345 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 349 "../../lib/graph/parser.y"
     {Agraph_type = AGDIGRAPHSTRICT; AG.edge_op = "->";}
     break;
 
   case 12:
-#line 349 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 353 "../../lib/graph/parser.y"
     {Current_class = TAG_GRAPH;}
     break;
 
   case 13:
-#line 351 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 355 "../../lib/graph/parser.y"
     {Current_class = TAG_NODE; N = G->proto->n;}
     break;
 
   case 14:
-#line 353 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 357 "../../lib/graph/parser.y"
     {Current_class = TAG_EDGE; E = G->proto->e;}
     break;
 
   case 23:
-#line 375 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 379 "../../lib/graph/parser.y"
     {attr_set((agvsp[(1) - (3)].str),(agvsp[(3) - (3)].str)); agstrfree((agvsp[(1) - (3)].str)); agstrfree((agvsp[(3) - (3)].str));}
     break;
 
   case 25:
-#line 380 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 384 "../../lib/graph/parser.y"
     {attr_set((agvsp[(1) - (1)].str),"true"); agstrfree((agvsp[(1) - (1)].str)); }
     break;
 
   case 32:
-#line 393 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 397 "../../lib/graph/parser.y"
     {agerror("syntax error, statement skipped");}
     break;
 
   case 36:
-#line 399 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 403 "../../lib/graph/parser.y"
     {}
     break;
 
   case 37:
-#line 403 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 407 "../../lib/graph/parser.y"
     {Current_class = TAG_GRAPH; /* reset */}
     break;
 
   case 38:
-#line 405 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 409 "../../lib/graph/parser.y"
     {Current_class = TAG_GRAPH;}
     break;
 
   case 39:
-#line 409 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 413 "../../lib/graph/parser.y"
     {
 					objport_t		rv;
 					rv.obj = (agvsp[(1) - (2)].n);
@@ -1807,114 +1864,158 @@ agreduce:
     break;
 
   case 40:
-#line 418 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 422 "../../lib/graph/parser.y"
     {(agval.n) = bind_node((agvsp[(1) - (1)].str)); agstrfree((agvsp[(1) - (1)].str));}
     break;
 
   case 42:
-#line 422 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 426 "../../lib/graph/parser.y"
     { Port=(agvsp[(2) - (2)].str);}
     break;
 
   case 43:
-#line 423 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 427 "../../lib/graph/parser.y"
     {Port=concat3((agvsp[(2) - (4)].str),":",(agvsp[(4) - (4)].str));agstrfree((agvsp[(2) - (4)].str)); agstrfree((agvsp[(4) - (4)].str));}
     break;
 
   case 44:
-#line 427 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 431 "../../lib/graph/parser.y"
     {Current_class = TAG_NODE; N = (Agnode_t*)((agvsp[(1) - (1)].obj).obj);}
     break;
 
   case 45:
-#line 429 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 433 "../../lib/graph/parser.y"
     {agstrfree((agvsp[(1) - (3)].obj).port);Current_class = TAG_GRAPH; /* reset */}
     break;
 
   case 46:
-#line 433 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 437 "../../lib/graph/parser.y"
     {begin_edgestmt((agvsp[(1) - (1)].obj));}
     break;
 
   case 47:
-#line 435 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 439 "../../lib/graph/parser.y"
     { E = SP->subg->proto->e;
 				  Current_class = TAG_EDGE; }
     break;
 
   case 48:
-#line 438 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 442 "../../lib/graph/parser.y"
     {end_edgestmt();}
     break;
 
   case 49:
-#line 440 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 444 "../../lib/graph/parser.y"
     {begin_edgestmt((agvsp[(1) - (1)].obj));}
     break;
 
   case 50:
-#line 442 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 446 "../../lib/graph/parser.y"
     { E = SP->subg->proto->e;
 				  Current_class = TAG_EDGE; }
     break;
 
   case 51:
-#line 445 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 449 "../../lib/graph/parser.y"
     {end_edgestmt();}
     break;
 
   case 52:
-#line 448 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 452 "../../lib/graph/parser.y"
     {mid_edgestmt((agvsp[(2) - (2)].obj));}
     break;
 
   case 53:
-#line 450 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 454 "../../lib/graph/parser.y"
     {mid_edgestmt((agvsp[(2) - (2)].obj));}
     break;
 
   case 55:
-#line 453 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 457 "../../lib/graph/parser.y"
     {mid_edgestmt((agvsp[(2) - (2)].obj));}
     break;
 
   case 56:
-#line 455 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 459 "../../lib/graph/parser.y"
     {mid_edgestmt((agvsp[(2) - (2)].obj));}
     break;
 
   case 58:
-#line 460 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 464 "../../lib/graph/parser.y"
     {(agval.obj) = pop_gobj();}
     break;
 
   case 59:
-#line 461 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 465 "../../lib/graph/parser.y"
     { anonsubg(); }
     break;
 
   case 60:
-#line 461 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 465 "../../lib/graph/parser.y"
     {(agval.obj) = pop_gobj();}
     break;
 
   case 61:
-#line 462 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 466 "../../lib/graph/parser.y"
     { anonsubg(); }
     break;
 
   case 62:
-#line 462 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 466 "../../lib/graph/parser.y"
     {(agval.obj) = pop_gobj();}
     break;
 
   case 63:
-#line 463 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 467 "../../lib/graph/parser.y"
     {subgraph_warn(); (agval.obj) = pop_gobj();}
     break;
 
   case 64:
-#line 467 "../../lib/graph/parser.y"
+
+/* Line 1455 of yacc.c  */
+#line 471 "../../lib/graph/parser.y"
     { Agraph_t	 *subg;
 				if ((subg = agfindsubg(AG.parsed_g,(agvsp[(2) - (2)].str)))) aginsert(G,subg);
 				else subg = agsubg(G,(agvsp[(2) - (2)].str)); 
@@ -1925,28 +2026,37 @@ agreduce:
     break;
 
   case 65:
-#line 476 "../../lib/graph/parser.y"
-    {(agval.str) = (agvsp[(1) - (1)].str); }
-    break;
 
-  case 66:
-#line 477 "../../lib/graph/parser.y"
-    {(agval.str) = (agvsp[(1) - (1)].str); }
-    break;
-
-  case 67:
+/* Line 1455 of yacc.c  */
 #line 480 "../../lib/graph/parser.y"
     {(agval.str) = (agvsp[(1) - (1)].str); }
     break;
 
-  case 68:
+  case 66:
+
+/* Line 1455 of yacc.c  */
 #line 481 "../../lib/graph/parser.y"
+    {(agval.str) = (agvsp[(1) - (1)].str); }
+    break;
+
+  case 67:
+
+/* Line 1455 of yacc.c  */
+#line 484 "../../lib/graph/parser.y"
+    {(agval.str) = (agvsp[(1) - (1)].str); }
+    break;
+
+  case 68:
+
+/* Line 1455 of yacc.c  */
+#line 485 "../../lib/graph/parser.y"
     {(agval.str) = concat((agvsp[(1) - (3)].str),(agvsp[(3) - (3)].str)); agstrfree((agvsp[(1) - (3)].str)); agstrfree((agvsp[(3) - (3)].str));}
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1950 "y.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 2060 "y.tab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", agr1[agn], &agval, &agloc);
@@ -1957,7 +2067,6 @@ agreduce:
 
   *++agvsp = agval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2022,7 +2131,7 @@ agerrlab:
 
   if (agerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (agchar <= YYEOF)
@@ -2039,7 +2148,7 @@ agerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto agerrlab1;
 
@@ -2096,9 +2205,6 @@ agerrlab1:
       YY_STACK_PRINT (agss, agssp);
     }
 
-  if (agn == YYFINAL)
-    YYACCEPT;
-
   *++agvsp = aglval;
 
 
@@ -2123,7 +2229,7 @@ agabortlab:
   agresult = 1;
   goto agreturn;
 
-#ifndef agoverflow
+#if !defined(agoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | agexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2134,7 +2240,7 @@ agexhaustedlab:
 #endif
 
 agreturn:
-  if (agchar != YYEOF && agchar != YYEMPTY)
+  if (agchar != YYEMPTY)
      agdestruct ("Cleanup: discarding lookahead",
 		 agtoken, &aglval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2160,7 +2266,9 @@ agreturn:
 }
 
 
-#line 483 "../../lib/graph/parser.y"
+
+/* Line 1675 of yacc.c  */
+#line 487 "../../lib/graph/parser.y"
 
 #ifdef UNUSED
 /* grammar allowing port variants */
