@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,43 +54,20 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     T_graph = 258,
-     T_digraph = 259,
-     T_strict = 260,
-     T_node = 261,
-     T_edge = 262,
-     T_edgeop = 263,
-     T_symbol = 264,
-     T_qsymbol = 265,
-     T_subgraph = 266
-   };
-#endif
-/* Tokens.  */
-#define T_graph 258
-#define T_digraph 259
-#define T_strict 260
-#define T_node 261
-#define T_edge 262
-#define T_edgeop 263
-#define T_symbol 264
-#define T_qsymbol 265
-#define T_subgraph 266
-
-
-
-
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 17 "../../lib/graph/parser.y"
 
 
@@ -384,6 +360,9 @@ concat3 (char* s1, char* s2, char*s3)
 
 
 
+/* Line 189 of yacc.c  */
+#line 365 "y.tab.c"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -402,30 +381,66 @@ concat3 (char* s1, char* s2, char*s3)
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     T_graph = 258,
+     T_digraph = 259,
+     T_strict = 260,
+     T_node = 261,
+     T_edge = 262,
+     T_edgeop = 263,
+     T_symbol = 264,
+     T_qsymbol = 265,
+     T_subgraph = 266
+   };
+#endif
+/* Tokens.  */
+#define T_graph 258
+#define T_digraph 259
+#define T_strict 260
+#define T_node 261
+#define T_edge 262
+#define T_edgeop 263
+#define T_symbol 264
+#define T_qsymbol 265
+#define T_subgraph 266
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 308 "../../lib/graph/parser.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 308 "../../lib/graph/parser.y"
+
 			int					i;
 			char				*str;
 			struct objport_t	obj;
 			struct Agnode_t		*n;
-}
-/* Line 187 of yacc.c.  */
-#line 416 "y.tab.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 432 "y.tab.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 429 "y.tab.c"
+/* Line 264 of yacc.c  */
+#line 444 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -500,14 +515,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -588,9 +603,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -624,12 +639,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -748,12 +763,13 @@ static const char *const yytname[] =
   "$end", "error", "$undefined", "T_graph", "T_digraph", "T_strict",
   "T_node", "T_edge", "T_edgeop", "T_symbol", "T_qsymbol", "T_subgraph",
   "'{'", "'}'", "','", "'['", "']'", "'='", "';'", "':'", "'+'", "$accept",
-  "file", "@1", "optgraphname", "graph_type", "attr_class",
+  "file", "$@1", "optgraphname", "graph_type", "attr_class",
   "inside_attr_list", "optcomma", "attr_list", "rec_attr_list",
   "opt_attr_list", "attr_set", "iattr_set", "stmt_list", "stmt_list1",
   "stmt", "stmt1", "attr_stmt", "node_id", "node_name", "node_port",
-  "node_stmt", "@2", "edge_stmt", "@3", "@4", "@5", "@6", "edgeRHS", "@7",
-  "@8", "subg_stmt", "@9", "@10", "subg_hdr", "symbol", "qsymbol", 0
+  "node_stmt", "$@2", "edge_stmt", "$@3", "$@4", "$@5", "$@6", "edgeRHS",
+  "$@7", "$@8", "subg_stmt", "$@9", "$@10", "subg_hdr", "symbol",
+  "qsymbol", 0
 };
 #endif
 
@@ -1070,17 +1086,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -1114,11 +1133,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1398,10 +1417,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1417,11 +1434,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1429,9 +1445,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1455,14 +1471,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1470,51 +1511,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1544,7 +1562,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1552,7 +1569,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1575,9 +1591,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1588,7 +1603,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1598,6 +1612,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1606,16 +1623,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1647,20 +1664,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1700,16 +1713,22 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 326 "../../lib/graph/parser.y"
     {begin_graph((yyvsp[(2) - (2)].str)); agstrfree((yyvsp[(2) - (2)].str));}
     break;
 
   case 3:
+
+/* Line 1455 of yacc.c  */
 #line 328 "../../lib/graph/parser.y"
     {AG.accepting_state = TRUE; end_graph();}
     break;
 
   case 4:
+
+/* Line 1455 of yacc.c  */
 #line 330 "../../lib/graph/parser.y"
     {
 					if (AG.parsed_g)
@@ -1720,86 +1739,120 @@ yyreduce:
     break;
 
   case 5:
+
+/* Line 1455 of yacc.c  */
 #line 336 "../../lib/graph/parser.y"
     {AG.parsed_g = NULL;}
     break;
 
   case 6:
+
+/* Line 1455 of yacc.c  */
 #line 339 "../../lib/graph/parser.y"
     {(yyval.str)=(yyvsp[(1) - (1)].str);}
     break;
 
   case 7:
+
+/* Line 1455 of yacc.c  */
 #line 339 "../../lib/graph/parser.y"
     {(yyval.str)=0;}
     break;
 
   case 8:
+
+/* Line 1455 of yacc.c  */
 #line 343 "../../lib/graph/parser.y"
     {Agraph_type = AGRAPH; AG.edge_op = "--";}
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 345 "../../lib/graph/parser.y"
     {Agraph_type = AGRAPHSTRICT; AG.edge_op = "--";}
     break;
 
   case 10:
+
+/* Line 1455 of yacc.c  */
 #line 347 "../../lib/graph/parser.y"
     {Agraph_type = AGDIGRAPH; AG.edge_op = "->";}
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 349 "../../lib/graph/parser.y"
     {Agraph_type = AGDIGRAPHSTRICT; AG.edge_op = "->";}
     break;
 
   case 12:
+
+/* Line 1455 of yacc.c  */
 #line 353 "../../lib/graph/parser.y"
     {Current_class = TAG_GRAPH;}
     break;
 
   case 13:
+
+/* Line 1455 of yacc.c  */
 #line 355 "../../lib/graph/parser.y"
     {Current_class = TAG_NODE; N = G->proto->n;}
     break;
 
   case 14:
+
+/* Line 1455 of yacc.c  */
 #line 357 "../../lib/graph/parser.y"
     {Current_class = TAG_EDGE; E = G->proto->e;}
     break;
 
   case 23:
+
+/* Line 1455 of yacc.c  */
 #line 379 "../../lib/graph/parser.y"
     {attr_set((yyvsp[(1) - (3)].str),(yyvsp[(3) - (3)].str)); agstrfree((yyvsp[(1) - (3)].str)); agstrfree((yyvsp[(3) - (3)].str));}
     break;
 
   case 25:
+
+/* Line 1455 of yacc.c  */
 #line 384 "../../lib/graph/parser.y"
     {attr_set((yyvsp[(1) - (1)].str),"true"); agstrfree((yyvsp[(1) - (1)].str)); }
     break;
 
   case 32:
+
+/* Line 1455 of yacc.c  */
 #line 397 "../../lib/graph/parser.y"
     {agerror("syntax error, statement skipped");}
     break;
 
   case 36:
+
+/* Line 1455 of yacc.c  */
 #line 403 "../../lib/graph/parser.y"
     {}
     break;
 
   case 37:
+
+/* Line 1455 of yacc.c  */
 #line 407 "../../lib/graph/parser.y"
     {Current_class = TAG_GRAPH; /* reset */}
     break;
 
   case 38:
+
+/* Line 1455 of yacc.c  */
 #line 409 "../../lib/graph/parser.y"
     {Current_class = TAG_GRAPH;}
     break;
 
   case 39:
+
+/* Line 1455 of yacc.c  */
 #line 413 "../../lib/graph/parser.y"
     {
 					objport_t		rv;
@@ -1811,113 +1864,157 @@ yyreduce:
     break;
 
   case 40:
+
+/* Line 1455 of yacc.c  */
 #line 422 "../../lib/graph/parser.y"
     {(yyval.n) = bind_node((yyvsp[(1) - (1)].str)); agstrfree((yyvsp[(1) - (1)].str));}
     break;
 
   case 42:
+
+/* Line 1455 of yacc.c  */
 #line 426 "../../lib/graph/parser.y"
     { Port=(yyvsp[(2) - (2)].str);}
     break;
 
   case 43:
+
+/* Line 1455 of yacc.c  */
 #line 427 "../../lib/graph/parser.y"
     {Port=concat3((yyvsp[(2) - (4)].str),":",(yyvsp[(4) - (4)].str));agstrfree((yyvsp[(2) - (4)].str)); agstrfree((yyvsp[(4) - (4)].str));}
     break;
 
   case 44:
+
+/* Line 1455 of yacc.c  */
 #line 431 "../../lib/graph/parser.y"
     {Current_class = TAG_NODE; N = (Agnode_t*)((yyvsp[(1) - (1)].obj).obj);}
     break;
 
   case 45:
+
+/* Line 1455 of yacc.c  */
 #line 433 "../../lib/graph/parser.y"
     {agstrfree((yyvsp[(1) - (3)].obj).port);Current_class = TAG_GRAPH; /* reset */}
     break;
 
   case 46:
+
+/* Line 1455 of yacc.c  */
 #line 437 "../../lib/graph/parser.y"
     {begin_edgestmt((yyvsp[(1) - (1)].obj));}
     break;
 
   case 47:
+
+/* Line 1455 of yacc.c  */
 #line 439 "../../lib/graph/parser.y"
     { E = SP->subg->proto->e;
 				  Current_class = TAG_EDGE; }
     break;
 
   case 48:
+
+/* Line 1455 of yacc.c  */
 #line 442 "../../lib/graph/parser.y"
     {end_edgestmt();}
     break;
 
   case 49:
+
+/* Line 1455 of yacc.c  */
 #line 444 "../../lib/graph/parser.y"
     {begin_edgestmt((yyvsp[(1) - (1)].obj));}
     break;
 
   case 50:
+
+/* Line 1455 of yacc.c  */
 #line 446 "../../lib/graph/parser.y"
     { E = SP->subg->proto->e;
 				  Current_class = TAG_EDGE; }
     break;
 
   case 51:
+
+/* Line 1455 of yacc.c  */
 #line 449 "../../lib/graph/parser.y"
     {end_edgestmt();}
     break;
 
   case 52:
+
+/* Line 1455 of yacc.c  */
 #line 452 "../../lib/graph/parser.y"
     {mid_edgestmt((yyvsp[(2) - (2)].obj));}
     break;
 
   case 53:
+
+/* Line 1455 of yacc.c  */
 #line 454 "../../lib/graph/parser.y"
     {mid_edgestmt((yyvsp[(2) - (2)].obj));}
     break;
 
   case 55:
+
+/* Line 1455 of yacc.c  */
 #line 457 "../../lib/graph/parser.y"
     {mid_edgestmt((yyvsp[(2) - (2)].obj));}
     break;
 
   case 56:
+
+/* Line 1455 of yacc.c  */
 #line 459 "../../lib/graph/parser.y"
     {mid_edgestmt((yyvsp[(2) - (2)].obj));}
     break;
 
   case 58:
+
+/* Line 1455 of yacc.c  */
 #line 464 "../../lib/graph/parser.y"
     {(yyval.obj) = pop_gobj();}
     break;
 
   case 59:
+
+/* Line 1455 of yacc.c  */
 #line 465 "../../lib/graph/parser.y"
     { anonsubg(); }
     break;
 
   case 60:
+
+/* Line 1455 of yacc.c  */
 #line 465 "../../lib/graph/parser.y"
     {(yyval.obj) = pop_gobj();}
     break;
 
   case 61:
+
+/* Line 1455 of yacc.c  */
 #line 466 "../../lib/graph/parser.y"
     { anonsubg(); }
     break;
 
   case 62:
+
+/* Line 1455 of yacc.c  */
 #line 466 "../../lib/graph/parser.y"
     {(yyval.obj) = pop_gobj();}
     break;
 
   case 63:
+
+/* Line 1455 of yacc.c  */
 #line 467 "../../lib/graph/parser.y"
     {subgraph_warn(); (yyval.obj) = pop_gobj();}
     break;
 
   case 64:
+
+/* Line 1455 of yacc.c  */
 #line 471 "../../lib/graph/parser.y"
     { Agraph_t	 *subg;
 				if ((subg = agfindsubg(AG.parsed_g,(yyvsp[(2) - (2)].str)))) aginsert(G,subg);
@@ -1929,28 +2026,37 @@ yyreduce:
     break;
 
   case 65:
+
+/* Line 1455 of yacc.c  */
 #line 480 "../../lib/graph/parser.y"
     {(yyval.str) = (yyvsp[(1) - (1)].str); }
     break;
 
   case 66:
+
+/* Line 1455 of yacc.c  */
 #line 481 "../../lib/graph/parser.y"
     {(yyval.str) = (yyvsp[(1) - (1)].str); }
     break;
 
   case 67:
+
+/* Line 1455 of yacc.c  */
 #line 484 "../../lib/graph/parser.y"
     {(yyval.str) = (yyvsp[(1) - (1)].str); }
     break;
 
   case 68:
+
+/* Line 1455 of yacc.c  */
 #line 485 "../../lib/graph/parser.y"
     {(yyval.str) = concat((yyvsp[(1) - (3)].str),(yyvsp[(3) - (3)].str)); agstrfree((yyvsp[(1) - (3)].str)); agstrfree((yyvsp[(3) - (3)].str));}
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1954 "y.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 2060 "y.tab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1961,7 +2067,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2026,7 +2131,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2043,7 +2148,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2100,9 +2205,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2127,7 +2229,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2138,7 +2240,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2164,6 +2266,8 @@ yyreturn:
 }
 
 
+
+/* Line 1675 of yacc.c  */
 #line 487 "../../lib/graph/parser.y"
 
 #ifdef UNUSED
