@@ -1,4 +1,4 @@
- /* $Id: gvc.c,v 1.62 2009/06/03 01:10:53 ellson Exp $ $Revision: 1.62 $ */
+ /* $Id: gvc.c,v 1.63 2009/07/14 13:18:07 ellson Exp $ $Revision: 1.63 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -38,7 +38,7 @@ GVC_t *gvContext(void)
 #endif
     /* default to no builtins, demand loading enabled */
     gvc = gvNEWcontext(NULL, TRUE);
-    gvconfig(gvc, FALSE); /* configure for available plugins and codegens */
+    gvconfig(gvc, FALSE); /* configure for available plugins */
     return gvc;
 }
 
@@ -53,7 +53,7 @@ GVC_t *gvContextPlugins(const lt_symlist_t *builtins, int demand_loading)
     agattr(NULL, AGNODE, "label", NODENAME_ESC);
 #endif
     gvc = gvNEWcontext(builtins, demand_loading);
-    gvconfig(gvc, FALSE); /* configure for available plugins and codegens */
+    gvconfig(gvc, FALSE); /* configure for available plugins */
     return gvc;
 }
 
