@@ -1,4 +1,4 @@
-/* $Id: gvcint.h,v 1.81 2008/10/14 04:17:44 ellson Exp $ $Revision: 1.81 $ */
+/* $Id: gvcint.h,v 1.86 2009/08/28 19:46:42 erg Exp $ $Revision: 1.86 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -49,12 +49,11 @@ extern "C" {
     };
 
     struct gvplugin_available_s {
-	gvplugin_available_t *next;       /* next plugin in linked list, or NULL */
-	const char *typestr;		 /* type string, e.g. "png" or "ps" */
-	int quality;             /* programmer assigned quality
-					ranking within type (+ve or -ve int)
-					- codegens have quality = 0 */
-	gvplugin_package_t *package;   /* details of library containing plugin */
+	gvplugin_available_t *next;     /* next plugin in linked list, or NULL */
+	const char *typestr;		/* type string, e.g. "png" or "ps" */
+	int quality;			/* Programmer assigned quality ranking within type (+ve or -ve int).
+					First implementation of type should be given "0" quality */
+	gvplugin_package_t *package;	/* details of library containing plugin */
 	gvplugin_installed_t *typeptr;  /* pointer to jumptable for plugin,
 					or NULL if not yet loaded */
     };
