@@ -1,4 +1,4 @@
-/* $Id: gvcjob.h,v 1.79 2009/02/18 13:36:50 glenlow Exp $ $Revision: 1.79 $ */
+/* $Id: gvcjob.h,v 1.83 2009/10/15 17:28:19 erg Exp $ $Revision: 1.83 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -179,11 +179,13 @@ extern "C" {
 
     typedef enum {ROOTGRAPH_OBJTYPE, CLUSTER_OBJTYPE, NODE_OBJTYPE, EDGE_OBJTYPE} obj_type;
 
-    /* See comment in gvrender_core_dot.c */
+    /* If this enum is changed, the implementation of xbuf and xbufs in
+     * gvrender_core_dot.c will probably need to be changed.
+     */
     typedef enum {
 	EMIT_GDRAW, EMIT_CDRAW, EMIT_TDRAW, EMIT_HDRAW, 
-	EMIT_GLABEL, EMIT_CLABEL, EMIT_TLABEL, EMIT_HLABEL,
-	EMIT_NDRAW, EMIT_EDRAW, EMIT_NLABEL, EMIT_ELABEL,  
+	EMIT_GLABEL, EMIT_CLABEL, EMIT_TLABEL, EMIT_HLABEL, 
+	EMIT_NDRAW, EMIT_EDRAW, EMIT_NLABEL, EMIT_ELABEL,
     } emit_state_t;
 
     typedef struct obj_state_s obj_state_t;
@@ -211,6 +213,7 @@ extern "C" {
 
 	/* fully substituted text strings */
 	char *label;
+	char *xlabel;
 	char *taillabel;
 	char *headlabel; 
 
@@ -366,12 +369,6 @@ extern "C" {
 	gvevent_key_binding_t *keybindings;
 	int numkeys;
 	void *keycodes;
-
-/* Must be last as separately compiled plugins are not compiled with WITH_CODEGENS */
-#ifdef WITH_CODEGENS
-	pointf	pageOffset;	/* offset for current page in graph units */
-	codegen_t *codegen;	/* current  codegen */
-#endif
     };
 
 #ifdef __cplusplus
