@@ -1,4 +1,4 @@
-/* $Id: gvdevice.c,v 1.69 2009/06/03 01:10:53 ellson Exp $ $Revision: 1.69 $ */
+/* $Id: gvdevice.c,v 1.72 2009/10/13 14:22:50 ellson Exp $ $Revision: 1.72 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -59,10 +59,6 @@ static unsigned long int crc;
 #include "logic.h"
 #include "gvio.h"
 
-#ifdef WITH_CODEGENS
-extern FILE* Output_file;
-#endif
-
 static const int PAGE_ALIGN = 4095;		/* align to a 4K boundary (less one), typical for Linux, Mac OS X and Windows memory allocation */
 
 static size_t gvwrite_no_z (GVJ_t * job, const char *s, size_t len)
@@ -151,10 +147,6 @@ void gvdevice_initialize(GVJ_t * job)
         else
             job->output_file = stdout;
 
-#ifdef WITH_CODEGENS
-        Output_file = job->output_file;
-#endif
-
 #ifdef HAVE_SETMODE
 #ifdef O_BINARY
         if (job->flags & GVDEVICE_BINARY_FORMAT)
@@ -167,9 +159,9 @@ void gvdevice_initialize(GVJ_t * job)
 #ifdef HAVE_LIBZ
 	z_stream *z = &z_strm;
 
-	z->zalloc = (alloc_func)0;
-	z->zfree = (free_func)0;
-	z->opaque = (voidpf)0;
+	z->zalloc = 0;
+	z->zfree = 0;
+	z->opaque = 0;
 	z->next_in = NULL;
 	z->next_out = NULL;
 	z->avail_in = 0;
@@ -288,13 +280,15 @@ int gvputc(GVJ_t * job, int c)
     return c;
 }
 
-static void gvdevice_flush(GVJ_t * job)
+int gvflush (GVJ_t * job)
 {
     if (job->output_file
       && ! job->external_context
       && ! job->gvc->write_fn) {
-	fflush(job->output_file);
+	return fflush(job->output_file);
     }
+    else
+	return 0;
 }
 
 static void gvdevice_close(GVJ_t * job)
@@ -316,7 +310,7 @@ void gvdevice_format(GVJ_t * job)
 
     if (gvde && gvde->format)
 	gvde->format(job);
-    gvdevice_flush(job);
+    gvflush (job);
 }
 
 void gvdevice_finalize(GVJ_t * job)
@@ -372,18 +366,10 @@ void gvdevice_finalize(GVJ_t * job)
 	    finalized_p = TRUE;
 	}
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->reset)
-	    cg->reset();
-    }
-#endif
 
     if (! finalized_p) {
         /* if the device has no finalization then it uses file output */
-	gvdevice_flush(job);
+	gvflush (job);
 	gvdevice_close(job);
     }
 }
