@@ -1,4 +1,4 @@
-/* $Id: gvlayout.c,v 1.35 2009/01/19 22:32:43 arif Exp $ $Revision: 1.35 $ */
+/* $Id: gvlayout.c,v 1.38 2009/07/20 20:16:46 erg Exp $ $Revision: 1.38 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -65,6 +65,9 @@ int gvLayoutJobs(GVC_t * gvc, Agraph_t * g)
     char *p;
     int rc;
 
+#ifdef WITH_CGRAPH
+    agbindrec(g, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
+#endif
     GD_gvc(g) = gvc;
     if (g != agroot(g))
 	GD_gvc(agroot(g)) = gvc;
