@@ -1,4 +1,4 @@
-/* $Id: gvrender.c,v 1.157 2009/02/24 19:47:18 ellson Exp $ $Revision: 1.157 $ */
+/* $Id: gvrender.c,v 1.163 2010/01/26 15:57:58 ellson Exp $ $Revision: 1.163 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -44,13 +44,13 @@ extern int emit_once(char *str);
 extern shape_desc *find_user_shape(char *name);
 extern boolean mapbool(char *s);
 
+#ifndef HAVE_STRCASECMP
+extern int strcasecmp(const char *s1, const char *s2);
+#endif
+
 /* storage for temporary hacks until client API is FP */
 static pointf *AF;
 static int sizeAF;
-#ifdef WITH_CODEGENS
-static point *A;
-static int sizeA;
-#endif
 /* end hack */
 
 int gvrender_select(GVJ_t * job, const char *str)
@@ -58,9 +58,6 @@ int gvrender_select(GVJ_t * job, const char *str)
     GVC_t *gvc = job->gvc;
     gvplugin_available_t *plugin;
     gvplugin_installed_t *typeptr;
-#ifdef WITH_CODEGENS
-    codegen_info_t *cg_info;
-#endif
 
     gvplugin_load(gvc, API_device, str);
 
@@ -71,14 +68,6 @@ int gvrender_select(GVJ_t * job, const char *str)
     /* job->flags = 0; */
     plugin = gvc->api[API_device];
     if (plugin) {
-#ifdef WITH_CODEGENS
-	if (strcmp(plugin->package->name, "cg") == 0) {
-	    cg_info = (codegen_info_t *) (plugin->typeptr);
-	    job->codegen = cg_info->cg;
-	    job->render.engine = NULL;
-	    return cg_info->id;
-	}
-#endif
         typeptr = plugin->typeptr;
         job->device.engine = (gvdevice_engine_t *) (typeptr->engine);
         job->device.features = (gvdevice_features_t *) (typeptr->features);
@@ -122,26 +111,11 @@ int gvrender_features(GVJ_t * job)
     if (gvre) {
 	features = job->render.features->flags;
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg) {
-	    if (cg->bezier_has_arrows)
-		features |= GVRENDER_DOES_ARROWS;
-	    if (cg->begin_layer)
-		features |= GVDEVICE_DOES_LAYERS;
-	}
-    }
-#endif
     return features;
 }
 
 void gvrender_begin_job(GVJ_t * job)
 {
-#ifdef WITH_CODEGENS
-    GVC_t *gvc = job->gvc;
-#endif
     gvrender_engine_t *gvre = job->render.engine;
 
     gvdevice_initialize(job);
@@ -149,17 +123,6 @@ void gvrender_begin_job(GVJ_t * job)
         if (gvre->begin_job)
 	    gvre->begin_job(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->begin_job)
-	    cg->begin_job(job->output_file, gvc->g,
-		    gvc->common.lib,
-		    gvc->common.info,
-		    job->pagesArraySize);
-    }
-#endif
 }
 
 void gvrender_end_job(GVJ_t * job)
@@ -170,14 +133,6 @@ void gvrender_end_job(GVJ_t * job)
        	if (gvre->end_job)
 	    gvre->end_job(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->end_job)
-	    cg->end_job();
-    }
-#endif
     job->gvc->common.lib = NULL;    /* FIXME - minimally this doesn't belong here */
     gvdevice_finalize(job);
 }
@@ -286,17 +241,6 @@ void gvrender_begin_graph(GVJ_t * job, graph_t * g)
 	}
 
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-	box canvasBox;
-
-	BF2B(job->canvasBox, canvasBox);
-
-	if (cg && cg->begin_graph)
-	    cg->begin_graph(gvc, g, canvasBox, gvc->pb);
-    }
-#endif
 }
 
 void gvrender_end_graph(GVJ_t * job)
@@ -307,14 +251,6 @@ void gvrender_end_graph(GVJ_t * job)
        	if (gvre->end_graph)
 	    gvre->end_graph(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->end_graph)
-	    cg->end_graph();
-    }
-#endif
     gvdevice_format(job);
 }
 
@@ -326,17 +262,6 @@ void gvrender_begin_page(GVJ_t * job)
         if (gvre->begin_page)
 	    gvre->begin_page(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-        point offset;
-
-        PF2P(job->pageOffset, offset);
-        if (cg && cg->begin_page)
-            cg->begin_page(job->gvc->g, job->pagesArrayElem,
-               job->zoom, job->rotation, offset);
-    }
-#endif
 }
 
 void gvrender_end_page(GVJ_t * job)
@@ -347,14 +272,6 @@ void gvrender_end_page(GVJ_t * job)
        	if (gvre->end_page)
 	    gvre->end_page(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->end_page)
-	    cg->end_page();
-    }
-#endif
 }
 
 void gvrender_begin_layer(GVJ_t * job)
@@ -365,14 +282,6 @@ void gvrender_begin_layer(GVJ_t * job)
 	if (gvre->begin_layer)
 	    gvre->begin_layer(job, job->gvc->layerIDs[job->layerNum], job->layerNum, job->numLayers);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->begin_layer)
-	    cg->begin_layer(job->gvc->layerIDs[job->layerNum], job->layerNum, job->numLayers);
-    }
-#endif
 }
 
 void gvrender_end_layer(GVJ_t * job)
@@ -383,14 +292,6 @@ void gvrender_end_layer(GVJ_t * job)
         if (gvre->end_layer)
 	    gvre->end_layer(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->end_layer)
-	    cg->end_layer();
-    }
-#endif
 }
 
 void gvrender_begin_cluster(GVJ_t * job, graph_t * sg)
@@ -401,14 +302,6 @@ void gvrender_begin_cluster(GVJ_t * job, graph_t * sg)
 	if (gvre->begin_cluster)
 	    gvre->begin_cluster(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->begin_cluster)
-	    cg->begin_cluster(sg);
-    }
-#endif
 }
 
 void gvrender_end_cluster(GVJ_t * job, graph_t *g)
@@ -419,14 +312,6 @@ void gvrender_end_cluster(GVJ_t * job, graph_t *g)
        	if (gvre->end_cluster)
 	    gvre->end_cluster(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->end_cluster)
-	    cg->end_cluster();
-    }
-#endif
 }
 
 void gvrender_begin_nodes(GVJ_t * job)
@@ -437,14 +322,6 @@ void gvrender_begin_nodes(GVJ_t * job)
 	if (gvre->begin_nodes)
 	    gvre->begin_nodes(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->begin_nodes)
-	    cg->begin_nodes();
-    }
-#endif
 }
 
 void gvrender_end_nodes(GVJ_t * job)
@@ -455,14 +332,6 @@ void gvrender_end_nodes(GVJ_t * job)
 	if (gvre->end_nodes)
 	    gvre->end_nodes(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->end_nodes)
-	    cg->end_nodes();
-    }
-#endif
 }
 
 void gvrender_begin_edges(GVJ_t * job)
@@ -473,14 +342,6 @@ void gvrender_begin_edges(GVJ_t * job)
 	if (gvre->begin_edges)
 	    gvre->begin_edges(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->begin_edges)
-	    cg->begin_edges();
-    }
-#endif
 }
 
 void gvrender_end_edges(GVJ_t * job)
@@ -491,14 +352,6 @@ void gvrender_end_edges(GVJ_t * job)
 	if (gvre->end_edges)
 	    gvre->end_edges(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->end_edges)
-	    cg->end_edges();
-    }
-#endif
 }
 
 void gvrender_begin_node(GVJ_t * job, node_t * n)
@@ -509,14 +362,6 @@ void gvrender_begin_node(GVJ_t * job, node_t * n)
 	if (gvre->begin_node)
 	    gvre->begin_node(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->begin_node)
-	    cg->begin_node(n);
-    }
-#endif
 }
 
 void gvrender_end_node(GVJ_t * job)
@@ -527,14 +372,6 @@ void gvrender_end_node(GVJ_t * job)
 	if (gvre->end_node)
 	    gvre->end_node(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->end_node)
-	    cg->end_node();
-    }
-#endif
 }
 
 void gvrender_begin_edge(GVJ_t * job, edge_t * e)
@@ -545,14 +382,6 @@ void gvrender_begin_edge(GVJ_t * job, edge_t * e)
 	if (gvre->begin_edge)
 	    gvre->begin_edge(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->begin_edge)
-	    cg->begin_edge(e);
-    }
-#endif
 }
 
 void gvrender_end_edge(GVJ_t * job)
@@ -563,36 +392,6 @@ void gvrender_end_edge(GVJ_t * job)
 	if (gvre->end_edge)
 	    gvre->end_edge(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->end_edge)
-	    cg->end_edge();
-    }
-#endif
-}
-
-void gvrender_begin_context(GVJ_t * job)
-{
-#ifdef WITH_CODEGENS
-    gvrender_engine_t *gvre = job->render.engine;
-    codegen_t *cg = job->codegen;
-
-    if (!gvre && cg && cg->begin_context)
-	cg->begin_context();
-#endif
-}
-
-void gvrender_end_context(GVJ_t * job)
-{
-#ifdef WITH_CODEGENS
-    gvrender_engine_t *gvre = job->render.engine;
-    codegen_t *cg = job->codegen;
-
-    if (!gvre && cg && cg->end_context)
-	cg->end_context();
-#endif
 }
 
 void gvrender_begin_anchor(GVJ_t * job, char *href, char *tooltip, char *target, char *id)
@@ -603,14 +402,6 @@ void gvrender_begin_anchor(GVJ_t * job, char *href, char *tooltip, char *target,
 	if (gvre->begin_anchor)
 	    gvre->begin_anchor(job, href, tooltip, target, id);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->begin_anchor)
-	    cg->begin_anchor(href, tooltip, target);
-    }
-#endif
 }
 
 void gvrender_end_anchor(GVJ_t * job)
@@ -621,14 +412,6 @@ void gvrender_end_anchor(GVJ_t * job)
 	if (gvre->end_anchor)
 	    gvre->end_anchor(job);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->end_anchor)
-	    cg->end_anchor();
-    }
-#endif
 }
 
 void gvrender_begin_label(GVJ_t * job, label_type type)
@@ -651,20 +434,6 @@ void gvrender_end_label(GVJ_t * job)
     }
 }
 
-void gvrender_set_font(GVJ_t * job, char *fontname, double fontsize)
-{
-#ifdef WITH_CODEGENS
-    gvrender_engine_t *gvre = job->render.engine;
-
-    if (!gvre) {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->set_font)
-	    cg->set_font(fontname, fontsize);
-    }
-#endif
-}
-
 void gvrender_textpara(GVJ_t * job, pointf p, textpara_t * para)
 {
     gvrender_engine_t *gvre = job->render.engine;
@@ -681,16 +450,6 @@ void gvrender_textpara(GVJ_t * job, pointf p, textpara_t * para)
 	    if (gvre->textpara)
 		gvre->textpara(job, PF, para);
 	}
-#ifdef WITH_CODEGENS
-	else {
-	    codegen_t *cg = job->codegen;
-	    point P;
-
-	    PF2P(p, P);
-	    if (cg && cg->textpara)
-		cg->textpara(P, para);
-	}
-#endif
     }
 }
 
@@ -707,14 +466,6 @@ void gvrender_set_pencolor(GVJ_t * job, char *name)
 	if (gvre->resolve_color)
 	    gvre->resolve_color(job, color);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->set_pencolor)
-	    cg->set_pencolor(name);
-    }
-#endif
     if (cp)  /* restore color list */
 	*cp = ':';
 }
@@ -732,14 +483,6 @@ void gvrender_set_fillcolor(GVJ_t * job, char *name)
 	if (gvre->resolve_color)
 	    gvre->resolve_color(job, color);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->set_fillcolor)
-	    cg->set_fillcolor(name);
-    }
-#endif
     if (cp)
 	*cp = ':';
 }
@@ -779,14 +522,6 @@ void gvrender_set_style(GVJ_t * job, char **s)
 	    }
 	}
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->set_style)
-	    cg->set_style(s);
-    }
-#endif
 }
 
 void gvrender_ellipse(GVJ_t * job, pointf * pf, int n, boolean filled)
@@ -808,27 +543,6 @@ void gvrender_ellipse(GVJ_t * job, pointf * pf, int n, boolean filled)
 	    gvre->ellipse(job, af, filled);
 	}
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->ellipse) {
-	    pointf af[2];
-	    point p, r;
-
-	    /* center */
-	    af[0].x = (pf[0].x + pf[1].x)/2.;
-	    af[0].y = (pf[0].y + pf[1].y)/2.;
-	    /* radius */
-	    af[1].x = pf[1].x - af[0].x;
-	    af[1].y = pf[1].y - af[0].y;
-
-	    PF2P(af[0], p);
-	    PF2P(af[1], r);
-	    cg->ellipse(p, r.x, r.y, filled);
-	}
-    }
-#endif
 }
 
 void gvrender_polygon(GVJ_t * job, pointf * af, int n, boolean filled)
@@ -849,21 +563,6 @@ void gvrender_polygon(GVJ_t * job, pointf * af, int n, boolean filled)
 	    }
 	}
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-        int i;
-
-	if (sizeA < n) {
-	    sizeA = n+10;
-	    A = grealloc(A, sizeA * sizeof(point));
-	}
-	for (i = 0; i < n; i++)
-	    PF2P(af[i], A[i]);
-	if (cg && cg->polygon)
-	    cg->polygon(A, n, filled);
-    }
-#endif
 }
 
 void gvrender_box(GVJ_t * job, boxf B, boolean filled)
@@ -899,21 +598,6 @@ void gvrender_beziercurve(GVJ_t * job, pointf * af, int n,
 	    }
 	}
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-	int i;
-	if (sizeA < n) {
-	    sizeA = n+10;
-	    A = grealloc(A, sizeA * sizeof(point));
-	}
-	for (i = 0; i < n; i++) {
-	    PF2P(af[i], A[i]);
-	}
-	if (cg && cg->beziercurve)
-	    cg->beziercurve(A, n, arrow_at_start, arrow_at_end, filled);
-    }
-#endif
 }
 
 void gvrender_polyline(GVJ_t * job, pointf * af, int n)
@@ -934,21 +618,6 @@ void gvrender_polyline(GVJ_t * job, pointf * af, int n)
 	    }
 	}
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-        int i;
-
-	if (sizeA < n) {
-	    sizeA = n+10;
-	    A = grealloc(A, sizeA * sizeof(point));
-	}
-	for (i = 0; i < n; i++)
-	    PF2P(af[i], A[i]);
-	if (cg && cg->polyline)
-	    cg->polyline(A, n);
-    }
-#endif
 }
 
 void gvrender_comment(GVJ_t * job, char *str)
@@ -962,14 +631,6 @@ void gvrender_comment(GVJ_t * job, char *str)
 	if (gvre->comment)
 	    gvre->comment(job, str);
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->comment)
-	    cg->comment(str);
-    }
-#endif
 }
 
 static imagescale_t get_imagescale(char *s)
@@ -1076,20 +737,6 @@ void gvrender_usershape(GVJ_t * job, char *name, pointf * a, int n,
     if (gvre) {
 	gvloadimage(job, us, b, filled, job->render.type);
     }
-#ifdef WITH_CODEGENS
-    else {
-        codegen_t *cg = job->codegen;
-
-	if (sizeA < n) {
-	    sizeA = n+10;
-	    A = grealloc(A, sizeA * sizeof(point));
-	}
-	for (i = 0; i < n; i++)
-	    PF2P(a[i], A[i]);
-        if (cg && cg->usershape)
-            cg->usershape(us, b, A, n, filled);
-    }
-#endif
 }
 
 void gvrender_set_penwidth(GVJ_t * job, double penwidth)
@@ -1100,12 +747,4 @@ void gvrender_set_penwidth(GVJ_t * job, double penwidth)
     	job->obj->penwidth = penwidth;
     	/*if (gvre->set_penwidth) gvre->set_penwidth(job, penwidth);*/
     }
-#ifdef WITH_CODEGENS
-    else {
-	codegen_t *cg = job->codegen;
-
-	if (cg && cg->set_penwidth)
-	    cg->set_penwidth(penwidth);
-    }
-#endif
 }
