@@ -1,4 +1,4 @@
-/* $Id: gvusershape.c,v 1.48 2009/01/06 22:58:41 arif Exp $ $Revision: 1.48 $ */
+/* $Id: gvusershape.c,v 1.51 2009/06/03 01:10:53 ellson Exp $ $Revision: 1.51 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -32,7 +32,7 @@
 #include "gvplugin_loadimage.h"
 
 
-extern shape_desc *find_user_shape(char *);
+extern shape_desc *find_user_shape(const char *);
 
 static Dict_t *ImageDict;
 
