@@ -1,4 +1,4 @@
-/* $Id: constrained_majorization.c,v 1.6 2008/04/25 14:38:29 erg Exp $ $Revision: 1.6 $ */
+/* $Id: constrained_majorization.c,v 1.10 2009/11/16 20:41:35 erg Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -159,6 +159,9 @@ stress_majorization_with_hierarchy(
 	if (maxi==0)
 		return iterations;
 
+    if (Verbose)
+	start_timer();
+
     if (model == MODEL_SUBSET) {
         /* weight graph to separate high-degree nodes */
         /* and perform slower Dijkstra-based computation */
@@ -173,12 +176,21 @@ stress_majorization_with_hierarchy(
             agerr(AGPREV,
                   "is undefined. Reverting to the shortest path model.\n");
         }
+    } else if (model == MODEL_MDS) {
+	if (Verbose)
+	    fprintf(stderr, "Calculating MDS model");
+	Dij = mdsModel(graph, n);
     }
     if (!Dij) {
         if (Verbose)
             fprintf(stderr, "Calculating shortest paths");
         Dij = compute_apsp_packed(graph, n);
     }
+    if (Verbose) {
+	fprintf(stderr, ": %.2f sec\n", elapsed_sec());
+	fprintf(stderr, "Setting initial positions");
+	start_timer();
+    }
 
 	diameter=-1;
 	length = n+n*(n-1)/2;
@@ -253,6 +265,8 @@ stress_majorization_with_hierarchy(
      */
 	constant_term=(float)(n*(n-1)/2);
 	
+    if (Verbose) fprintf(stderr, ": %.2f sec", elapsed_sec());
+
 	/**************************
 	** Laplacian computation **
 	**************************/
@@ -287,6 +301,7 @@ stress_majorization_with_hierarchy(
 		fp = fopen(FILENAME, "wb");
 		fwrite(lap2, sizeof(float), lap_length, fp);
 		fclose(fp);
+		fp = NULL;
 	}
 #endif
 		
@@ -467,6 +482,8 @@ stress_majorization_with_hierarchy(
 		free (lap1); 
 #ifdef NONCORE
 	}
+	if (fp)
+	    fclose (fp);
 #endif
 
 	free (ordering); 
