@@ -1,4 +1,4 @@
-/* $Id: delaunay.c,v 1.12 2008/07/25 15:35:06 ellson Exp $ $Revision: 1.12 $ */
+/* $Id: delaunay.c,v 1.17 2009/09/04 02:40:11 erg Exp $ $Revision: 1.17 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -301,6 +301,35 @@ static void addEdge (GtsSegment * e, estate* es)
     es->n += 1;
 }
 
+/* If qsort_r ever becomes standardized, this should be used
+ * instead of having a global variable.
+ */
+static double* _vals;
+typedef int (*qsort_cmpf) (const void *, const void *);
+
+static int 
+vcmp (int* a, int* b)
+{
+    double va = _vals[*a];
+    double vb = _vals[*b];
+
+    if (va < vb) return -1; 
+    else if (va > vb) return 1; 
+    else return 0;
+}
+
+/* delaunay_tri:
+ * Given n points whose coordinates are in the x[] and y[]
+ * arrays, compute a Delaunay triangulation of the points.
+ * The number of edges in the triangulation is returned in pnedges.
+ * The return value itself is an array e of 2*(*pnedges) integers,
+ * with edge i having points whose indices are e[2*i] and e[2*i+1].
+ *
+ * If the points are collinear, GTS fails with 0 edges.
+ * In this case, we sort the points by x coordinates (or y coordinates
+ * if the points form a vertical line). We then return a "triangulation"
+ * consisting of the n-1 pairs of adjacent points.
+ */
 int *delaunay_tri(double *x, double *y, int n, int* pnedges)
 {
     GtsSurface* s = tri(x, y, n, NULL, 0);
@@ -315,11 +344,40 @@ int *delaunay_tri(double *x, double *y, int n, int* pnedges)
     stats.delaunay = NULL;
     edgeStats (s, &stats);
     *pnedges = nedges = stats.n;
-    edges = N_GNEW(2 * nedges, int);
 
-    state.n = 0;
-    state.edges = edges;
-    gts_surface_foreach_edge (s, (GtsFunc) addEdge, &state);
+    if (nedges) {
+	edges = N_GNEW(2 * nedges, int);
+	state.n = 0;
+	state.edges = edges;
+	gts_surface_foreach_edge (s, (GtsFunc) addEdge, &state);
+    }
+    else {
+	int* vs = N_GNEW(n, int);
+	int* ip;
+	int i, hd, tl;
+
+	*pnedges = nedges = n-1;
+	ip = edges = N_GNEW(2 * nedges, int);
+
+	for (i = 0; i < n; i++)
+	    vs[i] = i;
+
+	if (x[0] == x[1])  /* vertical line */ 
+	    _vals = y;
+	else              
+	    _vals = x;
+	qsort (vs, n, sizeof(int), (qsort_cmpf)vcmp);
+
+	tl = vs[0];
+	for (i = 1; i < n; i++) {
+	    hd = vs[i];
+	    *ip++ = tl;
+	    *ip++ = hd;
+	    tl = hd;
+	}
+
+	free (vs);
+    }
 
     gts_object_destroy (GTS_OBJECT (s));
 
@@ -476,7 +534,30 @@ delaunay_tri (double *x, double *y, int n, int* nedges)
     triangulate("zQNEeB", &in, &out, NULL);
 
     *nedges = out.numberofedges;
-    free(in.pointlist);
+    free (in.pointlist);
+    free (in.pointattributelist);
+    free (in.pointmarkerlist);
+    free (in.trianglearealist);
+    free (in.triangleattributelist);
+    free (in.neighborlist);
+    free (in.segmentlist);
+    free (in.segmentmarkerlist);
+    free (in.holelist);
+    free (in.regionlist);
+    free (in.edgemarkerlist);
+    free (in.normlist);
+    free (out.pointattributelist);
+    free (out.pointmarkerlist);
+    free (out.trianglearealist);
+    free (out.triangleattributelist);
+    free (out.neighborlist);
+    free (out.segmentlist);
+    free (out.segmentmarkerlist);
+    free (out.holelist);
+    free (out.regionlist);
+    free (out.edgelist);
+    free (out.edgemarkerlist);
+    free (out.normlist);
     return out.edgelist;
 }
 
