@@ -1,4 +1,4 @@
-/* $Id: multispline.h,v 1.1 2008/06/27 18:20:24 erg Exp $Revision: */
+/* $Id: multispline.h,v 1.4 2009/08/11 21:21:20 erg Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -24,6 +24,6 @@ typedef struct router_s router_t;
 
 extern void freeRouter (router_t* rtr);
 extern router_t* mkRouter (Ppoly_t** obs, int npoly);
-extern int makeMultiSpline(edge_t* e, router_t * rtr, int);
+extern int makeMultiSpline(graph_t* g, edge_t* e, router_t * rtr, int);
 
 #endif
