@@ -1,4 +1,4 @@
-/* $Id: neatoinit.c,v 1.69 2009/01/27 19:20:29 erg Exp $ $Revision: 1.69 $ */
+/* $Id: neatoinit.c,v 1.86 2009/10/15 17:28:19 erg Exp $ $Revision: 1.86 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -654,6 +654,13 @@ static void translate(Agraph_t * g, pos_edge posEdges)
  * clusters, edges and labels. If certain position information
  * is missing, init_nop will use a standard neato technique to
  * supply it.
+ *
+ * If adjust is false, init_nop does nothing but initialize all
+ * of the basic graph information. No tweaking of positions or 
+ * filling in edge splines is done.
+ *
+ * Returns 0 on normal success, 1 if postprocess should be avoided, and -1
+ * on failure.
  */
 int init_nop(Agraph_t * g, int adjust)
 {
@@ -662,6 +669,8 @@ int init_nop(Agraph_t * g, int adjust)
     pos_edge posEdges;		/* How many edges have spline info */
     attrsym_t *G_lp = agfindgraphattr(g, "lp");
     attrsym_t *G_bb = agfindgraphattr(g, "bb");
+    int didAdjust = 0;  /* Have nodes been moved? */
+    int haveBackground;
 
     /* If G_bb not defined, define it */
     if (!G_bb)
@@ -676,25 +685,40 @@ int init_nop(Agraph_t * g, int adjust)
 	if (!hasPos(np) && strncmp(agnameof(np), "cluster", 7)) {
 	    agerr(AGERR, "node %s in graph %s has no position\n",
 		  agnameof(np), agnameof(g));
-	    return 1;
+	    return -1;
 	}
     }
     nop_init_graphs(g, G_lp, G_bb);
     posEdges = nop_init_edges(g);
 
-    if (adjust && Nop == 1)
-	adjustNodes(g);
+    if (adjust && (Nop == 1))
+	didAdjust = adjustNodes(g);
+
+    if (didAdjust) {
+	if (GD_label(g)) GD_label(g)->set = FALSE;
+/* FIX: 
+ *   - if nodes are moved, clusters are no longer valid.
+ */
+    }
 
     /* If g does not have a good "bb" attribute or we adjusted the nodes, 
      * compute it. 
      */
-    if (!chkBB(g, G_bb) || (adjust && Nop == 1))
+    if (!chkBB(g, G_bb) || didAdjust)
 	compute_bb(g);
 
+    /* Adjust bounding box for any background */
+    if (GD_drawing(g)->xdots) {
+	haveBackground = 1;
+	GD_bb(g) = xdotBB (g);
+    }
+    else
+	haveBackground = 0;
+
     /* At this point, all bounding boxes should be correctly defined.
      * If necessary, we translate the graph to the origin.
      */
-    if (adjust && (ROUND(abs(GD_bb(g).LL.x)) || ROUND(abs(GD_bb(g).LL.y))))
+    if (adjust && !haveBackground && (ROUND(abs(GD_bb(g).LL.x)) || ROUND(abs(GD_bb(g).LL.y))))
 	translate(g, posEdges);
 
     if (!adjust) {
@@ -711,7 +735,7 @@ int init_nop(Agraph_t * g, int adjust)
 	State = GVSPLINES;
 	neato_set_aspect(g);
     }
-    return 0;
+    return haveBackground;
 }
 
 static void neato_init_graph (Agraph_t * g)
@@ -731,7 +755,7 @@ static int neatoModel(graph_t * g)
     char *p = agget(g, "model");
     char c;
 
-    if (!p || (!(c = *p)))
+    if (!p || (!(c = *p)))    /* if p is NULL or "" */
 	return MODEL_SHORTPATH;
     if ((c == 'c') && streq(p, "circuit"))
 	return MODEL_CIRCUIT;
@@ -741,6 +765,20 @@ static int neatoModel(graph_t * g)
 	else if (streq(p, "shortpath"))
 	    return MODEL_SHORTPATH;
     }
+    if ((c == 'm') && streq(p, "mds")) {
+#ifndef WITH_CGRAPH
+	if (agindex(g->root->proto->e, "len") >= 0)
+#else /* WITH_CGRAPH */
+	if (agattr(g, AGEDGE, "len", 0))
+#endif /* WITH_CGRAPH */
+	    return MODEL_MDS;
+	else {
+	    agerr(AGWARN,
+	        "edges in graph %s have no len attribute. Hence, the mds model\n", agnameof(g));
+	    agerr(AGPREV, "is inappropriate. Reverting to the shortest path model.\n");
+	    return MODEL_SHORTPATH;
+	}
+    }
     agerr(AGWARN,
 	  "Unknown value %s for attribute \"model\" in graph %s - ignored\n",
 	  p, agnameof(g));
@@ -1089,7 +1127,7 @@ setSeed (graph_t * G, int dflt, long* seedp)
 	long seed;
 	/* Check for seed value */
 	if (!isdigit(*(unsigned char *)p) || sscanf(p, "%ld", &seed) < 1) {
-#ifdef MSWIN32
+#if defined(MSWIN32) || defined(WIN32)
 	    seed = (unsigned) time(NULL);
 #else
 	    seed = (unsigned) getpid() ^ (unsigned) time(NULL);
@@ -1157,11 +1195,11 @@ void dumpData(graph_t * g, vtx_data * gp, int nv, int ne)
 /* majorization:
  * Solve stress using majorization.
  * Old neato attributes to incorporate:
- *  weight?
- * model will be MODE_MAJOR, MODE_HIER or MODE_IPSEP
+ *  weight
+ * mode will be MODE_MAJOR, MODE_HIER or MODE_IPSEP
  */
 static void
-majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int steps)
+majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int steps, adjust_data* am)
 {
     double **coords;
     int ne;
@@ -1211,7 +1249,6 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
 #ifdef IPSEPCOLA
 	else {
             char* str;
-	    adjust_data* am;
             ipsep_options opt;
             pointf* nsize;
 	    cluster_data *cs = (cluster_data*)cluster_map(mg,g);
@@ -1233,7 +1270,6 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
                     fprintf(stderr,"Generating DiG-CoLa Edge Constraints...\n");
             }
 	    else opt.diredges = 0;
-            am = graphAdjustMode (g);
 	    if (am->mode == AM_IPSEP) {
                 opt.noverlap = 1;
                 if(Verbose)
@@ -1309,6 +1345,27 @@ static void subset_model(Agraph_t * G, int nG)
     freeGraphData(gp);
 }
 
+/* mds_model:
+ * Assume the matrix already contains shortest path values.
+ * Use the actual lengths provided the input for edges.
+ */
+static void mds_model(graph_t * g, int nG)
+{
+    long i, j;
+    node_t *v;
+    edge_t *e;
+
+    for (v = agfstnode(g); v; v = agnxtnode(g, v)) {
+	for (e = agfstout(g, v); e; e = agnxtout(g, e)) {
+	    i = AGID(agtail(e));
+	    j = AGID(aghead(e));
+	    if (i == j)
+		continue;
+	    GD_dist(g)[i][j] = GD_dist(g)[j][i] = ED_dist(e);
+	}
+    }
+}
+
 /* kkNeato:
  * Solve using gradient descent a la Kamada-Kawai.
  */
@@ -1328,6 +1385,9 @@ static void kkNeato(Agraph_t * g, int nG, int model)
 	    agerr(AGPREV, "the graph into connected components.\n");
 	    shortest_path(g, nG);
 	}
+    } else if (model == MODEL_MDS) {
+	shortest_path(g, nG);
+	mds_model(g, nG);
     } else
 	shortest_path(g, nG);
     initial_positions(g, nG);
@@ -1343,7 +1403,9 @@ static void kkNeato(Agraph_t * g, int nG, int model)
 /* neatoLayout:
  * Use stress optimization to layout a single component
  */
-void neatoLayout(Agraph_t * mg, Agraph_t * g, int layoutMode, int layoutModel)
+static void 
+neatoLayout(Agraph_t * mg, Agraph_t * g, int layoutMode, int layoutModel,
+  adjust_data* am)
 {
     int nG;
     char *str;
@@ -1358,12 +1420,8 @@ void neatoLayout(Agraph_t * mg, Agraph_t * g, int layoutMode, int layoutModel)
     nG = scan_graph_mode(g, layoutMode);
     if ((nG < 2) || (MaxIter <=0))
 	return;
-#ifdef WITH_CGRAPH
-//    if (Verbose) {
-//	fprintf(stderr, "%i\n", count_nodes(g));
-#endif /* WITH_CGRAPH */
     if (layoutMode)
-	majorization(mg, g, nG, layoutMode, layoutModel, Ndim, MaxIter);
+	majorization(mg, g, nG, layoutMode, layoutModel, Ndim, MaxIter, am);
     else
 	kkNeato(g, nG, layoutModel);
 }
@@ -1389,6 +1447,31 @@ static void addZ (Agraph_t* g)
     }
 }
 
+#ifdef IPSEPCOLA
+static void
+addCluster (graph_t* g)
+{
+    graph_t *subg;
+#ifndef WITH_CGRAPH
+    graph_t *mg;
+    node_t *mm, *mn;
+    edge_t *me;
+    mm = g->meta_node;
+    mg = agraphof(mm);
+    for (me = agfstout(mg, mm); me; me = agnxtout(mg, me)) {
+	mn = aghead(me);
+	subg = agusergraph(mn);
+#else
+    for (subg = agfstsubg(agroot(g)); subg; subg = agnxtsubg(subg)) {
+#endif
+	if (!strncmp(agnameof(subg), "cluster", 7)) {
+	    add_cluster(g, subg);
+	    compute_bb(subg);
+	}
+   }
+}
+#endif
+
 /* neato_layout:
  */
 void neato_layout(Agraph_t * g)
@@ -1396,6 +1479,8 @@ void neato_layout(Agraph_t * g)
     int layoutMode;
     int model;
     pack_mode mode;
+    pack_info pinfo;
+    adjust_data am;
 
     if (Nop) {
 	int save = PSinputscale;
@@ -1405,15 +1490,17 @@ void neato_layout(Agraph_t * g)
 	addZ (g);
 	ret = init_nop(g, 1);
 	PSinputscale = save;
-	if (ret) {
+	if (ret < 0) {
 	    agerr(AGPREV, "as required by the -n flag\n");
-	    exit(1);
+	    return;
 	}
+	else gv_postprocess(g, ret);
     } else {
 	neato_init_graph(g);
 	layoutMode = neatoMode(g);
+	graphAdjustMode (g, &am, 0);
 	model = neatoModel(g);
-	mode = getPackMode(g, l_undef);
+	mode = getPackModeInfo (g, l_undef, &pinfo);
 	Pack = getPack(g, -1, CL_OFFSET);
 	/* pack if just packmode defined. */
 	if (mode == l_undef) {
@@ -1422,7 +1509,7 @@ void neato_layout(Agraph_t * g)
 	     */
 	    if ((Pack < 0) && layoutMode)
 		Pack = CL_OFFSET;
-	    mode = l_node;
+	    pinfo.mode = l_node;
 	} else if (Pack < 0)
 	    Pack = CL_OFFSET;
 	if (Pack >= 0) {
@@ -1430,7 +1517,6 @@ void neato_layout(Agraph_t * g)
 	    graph_t **cc;
 	    int n_cc;
 	    int i;
-	    pack_info pinfo;
 	    boolean pin;
 
 	    cc = pccomps(g, &n_cc, cc_pfx, &pin);
@@ -1438,8 +1524,10 @@ void neato_layout(Agraph_t * g)
 	    for (i = 0; i < n_cc; i++) {
 		gc = cc[i];
 		nodeInduce(gc);
-		neatoLayout(g, gc, layoutMode, model);
-		adjustNodes(gc);
+		neatoLayout(g, gc, layoutMode, model, &am);
+		removeOverlapWith(gc, &am);
+		setEdgeType (gc, ET_LINE);
+		spline_edges(gc);
 	    }
 	    if (n_cc > 1) {
 		boolean *bp;
@@ -1449,16 +1537,14 @@ void neato_layout(Agraph_t * g)
 		} else
 		    bp = 0;
 		pinfo.margin = Pack;
-		pinfo.doSplines = 0;
-		pinfo.mode = mode;
 		pinfo.fixed = bp;
-		packGraphs(n_cc, cc, 0, &pinfo);
+		pinfo.doSplines = 1;
+		packGraphs(n_cc, cc, g, &pinfo);
 		if (bp)
 		    free(bp);
 	    }
 	    compute_bb(g);
 	    addZ (g);
-	    spline_edges(g);
 
 	    /* cleanup and remove component subgraphs */
 	    for (i = 0; i < n_cc; i++) {
@@ -1468,33 +1554,14 @@ void neato_layout(Agraph_t * g)
 	    }
 	    free (cc);
 #ifdef IPSEPCOLA
-            {
-		graph_t *subg;
-#ifndef WITH_CGRAPH
-                graph_t *mg;
-                node_t *mm, *mn;
-                edge_t *me;
-                mm = g->meta_node;
-                mg = agraphof(mm);
-                for (me = agfstout(mg, mm); me; me = agnxtout(mg, me)) {
-                    mn = aghead(me);
-                    subg = agusergraph(mn);
-#else
-		for (subg = agfstsubg(agroot(g)); subg; subg = agnxtsubg(subg)) {
-#endif
-                    if (!strncmp(agnameof(subg), "cluster", 7)) {
-                        add_cluster(g, subg);
-                        compute_bb(subg);
-                    }
-                }
-            }
+	    addCluster (g);
 #endif
 	} else {
-	    neatoLayout(g, g, layoutMode, model);
-	    adjustNodes(g);
+	    neatoLayout(g, g, layoutMode, model, &am);
+	    removeOverlapWith(g, &am);
 	    addZ (g);
 	    spline_edges(g);
 	}
+	dotneato_postprocess(g);
     }
-    dotneato_postprocess(g);
 }
