@@ -1,4 +1,4 @@
-/* $Id: neatoprocs.h,v 1.17 2009/01/06 22:58:42 arif Exp $ $Revision: 1.17 $ */
+/* $Id: neatoprocs.h,v 1.21 2009/08/11 21:21:20 erg Exp $ $Revision: 1.21 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -27,7 +27,7 @@ extern "C" {
 #define extern
 #endif
 
-    extern void addEdgeLabels(edge_t * e, pointf rp, pointf rq);
+    extern void addEdgeLabels(graph_t* g, edge_t * e, pointf rp, pointf rq);
     extern int allow_edits(int);
     extern void avoid_cycling(graph_t *, Agnode_t *, double *);
     extern int checkStart(graph_t * G, int nG, int);
@@ -50,7 +50,7 @@ extern "C" {
     extern Ppoly_t *makeObstacle(node_t * n, expand_t* );
     extern void makeStraightEdge(graph_t * g, edge_t * e, int doPolyline);
     extern void makeSelfArcs(path * P, edge_t * e, int stepx);
-    extern void makeSpline(edge_t *, Ppoly_t **, int, boolean);
+    extern void makeSpline(graph_t*, edge_t *, Ppoly_t **, int, boolean);
     extern void make_spring(graph_t *, Agnode_t *, Agnode_t *, double);
     extern void move_node(graph_t *, int, Agnode_t *);
     extern int init_nop(graph_t * g, int);
@@ -59,7 +59,6 @@ extern "C" {
     extern void neato_enqueue(node_t *);
     extern void neato_init_node(node_t * n);
     extern void neato_layout(Agraph_t * g);
-    extern void neatoLayout(Agraph_t *mg, Agraph_t * g, int layoutMode, int layoutModel);
     extern int Plegal_arrangement(Ppoly_t ** polys, int n_polys);
     extern void randompos(Agnode_t *, int);
     extern void s1(graph_t *, node_t *);
