@@ -1,4 +1,4 @@
-/* $Id: neatosplines.c,v 1.51 2008/12/07 22:13:10 erg Exp $ $Revision: 1.51 $ */
+/* $Id: neatosplines.c,v 1.59 2009/12/05 23:20:13 erg Exp $ $Revision: 1.59 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -198,9 +198,9 @@ polylineMidpoint (splines* spl, pointf* pp, pointf* pq)
  * significantly from rp and rq, but if the spline is degenerate (e.g.,
  * the nodes overlap), we use rp and rq.
  */
-void addEdgeLabels(edge_t * e, pointf rp, pointf rq)
+void addEdgeLabels(graph_t* g, edge_t * e, pointf rp, pointf rq)
 {
-    int et = EDGE_TYPE (agroot(agraphof(aghead(e))));
+    int et = EDGE_TYPE (g);
     pointf p, q;
     pointf d;			/* midpoint of segment p-q */
     point ld;
@@ -382,7 +382,7 @@ void makeSelfArcs(path * P, edge_t * e, int stepx)
 {
     int cnt = ED_count(e);
 
-    if (cnt == 1) {
+    if ((cnt == 1) || Concentrate) {
 	edge_t *edges1[1];
 	edges1[0] = e;
 	makeSelfEdge(P, edges1, 0, 1, stepx, stepx, &sinfo);
@@ -428,9 +428,9 @@ makeStraightEdge(graph_t * g, edge_t * e, int doPolyline)
 
     p = dumb[1] = dumb[0] = add_pointf(ND_coord(n), ED_tail_port(e).p);
     q = dumb[2] = dumb[3] = add_pointf(ND_coord(head), ED_head_port(e).p);
-    if (e_cnt == 1) {
+    if ((e_cnt == 1) || Concentrate) {
 	clip_and_install(e, aghead(e), dumb, 4, &sinfo);
-	addEdgeLabels(e, p, q);
+	addEdgeLabels(g, e, p, q);
 	return;
     }
 
@@ -446,7 +446,7 @@ makeStraightEdge(graph_t * g, edge_t * e, int doPolyline)
         perp.x = dumb[0].y - dumb[3].y;
         perp.y = dumb[3].x - dumb[0].x;
 	l_perp = LEN(perp.x, perp.y);
-	xstep = GD_nodesep(g);
+	xstep = GD_nodesep(g->root);
 	dx = xstep * (e_cnt - 1) / 2;
 	dumb[1].x = dumb[0].x + (dx * perp.x) / l_perp;
 	dumb[1].y = dumb[0].y + (dx * perp.y) / l_perp;
@@ -476,8 +476,8 @@ makeStraightEdge(graph_t * g, edge_t * e, int doPolyline)
 
 	    line.pn = 4;
 	    line.ps = pts;
-	    for (i=0; i < 4; i++) {
-		pts[i] = dumber[i];
+	    for (j=0; j < 4; j++) {
+		pts[j] = dumber[j];
 	    }
 	    make_polyline (line, &spl);
 	    clip_and_install(e0, aghead(e0), spl.ps, spl.pn, &sinfo);
@@ -485,7 +485,7 @@ makeStraightEdge(graph_t * g, edge_t * e, int doPolyline)
 	else
 	    clip_and_install(e0, aghead(e0), dumber, 4, &sinfo);
 
-	addEdgeLabels(e0, p, q);
+	addEdgeLabels(g, e0, p, q);
 	e0 = ED_to_virt(e0);
 	dumb[1].x += del.x;
 	dumb[1].y += del.y;
@@ -672,7 +672,7 @@ getPath(edge_t * e, vconfig_t * vconfig, int chkPts, Ppoly_t ** obs,
 /* makePolyline:
  */
 static void
-makePolyline(edge_t * e)
+makePolyline(graph_t* g, edge_t * e)
 {
     Ppolyline_t spl, line = ED_path(e);
     Ppoint_t p0, q0;
@@ -683,7 +683,7 @@ makePolyline(edge_t * e)
     if (Verbose > 1)
 	fprintf(stderr, "polyline %s %s\n", agnameof(agtail(e)), agnameof(aghead(e)));
     clip_and_install(e, aghead(e), spl.ps, spl.pn, &sinfo);
-    addEdgeLabels(e, p0, q0);
+    addEdgeLabels(g, e, p0, q0);
 }
 
 /* makeSpline:
@@ -696,7 +696,7 @@ makePolyline(edge_t * e)
  * is on or inside one of the obstacles and, if so, tells the shortest path
  * computation to ignore them. 
  */
-void makeSpline(edge_t * e, Ppoly_t ** obs, int npoly, boolean chkPts)
+void makeSpline(graph_t* g, edge_t * e, Ppoly_t ** obs, int npoly, boolean chkPts)
 {
     Ppolyline_t line, spline;
     Pvector_t slopes[2];
@@ -728,7 +728,7 @@ void makeSpline(edge_t * e, Ppoly_t ** obs, int npoly, boolean chkPts)
 	fprintf(stderr, "spline %s %s\n", agnameof(agtail(e)), agnameof(aghead(e)));
     clip_and_install(e, aghead(e), spline.ps, spline.pn, &sinfo);
     free(barriers);
-    addEdgeLabels(e, p, q);
+    addEdgeLabels(g, e, p, q);
 }
 
   /* True if either head or tail has a port on its boundary */
@@ -755,6 +755,7 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
     path *P = NULL;
     int useEdges = (Nop > 1);
     router_t* rtr = 0;
+    int legal = 0;
 
     /* build configuration */
     if (edgetype != ET_LINE) {
@@ -773,7 +774,7 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
     }
     npoly = i;
     if (obs) {
-	if (Plegal_arrangement(obs, npoly)) {
+	if ((legal = Plegal_arrangement(obs, npoly))) {
 	    if (edgetype != ET_ORTHO) vconfig = Pobsopen(obs, npoly);
 	}
 	else if (Verbose)
@@ -784,7 +785,7 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
     /* route edges  */
     if (Verbose)
 	fprintf(stderr, "Creating edges using %s\n",
-	    (edgetype == ET_ORTHO) ? "orthogonal lines" :
+	    (legal && (edgetype == ET_ORTHO)) ? "orthogonal lines" :
 	    (vconfig ? (edgetype == ET_SPLINE ? "splines" : "polylines") : 
 		"line segments"));
     if (vconfig) {
@@ -796,7 +797,7 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
 	}
     }
 #ifdef ORTHO
-    else if (edgetype == ET_ORTHO) {
+    else if (legal && (edgetype == ET_ORTHO)) {
 	orthoEdges (g, 0);
 	useEdges = 1;
     }
@@ -808,7 +809,7 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
 /* fprintf (stderr, "%s -- %s %d\n", agnameof(agtail(e)), agnameof(aghead(e)), ED_count(e)); */
 	    node_t *head = aghead(e);
 	    if (useEdges && ED_spl(e)) {
-		addEdgeLabels(e,
+		addEdgeLabels(g, e,
 			      add_pointf(ND_coord(n), ED_tail_port(e).p),
 			      add_pointf(ND_coord(head), ED_head_port(e).p));
 	    } 
@@ -818,7 +819,7 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
 		    P = NEW(path);
 		    P->boxes = N_NEW(agnnodes(g) + 20 * 2 * 9, boxf);
 		}
-		makeSelfArcs(P, e, GD_nodesep(g));
+		makeSelfArcs(P, e, GD_nodesep(g->root));
 	    } else if (vconfig) { /* ET_SPLINE or ET_PLINE */
 #ifdef HAVE_GTS
 		if ((ED_count(e) > 1) || BOUNDARY_PORT(e)) {
@@ -828,7 +829,7 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
 			makeStraightEdge(g, e, edgetype == ET_PLINE);
 		    else { 
 			if (!rtr) rtr = mkRouter (obs, npoly);
-			fail = makeMultiSpline(e, rtr, edgetype == ET_PLINE);
+			fail = makeMultiSpline(g, e, rtr, edgetype == ET_PLINE);
 		    } 
 		    if (!fail) continue;
 		}
@@ -838,12 +839,13 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
 		 */
 #endif
 		cnt = ED_count(e);
+		if (Concentrate) cnt = 1; /* only do representative */
 		e0 = e;
 		for (i = 0; i < cnt; i++) {
 		    if (edgetype == ET_SPLINE)
-			makeSpline(e0, obs, npoly, TRUE);
+			makeSpline(g, e0, obs, npoly, TRUE);
 		    else
-			makePolyline(e0);
+			makePolyline(g, e0);
 		    e0 = ED_to_virt(e0);
 		}
 	    } else {
@@ -947,7 +949,7 @@ int spline_edges1(graph_t * g, int edgetype)
  */
 void spline_edges0(graph_t * g)
 {
-    int et = EDGE_TYPE (g->root);
+    int et = EDGE_TYPE (g);
     neato_set_aspect(g);
     if (et == ET_NONE) return;
 #ifndef ORTHO
@@ -1082,6 +1084,7 @@ static void scaleBB(graph_t * g, double xf, double yf)
 /* _neato_set_aspect;
  * Assume all bounding boxes are correct and
  * that GD_bb(g).LL is at origin.
+ * Also assume g is the root graph
  */
 static void _neato_set_aspect(graph_t * g)
 {
@@ -1171,7 +1174,9 @@ void neato_set_aspect(graph_t * g)
 {
     node_t *n;
 
-    _neato_set_aspect(g);
+	/* setting aspect ratio only makes sense on root graph */
+    if (g->root == g)
+	_neato_set_aspect(g);
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	ND_coord(n).x = POINTS_PER_INCH * (ND_pos(n)[0]);
 	ND_coord(n).y = POINTS_PER_INCH * (ND_pos(n)[1]);
