@@ -1,4 +1,4 @@
-/* $Id: quad_prog_vpsc.c,v 1.6 2008/04/28 16:52:59 erg Exp $ $Revision: 1.6 $ */
+/* $Id: quad_prog_vpsc.c,v 1.9 2009/06/03 01:10:54 ellson Exp $ $Revision: 1.9 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**
@@ -238,9 +238,9 @@ CMajEnvVPSC *initCMajVPSC(int n, float *packedMat, vtx_data * graph,
 	DigColaLevel *levels;
 	Variable **vs = e->vs;
 	/* e->ndv is the number of dummy variables required, one for each boundary */
-	compute_hierarchy(graph, n, 1e-2, 1e-1, NULL, &ordering, &ls,
+	compute_hierarchy(graph, e->nv, 1e-2, 1e-1, NULL, &ordering, &ls,
 			  &e->ndv);
-	levels = assign_digcola_levels(ordering, n, ls, e->ndv);
+	levels = assign_digcola_levels(ordering, e->nv, ls, e->ndv);
 	if (Verbose)
 	    fprintf(stderr, "Found %d DiG-CoLa boundaries\n", e->ndv);
 	e->gm =
