@@ -1,4 +1,4 @@
-/* $Id: ortho.c,v 1.4 2009/01/05 20:12:47 ellson Exp $Revision: */
+/* $Id: ortho.c,v 1.9 2009/07/10 21:21:14 erg Exp $Revision: */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -37,8 +37,12 @@
 #include "geomprocs.h"
 #include "globals.h"
 #include "render.h"
+#include "pointset.h"
 
-/* #define DEBUG */
+#ifdef DEBUG
+static void emitSearchGraph (FILE* fp, sgraph* sg);
+static void emitGraph (FILE* fp, maze* mp, Agraph_t* g, route* route_list);
+#endif
 
 #define CELL(n) ((cell*)ND_alg(n))
 #define MID(a,b) (((a)+(b))/2.0)
@@ -246,6 +250,7 @@ static void
 freeChannel (Dt_t* d, channel* cp, Dtdisc_t* disc)
 {
     free_graph (cp->G);
+    free (cp->seg_list);
     free (cp);
 }
 
@@ -984,7 +989,7 @@ addPEdges (channel* cp, maze* mp)
 			    dir = 1;
 		    }
 		    else if(segs[j]->prev==0) {
-			assert (0);  /* FIXME */
+			dir = 1;
 		    }
 		    else {
 			if(segs[i]->prev->comm_coord==segs[j]->prev->comm_coord)
@@ -1122,8 +1127,8 @@ attachOrthoEdges (maze* mp, int n_edges, route* route_list, splineInfo *sinfo, e
 
     for (; irte < n_edges; irte++) {
 	e = es[irte].e;
-	p1 = addPoints(ND_coord(e->tail), ED_tail_port(e).p);
-	q1 = addPoints(ND_coord(e->head), ED_head_port(e).p);
+	p1 = addPoints(ND_coord(agtail(e)), ED_tail_port(e).p);
+	q1 = addPoints(ND_coord(aghead(e)), ED_head_port(e).p);
 
 	rte = route_list[irte];
 	npts = 1 + 3*rte.n;
@@ -1166,8 +1171,8 @@ attachOrthoEdges (maze* mp, int n_edges, route* route_list, splineInfo *sinfo, e
 	ispline[ipt] = ispline[ipt+1] = p;
 
 	if (Verbose > 1)
-		fprintf(stderr, "ortho %s %s\n", e->tail->name, e->head->name);
-	clip_and_install(e, e->head, ispline, npts, sinfo);
+		fprintf(stderr, "ortho %s %s\n", agnameof(agtail(e)),agnameof(aghead(e)));
+	clip_and_install(e, aghead(e), ispline, npts, sinfo);
     }
     free(ispline);
 }
@@ -1175,8 +1180,8 @@ attachOrthoEdges (maze* mp, int n_edges, route* route_list, splineInfo *sinfo, e
 static int
 edgeLen (Agedge_t* e)
 {
-    pointf p = ND_coord(e->tail);
-    pointf q = ND_coord(e->head);
+    pointf p = ND_coord(agtail(e));
+    pointf q = ND_coord(aghead(e));
     return (int)DIST2(p,q);
 }
 
@@ -1195,7 +1200,7 @@ static boolean swap_ends_p(edge_t * e)
     return FALSE;
 }
 
-static splineInfo sinfo = { swap_ends_p, spline_merge };
+static splineInfo sinfo = { swap_ends_p, spline_merge, 1 };
 
 void
 orthoEdges (Agraph_t* g, int useLbls)
@@ -1212,6 +1217,10 @@ orthoEdges (Agraph_t* g, int useLbls)
     epair_t* es = N_GNEW(agnedges(g), epair_t);
     cell* start;
     cell* dest;
+    PointSet* ps;
+
+    if (Concentrate) 
+	ps = newPS();
 
     mp = mkMaze (g);
     sg = mp->sg;
@@ -1220,6 +1229,18 @@ orthoEdges (Agraph_t* g, int useLbls)
     for (n = agfstnode (g); n; n = agnxtnode(g, n)) {
         for (e = agfstout(g, n); e; e = agnxtout(g,e)) {
 	    if ((Nop == 2) && ED_spl(e)) continue;
+	    if (Concentrate) {
+		int ti = AGID(agtail(e));
+		int hi = AGID(aghead(e));
+		if (ti <= hi) {
+		    if (isInPS (ps,ti,hi)) continue;
+		    else addPS (ps,ti,hi);
+		}
+		else {
+		    if (isInPS (ps,hi,ti)) continue;
+		    else addPS (ps,hi,ti);
+		}
+	    }
 	    es[n_edges].e = e;
 	    es[n_edges].d = edgeLen (e);
 	    n_edges++;
@@ -1236,8 +1257,8 @@ orthoEdges (Agraph_t* g, int useLbls)
     dn = &sg->nodes[gstart+1];
     for (i = 0; i < n_edges; i++) {
 	e = es[i].e;
-        start = CELL(e->tail);
-        dest = CELL(e->head);
+        start = CELL(agtail(e));
+        dest = CELL(aghead(e));
 
 	if (start == dest)
 	    addLoop (sg, start, dn);
@@ -1259,9 +1280,9 @@ orthoEdges (Agraph_t* g, int useLbls)
     /* emitGraph (stdout, mp, g, route_list); */
     attachOrthoEdges (mp, n_edges, route_list, &sinfo, es);
 
-    freeSGraph (sg);
-    dtclose (mp->hchans);
-    dtclose (mp->vchans);
+    if (Concentrate)
+	freePS (ps);
+
     for (i=0; i < n_edges; i++)
 	free (route_list[i].segs);
     free (route_list);
@@ -1337,7 +1358,7 @@ static boxf
 emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, int ix, boxf bb)
 {
   int i, x, y;
-  boxf n = CELL(e->head)->bb;
+  boxf n = CELL(aghead(e))->bb;
   segment* seg = rte.segs;
   if (seg->isVert) {
     x = vtrack(seg, m);
@@ -1368,7 +1389,7 @@ emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, int ix, boxf bb)
     fprintf (fp, "%d %d lineto\n", SC*x, SC*y);
   }
 
-  n = CELL(e->tail)->bb;
+  n = CELL(agtail(e))->bb;
   if (seg->isVert) {
     x = vtrack(seg, m);
     y = (n.UR.y + n.LL.y)/2;
@@ -1412,7 +1433,7 @@ emitSearchGraph (FILE* fp, sgraph* sg)
     }
     for (i = 0; i < sg->nedges; i++) {
 	ep = sg->edges+i;
-	fprintf (fp, "  %d -- %d\n", ep->v1, ep->v2);
+	fprintf (fp, "  %d -- %d[len=\"%f\"]\n", ep->v1, ep->v2, ep->weight);
     }
     fputs ("}\n", fp);
 }
