@@ -1,4 +1,4 @@
-/* $Id: pathplan.h,v 1.2 2006/07/27 03:44:05 erg Exp $ $Revision: 1.2 $ */
+/* $Id: pathplan.h,v 1.5 2009/06/03 01:10:54 ellson Exp $ $Revision: 1.5 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -44,6 +44,9 @@ extern "C" {
     extern int Ppolybarriers(Ppoly_t ** polys, int npolys,
 			     Pedge_t ** barriers, int *n_barriers);
 
+/* function to convert a polyline into a spline representation */
+    extern void make_polyline(Ppolyline_t line, Ppolyline_t* sline);
+
 #undef extern
 
 #ifdef __cplusplus
