@@ -1,4 +1,4 @@
-/* $Id: sfdpinit.c,v 1.5 2009/06/15 16:26:11 arif Exp $ $Revision: 1.5 $ */
+/* $Id: sfdpinit.c,v 1.10 2010/01/05 17:22:24 arif Exp $ $Revision: 1.10 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -38,13 +38,6 @@
 double _statistics[10];
 #endif
 
-static void sfdp_init_node(node_t * n)
-{
-    common_init_node(n);
-    ND_pos(n) = N_NEW(GD_ndim(n->graph), double);
-    gv_nodesize(n, GD_flip(n->graph));
-}
-
 static void sfdp_init_edge(edge_t * e)
 {
     common_init_edge(e);
@@ -60,7 +53,7 @@ static void sfdp_init_node_edge(graph_t * g)
 #endif
 
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	sfdp_init_node(n);
+	neato_init_node(n);
 #if 0
    FIX so that user positions works with multiscale
 	user_pos(N_pos, NULL, n, nnodes); 
@@ -75,6 +68,7 @@ static void sfdp_init_node_edge(graph_t * g)
 static void sfdp_init_graph(Agraph_t * g)
 {
     int outdim;
+    int temp;
 
     setEdgeType(g, ET_LINE);
     outdim = late_int(g, agfindgraphattr(g, "dimen"), 2, 2);
@@ -149,7 +143,11 @@ late_smooth (graph_t* g, Agsym_t* sym, int dflt)
     int rv;
 
     if (!sym) return dflt;
+#ifdef WITH_CGRAPH
+    s = agxget (g, sym);
+#else
     s = agxget (g, sym->index);
+#endif
     if (isdigit(*s)) {
 #if (HAVE_GTS || HAVE_TRIANGLE)
 	if ((v = atoi (s)) <= SMOOTHING_RNG)
@@ -195,7 +193,11 @@ late_quadtree_scheme (graph_t* g, Agsym_t* sym, int dflt)
     int rv;
 
     if (!sym) return dflt;
+#ifdef WITH_CGRAPH
+    s = agxget (g, sym);
+#else
     s = agxget (g, sym->index);
+#endif
     if (isdigit(*s)) {
       if ((v = atoi (s)) <= QUAD_TREE_FAST && v >= QUAD_TREE_NONE){
 	rv = v;
@@ -262,7 +264,11 @@ void sfdp_layout(graph_t * g)
 	spring_electrical_control ctrl = spring_electrical_control_new();
 
 	tuneControl (g, ctrl);
+#if (HAVE_GTS || HAVE_TRIANGLE)
 	graphAdjustMode(g, &am, "prism0");
+#else
+	graphAdjustMode(g, &am, 0);
+#endif
 
 	if ((am.mode == AM_PRISM) && doAdjust) {
 	    doAdjust = 0;  /* overlap removal done in sfpd */
@@ -297,8 +303,9 @@ void sfdp_layout(graph_t * g)
 		nodeInduce(sg);
 		sfdpLayout(sg, ctrl, pad);
 		if (doAdjust) removeOverlapWith(sg, &am);
+		setEdgeType(sg, ET_LINE);
+		spline_edges(sg);
 	    }
-	    spline_edges(g);
 	    packSubgraphs(ncc, ccs, g, &pinfo);
 	}
 	for (i = 0; i < ncc; i++) {
