@@ -1,4 +1,4 @@
-/* $Id: twopiinit.c,v 1.14 2009/02/25 21:39:47 arif Exp $ $Revision: 1.14 $ */
+/* $Id: twopiinit.c,v 1.19 2009/08/11 21:21:20 erg Exp $ $Revision: 1.19 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -93,7 +93,8 @@ void twopi_layout(Agraph_t * g)
 	    spline_edges(g);
 	} else {
 	    pack_info pinfo;
-	    pack_mode pmode = getPackMode(g, l_node);
+	    getPackInfo (g, l_node, CL_OFFSET, &pinfo);
+	    pinfo.doSplines = 1;
 
 	    for (i = 0; i < ncc; i++) {
 		sg = ccs[i];
@@ -104,13 +105,10 @@ void twopi_layout(Agraph_t * g)
 		nodeInduce(sg);
 		circleLayout(sg, c);
 		adjustNodes(sg);
+		setEdgeType (sg, ET_LINE);
+		spline_edges(sg);
 	    }
 	    free(ND_alg(agfstnode(g)));
-	    spline_edges(g);
-	    pinfo.margin = getPack(g, CL_OFFSET, CL_OFFSET);
-	    pinfo.doSplines = 1;
-	    pinfo.mode = pmode;
-	    pinfo.fixed = 0;
 	    packSubgraphs(ncc, ccs, g, &pinfo);
 	}
 	for (i = 0; i < ncc; i++) {
