@@ -1,4 +1,4 @@
-/* $Id: gvloadimage_core.c,v 1.34 2008/12/23 18:31:46 ellson Exp $ $Revision: 1.34 $ */
+/* $Id: gvloadimage_core.c,v 1.37 2009/06/03 01:10:56 ellson Exp $ $Revision: 1.37 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -24,6 +24,9 @@
 #if HAVE_SYS_MMAN_H
 #include <sys/mman.h>
 #endif
+#ifdef _MSC_VER
+#include <io.h>
+#endif
 
 #include "gvplugin_loadimage.h"
 #include "agxbuf.h"
