@@ -1,4 +1,4 @@
-/* $Id: gvrender_core_svg.c,v 1.81 2009/02/23 15:25:21 ellson Exp $ $Revision: 1.81 $ */
+/* $Id: gvrender_core_svg.c,v 1.84 2009/06/03 01:10:56 ellson Exp $ $Revision: 1.84 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -53,6 +53,10 @@ static char *sdasharray = "5,2";
 /* SVG dot array */
 static char *sdotarray = "1,5";
 
+#ifndef HAVE_STRCASECMP
+extern int strcasecmp(const char *s1, const char *s2);
+#endif
+
 static void svg_bzptarray(GVJ_t * job, pointf * A, int n)
 {
     int i;
