@@ -1,4 +1,4 @@
-/* $Id: gvdevice_gd.c,v 1.16 2008/09/07 17:42:56 ellson Exp $ $Revision: 1.16 $ */
+/* $Id: gvdevice_gd.c,v 1.20 2009/07/30 15:14:49 ellson Exp $ $Revision: 1.20 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -62,17 +62,39 @@ static void gd_format(GVJ_t * job)
     ctx.tell = (void*)job;    /* hide *job here */
 
     im = gdImageCreateTrueColor(width, height);
-    for (y = 0; y < height; y++) {
-        for (x = 0; x < width; x++) {
-	    color = *data++;
-	    /* gd's max alpha is 127 */
-	    if ((alpha = (color >> 25) & 0x7f))
-	        /* gd's alpha is transparency instead of opacity */
-	    	color = (color & 0xffffff) | ((127 - alpha) << 24);
-	    else
-		color = im->transparent;
-	    gdImageSetPixel (im, x, y, color);
-	}
+    switch (job->device.id) {
+#ifdef HAVE_GD_PNG
+    case FORMAT_PNG:
+        for (y = 0; y < height; y++) {
+            for (x = 0; x < width; x++) {
+                color = *data++;
+	        /* gd's max alpha is 127 */
+	        /*   so right-shift 25 to lose lsb of alpha */
+	        alpha = (color >> 25) & 0x7f;
+	        im->tpixels[y][x] = (color & 0xffffff) | ((0x7f - alpha) << 24);
+	    }
+        }
+        break;
+#endif
+    default:
+/* pick an off-white color, so that transparent backgrounds look white in jpgs */
+#define TRANSPARENT 0x7ffffffe
+
+        gdImageColorTransparent(im, TRANSPARENT);
+        gdImageAlphaBlending(im, FALSE);
+        for (y = 0; y < height; y++) {
+            for (x = 0; x < width; x++) {
+                color = *data++;
+	        /* gd's max alpha is 127 */
+	        /*   so right-shift 25 to lose lsb of alpha */
+	        if ((alpha = (color >> 25) & 0x7f) >= 0x20)
+		    /* if not > 75% transparent */
+		    im->tpixels[y][x] = (color & 0xffffff) | ((0x7f - alpha) << 24);
+	        else
+		    im->tpixels[y][x] = TRANSPARENT;
+	    }
+        }
+        break;
     }
 
     switch (job->device.id) {
@@ -101,6 +123,7 @@ static void gd_format(GVJ_t * job)
 
 #ifdef HAVE_GD_PNG
     case FORMAT_PNG:
+	gdImageSaveAlpha(im, TRUE);
 	gdImagePngCtx(im, &ctx);
         break;
 #endif
