@@ -1,4 +1,4 @@
-/* $Id: gvrender_gd.c,v 1.73 2009/03/13 18:04:35 ellson Exp $ $Revision: 1.73 $ */
+/* $Id: gvrender_gd.c,v 1.79 2009/12/07 16:40:59 ellson Exp $ $Revision: 1.79 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -23,6 +23,12 @@
 #endif
 #include <stdlib.h>
 #include <stddef.h>
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
+#ifdef HAVE_INTTYPES_H
+#include <inttypes.h>
+#endif
 #include <string.h>
 #include <fcntl.h>
 
@@ -33,6 +39,14 @@
 #ifdef HAVE_LIBGD
 #include "gd.h"
 
+#ifndef INT32_MAX
+#define INT32_MAX              (2147483647)
+#endif
+#ifndef UINT32_MAX
+#define UINT32_MAX             (4294967295U)
+#endif
+
+
 typedef enum {
 	FORMAT_GIF,
 	FORMAT_JPEG,
@@ -72,8 +86,7 @@ static void gdgen_resolve_color(GVJ_t * job, gvcolor_t * color)
 
 static int white, black, transparent, basecolor;
 
-#define GD_XMAX 32767
-#define GD_YMAX 32767
+#define GD_XYMAX INT32_MAX
 
 static void gdgen_begin_page(GVJ_t * job)
 {
@@ -102,14 +115,13 @@ static void gdgen_begin_page(GVJ_t * job)
 	    fprintf(stderr, "%s: using existing GD image\n", job->common->cmdname);
 	im = (gdImagePtr) (job->context);
     } else {
-        if (job->width >= GD_XMAX || job->height >= GD_YMAX) {
-	    double scale = MIN((double)GD_XMAX / job->width,
-		(double)GD_YMAX / job->height);
+        if (job->width * job->height >= GD_XYMAX) {
+	    double scale = sqrt(GD_XYMAX / (job->width * job->height));
 	    job->width *= scale;
 	    job->height *= scale;
 	    job->zoom *= scale;
 	    fprintf(stderr,
-		"%s: graph is too large for bitmap. Scaling by %g to fit\n",
+		"%s: graph is too large for gd-renderer bitmaps. Scaling by %g to fit\n",
 		job->common->cmdname, scale);
 	}
 	if (truecolor_p) {
@@ -433,8 +445,13 @@ static int gdgen_set_penstyle(GVJ_t * job, gdImagePtr im, gdImagePtr brush)
     gdImageSetThickness(im, width);
     /* use brush instead of Thickness to improve end butts */
     if (width != PENWIDTH_NORMAL) {
-	brush = gdImageCreate(width, width);
-	gdImagePaletteCopy(brush, im);
+	if (im->trueColor) {
+	    brush = gdImageCreateTrueColor(width,width);
+	}
+	else {
+	    brush = gdImageCreate(width, width);
+	    gdImagePaletteCopy(brush, im);
+	}
 	gdImageFilledRectangle(brush, 0, 0, width - 1, width - 1,
 			       obj->pencolor.u.index);
 	gdImageSetBrush(im, brush);
@@ -664,14 +681,14 @@ gvplugin_installed_t gvrender_gd_types[] = {
 gvplugin_installed_t gvdevice_gd_types2[] = {
 #ifdef HAVE_LIBGD
 #ifdef HAVE_GD_GIF
-    {FORMAT_GIF, "gif:gd", 1, NULL, &device_features_gd},
+    {FORMAT_GIF, "gif:gd", 1, NULL, &device_features_gd_tc},  /* pretend gif is truecolor because it supports transparency */
     {FORMAT_WBMP, "wbmp:gd", 1, NULL, &device_features_gd},
 #endif
 
 #ifdef HAVE_GD_JPEG
-    {FORMAT_JPEG, "jpe:gd", 1, NULL, &device_features_gd_tc},
-    {FORMAT_JPEG, "jpeg:gd", 1, NULL, &device_features_gd_tc},
-    {FORMAT_JPEG, "jpg:gd", 1, NULL, &device_features_gd_tc},
+    {FORMAT_JPEG, "jpe:gd", 1, NULL, &device_features_gd},
+    {FORMAT_JPEG, "jpeg:gd", 1, NULL, &device_features_gd},
+    {FORMAT_JPEG, "jpg:gd", 1, NULL, &device_features_gd},
 #endif
 
 #ifdef HAVE_GD_PNG
