@@ -1,4 +1,4 @@
-/* $Id: gvlayout_neato_layout.c,v 1.16 2008/08/18 19:34:54 north Exp $ $Revision: 1.16 $ */
+/* $Id: gvlayout_neato_layout.c,v 1.20 2009/09/04 14:23:35 erg Exp $ $Revision: 1.20 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /**********************************************************
@@ -37,6 +37,7 @@ typedef enum { LAYOUT_NEATO,
 		LAYOUT_TWOPI,
 		LAYOUT_CIRCO,
 		LAYOUT_PATCHWORK,
+		LAYOUT_CLUSTER,
 		LAYOUT_NOP1,
 		LAYOUT_NOP2,
 	} layout_type;
@@ -47,6 +48,7 @@ extern void sfdp_layout(graph_t * g);
 extern void twopi_layout(graph_t * g);
 extern void circo_layout(graph_t * g);
 extern void patchwork_layout(graph_t * g);
+extern void osage_layout(graph_t * g);
 
 extern void neato_cleanup(graph_t * g);
 extern void fdp_cleanup(graph_t * g);
@@ -54,17 +56,20 @@ extern void sfdp_cleanup(graph_t * g);
 extern void twopi_cleanup(graph_t * g);
 extern void circo_cleanup(graph_t * g);
 extern void patchwork_cleanup(graph_t * g);
+extern void osage_cleanup(graph_t * g);
 
 static void nop1_layout(graph_t * g)
 {
     Nop = 1;
     neato_layout(g);
+    Nop = 0;
 }
 
 static void nop2_layout(graph_t * g)
 {
     Nop = 2;
     neato_layout(g);
+    Nop = 0;
 }
 
 gvlayout_engine_t neatogen_engine = {
@@ -109,6 +114,11 @@ gvlayout_engine_t patchwork_engine = {
     patchwork_cleanup,
 };
 
+gvlayout_engine_t osage_engine = {
+    osage_layout,
+    osage_cleanup,
+};
+
 gvlayout_features_t neatogen_features = {
         0,
 };
@@ -122,6 +132,7 @@ gvplugin_installed_t gvlayout_neato_types[] = {
     {LAYOUT_TWOPI, "twopi", 0, &twopigen_engine, &neatogen_features},
     {LAYOUT_CIRCO, "circo", 0, &circogen_engine, &neatogen_features},
     {LAYOUT_PATCHWORK, "patchwork", 0, &patchwork_engine, &neatogen_features},
+    {LAYOUT_CLUSTER, "osage", 0, &osage_engine, &neatogen_features},
     {LAYOUT_NOP1, "nop", 0, &nop1gen_engine, &neatogen_features},
     {LAYOUT_NOP1, "nop1", 0, &nop1gen_engine, &neatogen_features},
     {LAYOUT_NOP1, "nop2", 0, &nop2gen_engine, &neatogen_features},
