@@ -1,4 +1,4 @@
-  /* $Id: gvtextlayout_pango.c,v 1.47 2009/03/13 18:04:35 ellson Exp $ $Revision: 1.47 $ */
+  /* $Id: gvtextlayout_pango.c,v 1.52 2010/01/07 20:04:40 arif Exp $ $Revision: 1.52 $ */
 /* vim:set shiftwidth=4 ts=8: */
 
 /*********************************************************
@@ -187,8 +187,8 @@ static boolean pango_textlayout(textpara_t * para, char **fontpath)
 	logical_rect.height = 0;
 
     textlayout_scale = POINTS_PER_INCH / (FONT_DPI * PANGO_SCALE);
-    para->width = ROUND(logical_rect.width * textlayout_scale);
-    para->height = ROUND(logical_rect.height * textlayout_scale);
+    para->width = (int)(logical_rect.width * textlayout_scale + 1);    /* round up so that width/height are never too small */
+    para->height = (int)(logical_rect.height * textlayout_scale + 1);
 
     /* The y offset from baseline to 0,0 of the bitmap representation */
     iter = pango_layout_get_iter (layout);
