@@ -1,6 +1,6 @@
 /* manually generated configuration for Windows */
 
-#include "config_version.h"
+#include "graphviz_version.h"
 
 /* Command to open a browser on a URL */
 #define BROWSER "xdg-open"
@@ -440,6 +440,7 @@
 #define PATHSEPARATOR ":"
 
 /* Define if you want SFDP */
+#define SFDP 1
 /* #undef SFDP */
 
 /* Define if you want SMYRNA */
